@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2002,2003 Leo Savernik <l.savernik@aon.at>
- * Copyright (C) 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
+    SPDX-FileCopyrightText: 2002, 2003 Leo Savernik <l.savernik@aon.at>
+    SPDX-FileCopyrightText: 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+*/
 
 #ifdef DATAKIOSLAVE
 #  undef DATAKIOSLAVE
@@ -12,10 +12,9 @@
 
 #include "dataprotocoltest.h"
 
-#include <qtest.h>
+#include <QTest>
 #include <QDebug>
 
-#include <kio/global.h>
 
 QTEST_MAIN(DataProtocolTest)
 
@@ -99,7 +98,7 @@ public:
 
 private:
     // -- testcase related members
-    QString mime_type_expected;   // expected mime type
+    QString mime_type_expected;   // expected MIME type
     /** contains all attributes and values the testcase has to set */
     KIO::MetaData attributes_expected;
     /** contains the content as it is expected to be returned */
@@ -107,7 +106,7 @@ private:
 
 public:
     /**
-     * sets the mime type that this testcase is expected to return
+     * sets the MIME type that this testcase is expected to return
      */
     void setExpectedMimeType(const QString &mime_type)
     {
@@ -139,7 +138,7 @@ void runTest(const QByteArray &mimetype, const QStringList &metalist, const QByt
 
     kio_data.setExpectedMimeType(mimetype);
     MetaData exp_attrs;
-    foreach (const QString &meta, metalist) {
+    for (const QString &meta : metalist) {
         const QStringList metadata = meta.split(QLatin1Char('='));
         Q_ASSERT(metadata.count() == 2);
         exp_attrs[metadata[0]] = metadata[1];
@@ -184,7 +183,7 @@ void DataProtocolTest::runAllTests_data()
                                       QByteArray("blah blah") <<
                                       QByteArray("data:,blah%20blah");
 
-    QTest::newRow("mime type, escape resolving") <<
+    QTest::newRow("MIME type, escape resolving") <<
             QByteArray("text/html") <<
             usascii <<
             QByteArray("<div style=\"border:thin orange solid;padding:1ex;background-color:yellow;color:black\">Rich <b>text</b></div>") <<
