@@ -1,33 +1,20 @@
-/* This file is part of the KDE project
-   Copyright (C) 2007 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kdirlistertest.h"
-#include <qtemporaryfile.h>
-#include <kdirlister.h>
-#include <qtest.h>
+#include <QTemporaryFile>
+#include <QTest>
 
 QTEST_MAIN(KDirListerTest)
 
 #include <QDebug>
 #include "kiotesthelper.h"
 #include <kio/deletejob.h>
-#include <kdirwatch.h>
+#include <KDirWatch>
 #include <kprotocolinfo.h>
 #include <kio/job.h>
 #include <kio/copyjob.h>
@@ -46,7 +33,7 @@ void KDirListerTest::initTestCase()
     // To avoid a runtime dependency on klauncher
     qputenv("KDE_FORK_SLAVES", "yes");
 
-    // To avoid failing on broken locally defined mime types
+    // To avoid failing on broken locally defined MIME types
     QStandardPaths::setTestModeEnabled(true);
 
     KIO::setDefaultJobUiDelegateExtension(nullptr); // no "skip" dialogs
@@ -427,7 +414,7 @@ void KDirListerTest::testRefreshRootItem()
 
     // Arguably, the mtime change of "subdir" should lead to a refreshItem of subdir in the root dir.
     // So the next line shouldn't be necessary, if KDirLister did this correctly. This isn't what this test is about though.
-    org::kde::KDirNotify::emitFilesChanged(QList<QUrl>() << QUrl::fromLocalFile(path));
+    org::kde::KDirNotify::emitFilesChanged(QList<QUrl>{QUrl::fromLocalFile(path)});
     QTRY_VERIFY(!m_refreshedItems.isEmpty());
 
     QCOMPARE(m_dirLister.spyStarted.count(), 0);
@@ -460,8 +447,8 @@ void KDirListerTest::testRefreshRootItem()
     org::kde::KDirNotify::emitFilesAdded(QUrl::fromLocalFile(path));
     QTest::qWait(200);
     // The order of these two is not deterministic
-    org::kde::KDirNotify::emitFilesChanged(QList<QUrl>() << QUrl::fromLocalFile(directoryFile));
-    org::kde::KDirNotify::emitFilesChanged(QList<QUrl>() << QUrl::fromLocalFile(path));
+    org::kde::KDirNotify::emitFilesChanged(QList<QUrl>{QUrl::fromLocalFile(directoryFile)});
+    org::kde::KDirNotify::emitFilesChanged(QList<QUrl>{QUrl::fromLocalFile(path)});
     QTRY_VERIFY(!m_refreshedItems.isEmpty());
 
     QCOMPARE(m_refreshedItems.count(), 1);
@@ -547,7 +534,7 @@ void KDirListerTest::testRenameItem()
     KIO::SimpleJob *job = KIO::rename(QUrl::fromLocalFile(path), QUrl::fromLocalFile(newPath), KIO::HideProgressInfo);
     QVERIFY(job->exec());
 
-    QSignalSpy spyRefreshItems(&m_dirLister, SIGNAL(refreshItems(QList<QPair<KFileItem,KFileItem>>)));
+    QSignalSpy spyRefreshItems(&m_dirLister, &KCoreDirLister::refreshItems);
     QVERIFY(spyRefreshItems.wait(2000));
     QTRY_COMPARE(m_refreshedItems2.count(), 1);
     QPair<KFileItem, KFileItem> entry = m_refreshedItems2.first();
@@ -1235,7 +1222,7 @@ void KDirListerTest::testDirPermissionChange()
     KIO::SimpleJob *job = KIO::chmod(list.first().url(), permissions);
     QVERIFY(job->exec());
 
-    QSignalSpy spyRefreshItems(&mylister, SIGNAL(refreshItems(QList<QPair<KFileItem,KFileItem>>)));
+    QSignalSpy spyRefreshItems(&mylister, &KCoreDirLister::refreshItems);
     QVERIFY(spyRefreshItems.wait(2000));
 
     list = mylister.items();
