@@ -1,27 +1,15 @@
-/* This file is part of the KDE project
-   Copyright (C) 2007 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef KDIRLISTERTEST_H
 #define KDIRLISTERTEST_H
 
 #include <QSignalSpy>
 #include <QObject>
-#include <qtemporarydir.h>
+#include <QTemporaryDir>
 #include <QDate>
 #include <kdirlister.h>
 #include <QEventLoop>
@@ -43,7 +31,7 @@ class MyDirLister : public KDirLister, GlobalInits
 {
 public:
     MyDirLister()
-        : spyStarted(this, SIGNAL(started(QUrl))),
+        : spyStarted(this, &KCoreDirLister::started),
           spyClear(this, SIGNAL(clear())),
           spyClearQUrl(this, SIGNAL(clear(QUrl))),
           spyCompleted(this, SIGNAL(completed())),
@@ -51,7 +39,7 @@ public:
           spyCanceled(this, SIGNAL(canceled())),
           spyCanceledQUrl(this, SIGNAL(canceled(QUrl))),
           spyRedirection(this, SIGNAL(redirection(QUrl))),
-          spyItemsDeleted(this, SIGNAL(itemsDeleted(KFileItemList)))
+          spyItemsDeleted(this, &KCoreDirLister::itemsDeleted)
     {}
 
     void clearSpies()
