@@ -1,20 +1,8 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2017 Renato Araujo Oliveira Filho <renato.araujo@kdab.com>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License version 2
-    as published by the Free Software Foundation.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2017 Renato Araujo Oliveira Filho <renato.araujo@kdab.com>
 
+    SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include <QObject>
@@ -24,8 +12,8 @@
 
 #include <kfileplacesview.h>
 #include <kfileplacesmodel.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 #include <KProtocolInfo>
 
 #include <QTest>
@@ -107,15 +95,12 @@ void KFilePlacesViewTest::testUrlChanged()
     QFETCH(QString, expectedUrl);
 
     KFilePlacesView pv;
-    pv.show();
-    pv.activateWindow();
     pv.setModel(new KFilePlacesModel());
-    QVERIFY(QTest::qWaitForWindowActive(&pv));
 
     QSignalSpy urlChangedSpy(&pv, &KFilePlacesView::urlChanged);
     const QModelIndex targetIndex = pv.model()->index(row, 0);
     pv.scrollTo(targetIndex);
-    pv.clicked(targetIndex);
+    Q_EMIT pv.clicked(targetIndex);
     QTRY_COMPARE(urlChangedSpy.count(), 1);
     const QList<QVariant> args = urlChangedSpy.takeFirst();
     QCOMPARE(args.at(0).toUrl().toString(), expectedUrl);
