@@ -1,20 +1,8 @@
 /*
- *  Copyright (C) 2002 David Faure   <faure@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2002 David Faure <faure@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include <QFile>
 #include <QUrl>
@@ -22,8 +10,8 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <QDebug>
-#include <QtTest>
-#include <qstandardpaths.h>
+#include <QTest>
+#include <QStandardPaths>
 
 // Tests both KProtocolInfo and KProtocolManager
 
@@ -52,14 +40,18 @@ void KProtocolInfoTest::initTestCase()
 
 void KProtocolInfoTest::testBasic()
 {
-    QVERIFY(KProtocolInfo::isKnownProtocol(QUrl("http:/")));
-    QVERIFY(KProtocolInfo::isKnownProtocol(QUrl("file:/")));
-    QCOMPARE(KProtocolInfo::exec("file"), QString::fromLatin1("kf5/kio/file"));
-    QCOMPARE(KProtocolInfo::protocolClass("file"), QString::fromLatin1(":local"));
+    QVERIFY(KProtocolInfo::isKnownProtocol(QUrl(QStringLiteral("http:/"))));
+    QVERIFY(KProtocolInfo::isKnownProtocol(QUrl(QStringLiteral("file:/"))));
+    QVERIFY(KProtocolInfo::exec(QStringLiteral("file")).contains(QLatin1String("kf5/kio/file")));
+    QCOMPARE(KProtocolInfo::protocolClass(QStringLiteral("file")), QStringLiteral(":local"));
 
-    QCOMPARE(KProtocolInfo::protocolClass("http"), QString::fromLatin1(":internet"));
+    QCOMPARE(KProtocolInfo::protocolClass(QStringLiteral("http")), QStringLiteral(":internet"));
 
-    QVERIFY(KProtocolManager::supportsListing(QUrl("ftp://10.1.1.10")));
+    QCOMPARE(KProtocolInfo::defaultMimetype(QStringLiteral("ftp")), QString());
+    QCOMPARE(KProtocolInfo::defaultMimetype(QStringLiteral("rtsp")), QString("audio/x-pn-realaudio"));
+    QCOMPARE(KProtocolInfo::defaultMimetype(QStringLiteral("data")), QString("application/octet-stream"));
+
+    QVERIFY(KProtocolManager::supportsListing(QUrl(QStringLiteral("ftp://10.1.1.10"))));
 
     const QUrl url = QUrl::fromLocalFile(QStringLiteral("/tmp"));
     QCOMPARE(KProtocolManager::inputType(url), KProtocolInfo::T_NONE);
@@ -79,21 +71,21 @@ void KProtocolInfoTest::testExtraFields()
 
 void KProtocolInfoTest::testShowFilePreview()
 {
-    QVERIFY(KProtocolInfo::showFilePreview("file"));
-    QVERIFY(!KProtocolInfo::showFilePreview("audiocd"));
+    QVERIFY(KProtocolInfo::showFilePreview(QStringLiteral("file")));
+    QVERIFY(!KProtocolInfo::showFilePreview(QStringLiteral("audiocd")));
 }
 
 void KProtocolInfoTest::testSlaveProtocol()
 {
     QString proxy;
     QString protocol = KProtocolManager::slaveProtocol(QUrl(QStringLiteral("http://bugs.kde.org")), proxy);
-    QCOMPARE(protocol, QString::fromLatin1("http"));
+    QCOMPARE(protocol, QStringLiteral("http"));
     QVERIFY(!KProtocolManager::useProxy());
 
     // Just to test it doesn't deadlock
     KProtocolManager::reparseConfiguration();
     protocol = KProtocolManager::slaveProtocol(QUrl(QStringLiteral("http://bugs.kde.org")), proxy);
-    QCOMPARE(protocol, QString::fromLatin1("http"));
+    QCOMPARE(protocol, QStringLiteral("http"));
 }
 
 void KProtocolInfoTest::testProxySettings_data()
@@ -117,7 +109,7 @@ void KProtocolInfoTest::testProxySettings()
     KProtocolManager::reparseConfiguration();
     QString proxy;
     QString protocol = KProtocolManager::slaveProtocol(QUrl(QStringLiteral("http://bugs.kde.org")), proxy);
-    QCOMPARE(protocol, QString::fromLatin1("http"));
+    QCOMPARE(protocol, QStringLiteral("http"));
     QVERIFY(KProtocolManager::useProxy());
 
     // restore
@@ -139,41 +131,24 @@ void KProtocolInfoTest::testProtocolForArchiveMimetype()
         QSKIP("kdebase not installed");
     } else {
         const QString zip = KProtocolManager::protocolForArchiveMimetype(QStringLiteral("application/zip"));
-        QCOMPARE(zip, QString("zip"));
+        QVERIFY(zip == QLatin1String("zip") || zip == QLatin1String("krarc"));
     }
 }
 
 void KProtocolInfoTest::testHelperProtocols()
 {
-    QVERIFY(!KProtocolInfo::isHelperProtocol("http"));
-    QVERIFY(!KProtocolInfo::isHelperProtocol("ftp"));
-    QVERIFY(!KProtocolInfo::isHelperProtocol("file"));
-    QVERIFY(!KProtocolInfo::isHelperProtocol("unknown"));
+    QVERIFY(!KProtocolInfo::isHelperProtocol(QStringLiteral("http")));
+    QVERIFY(!KProtocolInfo::isHelperProtocol(QStringLiteral("ftp")));
+    QVERIFY(!KProtocolInfo::isHelperProtocol(QStringLiteral("file")));
+    QVERIFY(!KProtocolInfo::isHelperProtocol(QStringLiteral("unknown")));
     // Comes from ktelnetservice.desktop:MimeType=x-scheme-handler/telnet;x-scheme-handler/rlogin;x-scheme-handler/ssh;
     // TODO: this logic has moved to KRun. Should it be public API, so we can unittest it?
     //QVERIFY(KProtocolInfo::isHelperProtocol("telnet"));
 
     // To test that compat still works
     if (KProtocolInfo::isKnownProtocol(QStringLiteral("tel"))) {
-        QVERIFY(KProtocolInfo::isHelperProtocol("tel"));
+        QVERIFY(KProtocolInfo::isHelperProtocol(QStringLiteral("tel")));
     }
-
-    // TODO: this logic has moved to KRun. Should it be public API, so we can unittest it?
-#if 0
-    QVERIFY(KProtocolInfo::isKnownProtocol("mailto"));
-    QVERIFY(KProtocolInfo::isHelperProtocol("mailto"));
-    QVERIFY(KProtocolInfo::isHelperProtocol(QUrl("mailto:faure@kde.org")));
-
-    // "mailto" is associated with kmail2 when present, and with kmailservice otherwise.
-    KService::Ptr kmail2 = KService::serviceByStorageId("KMail2.desktop");
-    if (kmail2) {
-        //qDebug() << kmail2->entryPath();
-        QVERIFY2(KProtocolInfo::exec("mailto").contains(QLatin1String("kmail -caption \"%c\"")), // comes from KMail2.desktop
-                 qPrintable(KProtocolInfo::exec("mailto")));
-    } else {
-        QCOMPARE(KProtocolInfo::exec("mailto"), QLatin1String("kmailservice %u"));
-    }
-#endif
 }
 
 QTEST_MAIN(KProtocolInfoTest)
