@@ -1,41 +1,30 @@
 /*
- *  Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
- *  Copyright (C) 2007, 2009 David Faure   <faure@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2007, 2009 David Faure <faure@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #undef QT_USE_FAST_OPERATOR_PLUS
-#undef QT_USE_FAST_CONCATENATION
 
 #include "krununittest.h"
 
-#include <QtTest>
+#include <QTest>
+#include <QSignalSpy>
 
 QTEST_GUILESS_MAIN(KRunUnitTest)
 
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 
 #include "krun.h"
 #include <desktopexecparser.h>
-#include <kshell.h>
-#include <kservice.h>
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
-#include <kprocess.h>
+#include <KShell>
+#include <KService>
+#include <KApplicationTrader>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <KProcess>
+#include <kprotocolinfo.h>
 #include <KDesktopFile>
 #include "kiotesthelper.h" // createTestFile etc.
 #ifdef Q_OS_UNIX
@@ -44,10 +33,17 @@ QTEST_GUILESS_MAIN(KRunUnitTest)
 
 void KRunUnitTest::initTestCase()
 {
-    QStandardPaths::enableTestMode(true);
-    // testProcessDesktopExec works only if your terminal application is set to "x-term"
+    QStandardPaths::setTestModeEnabled(true);
+
+    qputenv("PATH", qgetenv("PATH") + QFile::encodeName(QDir::listSeparator() + QCoreApplication::applicationDirPath()));
+
+    // testProcessDesktopExec works only if your terminal application is set to "xterm"
     KConfigGroup cg(KSharedConfig::openConfig(), "General");
-    cg.writeEntry("TerminalApplication", "x-term");
+    cg.writeEntry("TerminalApplication", "true");
+
+    // We just want to test if the command is properly constructed
+    m_pseudoTerminalProgram = QStandardPaths::findExecutable(QStringLiteral("true"));
+    QVERIFY(!m_pseudoTerminalProgram.isEmpty());
 
     // Determine the full path of sh - this is needed to make testProcessDesktopExecNoFile()
     // pass on systems where QStandardPaths::findExecutable("sh") is not "/bin/sh".
@@ -76,7 +72,7 @@ void KRunUnitTest::testExecutableName_data()
     QTest::newRow("\"progname\" \"arg1\"") << "\"progname\" \"arg1\"" << "progname" << "progname";
     QTest::newRow("'quoted' \"arg1\"") << "'quoted' \"arg1\"" << "quoted" << "quoted";
     QTest::newRow(" 'leading space'   arg1") << " 'leading space'   arg1" << "leading space" << "leading space";
-    QTest::newRow("if_command") << "if test -e /tmp/foo; then kwrite ; else konsole ; fi" << "if" << "if";
+    QTest::newRow("if_command") << "if test -e /tmp/foo; then kwrite ; else konsole ; fi" << "" << ""; // "if" isn't a known executable, so this is good...
 }
 
 void KRunUnitTest::testExecutableName()
@@ -130,12 +126,12 @@ void KRunUnitTest::testProcessDesktopExec()
     static const char *const results[] = {
         "/bin/date -u", // 0
         "/bin/sh -c 'echo $PWD '", // 1
-        "x-term -T ' - just_a_test' -e /bin/date -u", // 2
-        "x-term -T ' - just_a_test' -e /bin/sh -c 'echo $PWD '", // 3
+        "/bin/true -T ' - just_a_test' -e /bin/date -u", // 2
+        "/bin/true -T ' - just_a_test' -e /bin/sh -c 'echo $PWD '", // 3
         /* kdesu */ " -u sprallo -c '/bin/date -u'", // 4
         /* kdesu */ " -u sprallo -c '/bin/sh -c '\\''echo $PWD '\\'''", // 5
-        "x-term -T ' - just_a_test' -e su sprallo -c '/bin/date -u'", // 6
-        "x-term -T ' - just_a_test' -e su sprallo -c '/bin/sh -c '\\''echo $PWD '\\'''", // 7
+        "/bin/true -T ' - just_a_test' -e su sprallo -c '/bin/date -u'", // 6
+        "/bin/true -T ' - just_a_test' -e su sprallo -c '/bin/sh -c '\\''echo $PWD '\\'''", // 7
     };
 
     // Find out the full path of the shell which will be used to execute shell commands
@@ -159,6 +155,7 @@ void KRunUnitTest::testProcessDesktopExec()
                     }
                 }
                 const QString result = QString::fromLatin1(results[pt])
+                                       .replace(QLatin1String("/bin/true"), m_pseudoTerminalProgram)
                                        .replace(QLatin1String("/bin/sh"), shellPath)
                                        .replace(QLatin1String("/bin/date"), datePath);
                 checkDesktopExecParser(execs[ex], terms[te], sus[su], l0, false, exe + result);
@@ -179,11 +176,10 @@ void KRunUnitTest::testProcessDesktopExecNoFile_data()
     QList<QUrl> l4; l4 << QUrl(QStringLiteral("http://login:password@www.kde.org"));
 
     // A real-world use case would be kate.
-    // But I picked kdeinit5 since it's installed by kdelibs
-    QString kdeinit = QStandardPaths::findExecutable(QStringLiteral("kdeinit5"));
-    if (kdeinit.isEmpty()) {
-        kdeinit = QStringLiteral("kdeinit5");
-    }
+    // But I picked ktrash5 since it's installed by kio
+    QString ktrash = QStandardPaths::findExecutable(QStringLiteral("ktrash5"));
+    QVERIFY(!ktrash.isEmpty());
+    QString ktrashQuoted = KShell::quoteArg(ktrash);
 
     QString kioexec = QCoreApplication::applicationDirPath() + "/kioexec";
     if (!QFileInfo::exists(kioexec)) {
@@ -192,34 +188,30 @@ void KRunUnitTest::testProcessDesktopExecNoFile_data()
     QVERIFY(QFileInfo::exists(kioexec));
     QString kioexecQuoted = KShell::quoteArg(kioexec);
 
-    QString kmailservice = QStandardPaths::findExecutable(QStringLiteral("kmailservice5"));
-    if (!QFile::exists(kmailservice)) {
-        kmailservice = QStringLiteral("kmailservice5");
-    }
+    QTest::newRow("%U l0") << "ktrash5 %U" << l0 << false << ktrashQuoted;
+    QTest::newRow("%U l1") << "ktrash5 %U" << l1 << false << ktrashQuoted + " /tmp";
+    QTest::newRow("%U l2") << "ktrash5 %U" << l2 << false << ktrashQuoted + " http://localhost/foo";
+    QTest::newRow("%U l3") << "ktrash5 %U" << l3 << false << ktrashQuoted + " '/local/some file' http://remotehost.org/bar";
 
-    QTest::newRow("%U l0") << "kdeinit5 %U" << l0 << false << kdeinit;
-    QTest::newRow("%U l1") << "kdeinit5 %U" << l1 << false << kdeinit + " /tmp";
-    QTest::newRow("%U l2") << "kdeinit5 %U" << l2 << false << kdeinit + " http://localhost/foo";
-    QTest::newRow("%U l3") << "kdeinit5 %U" << l3 << false << kdeinit + " '/local/some file' http://remotehost.org/bar";
+    //QTest::newRow("%u l0") << "ktrash5 %u" << l0 << false << ktrashQuoted; // gives runtime warning
+    QTest::newRow("%u l1") << "ktrash5 %u" << l1 << false << ktrashQuoted + " /tmp";
+    QTest::newRow("%u l2") << "ktrash5 %u" << l2 << false << ktrashQuoted + " http://localhost/foo";
+    //QTest::newRow("%u l3") << "ktrash5 %u" << l3 << false << ktrashQuoted; // gives runtime warning
 
-    //QTest::newRow("%u l0") << "kdeinit5 %u" << l0 << false << kdeinit; // gives runtime warning
-    QTest::newRow("%u l1") << "kdeinit5 %u" << l1 << false << kdeinit + " /tmp";
-    QTest::newRow("%u l2") << "kdeinit5 %u" << l2 << false << kdeinit + " http://localhost/foo";
-    //QTest::newRow("%u l3") << "kdeinit5 %u" << l3 << false << kdeinit; // gives runtime warning
+    QTest::newRow("%F l0") << "ktrash5 %F" << l0 << false << ktrashQuoted;
+    QTest::newRow("%F l1") << "ktrash5 %F" << l1 << false << ktrashQuoted + " /tmp";
+    QTest::newRow("%F l2") << "ktrash5 %F" << l2 << false << kioexecQuoted + " 'ktrash5 %F' http://localhost/foo";
+    QTest::newRow("%F l3") << "ktrash5 %F" << l3 << false << kioexecQuoted + " 'ktrash5 %F' 'file:///local/some file' http://remotehost.org/bar";
 
-    QTest::newRow("%F l0") << "kdeinit5 %F" << l0 << false << kdeinit;
-    QTest::newRow("%F l1") << "kdeinit5 %F" << l1 << false << kdeinit + " /tmp";
-    QTest::newRow("%F l2") << "kdeinit5 %F" << l2 << false << kioexecQuoted + " 'kdeinit5 %F' http://localhost/foo";
-    QTest::newRow("%F l3") << "kdeinit5 %F" << l3 << false << kioexecQuoted + " 'kdeinit5 %F' 'file:///local/some file' http://remotehost.org/bar";
+    QTest::newRow("%F l1 tempfile") << "ktrash5 %F" << l1 << true << kioexecQuoted + " --tempfiles 'ktrash5 %F' file:///tmp";
+    QTest::newRow("%f l1 tempfile") << "ktrash5 %f" << l1 << true << kioexecQuoted + " --tempfiles 'ktrash5 %f' file:///tmp";
 
-    QTest::newRow("%F l1 tempfile") << "kdeinit5 %F" << l1 << true << kioexecQuoted + " --tempfiles 'kdeinit5 %F' file:///tmp";
-    QTest::newRow("%f l1 tempfile") << "kdeinit5 %f" << l1 << true << kioexecQuoted + " --tempfiles 'kdeinit5 %f' file:///tmp";
+    QTest::newRow("sh -c ktrash5 %F") << "sh -c \"ktrash5 \"'\\\"'\"%F\"'\\\"'"
+                                       << l1 << false << m_sh + " -c 'ktrash5 \\\"/tmp\\\"'";
 
-    QTest::newRow("sh -c kdeinit5 %F") << "sh -c \"kdeinit5 \"'\\\"'\"%F\"'\\\"'"
-                                       << l1 << false << m_sh + " -c 'kdeinit5 \\\"/tmp\\\"'";
-
-    QTest::newRow("kmailservice5 %u l1") << "kmailservice5 %u" << l1 << false << kmailservice + " /tmp";
-    QTest::newRow("kmailservice5 %u l4") << "kmailservice5 %u" << l4 << false << kmailservice + " http://login:password@www.kde.org";
+    // This was originally with kmailservice5, but that relies on it being installed
+    QTest::newRow("ktrash5 %u l1") << "ktrash5 %u" << l1 << false << ktrashQuoted + " /tmp";
+    QTest::newRow("ktrash5 %u l4") << "ktrash5 %u" << l4 << false << ktrashQuoted + " http://login:password@www.kde.org";
 }
 
 void KRunUnitTest::testProcessDesktopExecNoFile()
@@ -231,22 +223,65 @@ void KRunUnitTest::testProcessDesktopExecNoFile()
     QFETCH(QString, expected);
     KIO::DesktopExecParser parser(service, urls);
     parser.setUrlsAreTempFiles(tempfiles);
-    QCOMPARE(KShell::joinArgs(parser.resultingArguments()), expected);
+    const QStringList args = parser.resultingArguments();
+    QVERIFY2(!args.isEmpty(), qPrintable(parser.errorMessage()));
+    QCOMPARE(KShell::joinArgs(args), expected);
 }
 
+extern KSERVICE_EXPORT int ksycoca_ms_between_checks;
+
+void KRunUnitTest::testKtelnetservice()
+{
+    const QString ktelnetDesk = QFINDTESTDATA(QStringLiteral("../src/ioslaves/telnet/ktelnetservice5.desktop"));
+    QVERIFY(!ktelnetDesk.isEmpty());
+
+    // KApplicationTrader in KIO::DesktopExecParser::hasSchemeHandler() needs the .desktop file to be installed
+    const QString destDir = QStandardPaths::writableLocation(QStandardPaths::ApplicationsLocation);
+    QVERIFY(QDir().mkpath(destDir));
+    QFile::remove(destDir + QLatin1String("/ktelnetservice5.desktop"));
+    QVERIFY(QFile::copy(ktelnetDesk, destDir + QLatin1String("/ktelnetservice5.desktop")));
+
+    ksycoca_ms_between_checks = 0; // need it to check the ksycoca mtime
+
+    KService::Ptr service = KService::serviceByStorageId(QStringLiteral("ktelnetservice5.desktop"));
+    QVERIFY(service);
+
+    QString ktelnetExec = QStandardPaths::findExecutable(QStringLiteral("ktelnetservice5"));
+    // if KIO is installed we'll find <bindir>/ktelnetservice5, otherwise KIO::DesktopExecParser will
+    // use the executable from Exec= line
+    if (ktelnetExec.isEmpty()) {
+        ktelnetExec = service->exec().remove(QLatin1String(" %u"));
+    }
+    QVERIFY(!ktelnetExec.isEmpty());
+
+    const QStringList protocols({QStringLiteral("ssh"), QStringLiteral("telnet"), QStringLiteral("rlogin")});
+    for (const QString &protocol : protocols) {
+        // Check that hasSchemeHandler will return true
+        QVERIFY(!KProtocolInfo::isKnownProtocol(protocol));
+        QVERIFY(!KProtocolInfo::isHelperProtocol(protocol));
+        QVERIFY(KApplicationTrader::preferredService(QLatin1String("x-scheme-handler/") + protocol));
+
+        const QList<QUrl> urls({QUrl(QStringLiteral("%1://root@10.1.1.1").arg(protocol))});
+        KIO::DesktopExecParser parser(*service, urls);
+        QCOMPARE(KShell::joinArgs(parser.resultingArguments()),
+                 QStringLiteral("%1 %2://root@10.1.1.1").arg(KShell::quoteArg(ktelnetExec), protocol));
+    }
+}
+
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 71)
 class KRunImpl : public KRun
 {
 public:
     KRunImpl(const QUrl &url)
         : KRun(url, nullptr, false), m_errCode(-1) {}
 
-    void foundMimeType(const QString &type) Q_DECL_OVERRIDE {
+    void foundMimeType(const QString &type) override {
         m_mimeType = type;
         // don't call KRun::foundMimeType, we don't want to start an app ;-)
         setFinished(true);
     }
 
-    void handleInitError(int kioErrorCode, const QString &err) Q_DECL_OVERRIDE {
+    void handleInitError(int kioErrorCode, const QString &err) override {
         m_errCode = kioErrorCode;
         m_errText = err;
     }
@@ -276,7 +311,7 @@ void KRunUnitTest::testMimeTypeFile()
     createTestFile(filePath, true);
     KRunImpl *krun = new KRunImpl(QUrl::fromLocalFile(filePath));
     krun->setAutoDelete(false);
-    QSignalSpy spyFinished(krun, SIGNAL(finished()));
+    QSignalSpy spyFinished(krun, &KRun::finished);
     QVERIFY(spyFinished.wait(1000));
     QCOMPARE(krun->mimeTypeFound(), QString::fromLatin1("text/plain"));
     delete krun;
@@ -287,7 +322,7 @@ void KRunUnitTest::testMimeTypeDirectory()
     const QString dir = homeTmpDir() + "dir";
     createTestDirectory(dir);
     KRunImpl *krun = new KRunImpl(QUrl::fromLocalFile(dir));
-    QSignalSpy spyFinished(krun, SIGNAL(finished()));
+    QSignalSpy spyFinished(krun, &KRun::finished);
     QVERIFY(spyFinished.wait(1000));
     QCOMPARE(krun->mimeTypeFound(), QString::fromLatin1("inode/directory"));
 }
@@ -297,8 +332,8 @@ void KRunUnitTest::testMimeTypeBrokenLink()
     const QString dir = homeTmpDir() + "dir";
     createTestDirectory(dir);
     KRunImpl *krun = new KRunImpl(QUrl::fromLocalFile(dir + "/testlink"));
-    QSignalSpy spyError(krun, SIGNAL(error()));
-    QSignalSpy spyFinished(krun, SIGNAL(finished()));
+    QSignalSpy spyError(krun, &KRun::error);
+    QSignalSpy spyFinished(krun, &KRun::finished);
     QVERIFY(spyFinished.wait(1000));
     QVERIFY(krun->mimeTypeFound().isEmpty());
     QCOMPARE(spyError.count(), 1);
@@ -307,17 +342,20 @@ void KRunUnitTest::testMimeTypeBrokenLink()
     QTest::qWait(100); // let auto-deletion proceed.
 }
 
-void KRunUnitTest::testMimeTypeDoesNotExist()
+void KRunUnitTest::testMimeTypeDoesNotExist() // ported to OpenUrlJobTest::nonExistingFile()
 {
     KRunImpl *krun = new KRunImpl(QUrl::fromLocalFile(QStringLiteral("/does/not/exist")));
-    QSignalSpy spyError(krun, SIGNAL(error()));
-    QSignalSpy spyFinished(krun, SIGNAL(finished()));
+    QSignalSpy spyError(krun, &KRun::error);
+    QSignalSpy spyFinished(krun, &KRun::finished);
     QVERIFY(spyFinished.wait(1000));
     QVERIFY(krun->mimeTypeFound().isEmpty());
     QCOMPARE(spyError.count(), 1);
     QTest::qWait(100); // let auto-deletion proceed.
 }
 
+#endif
+
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 71)
 static const char s_tempServiceName[] = "krununittest_service.desktop";
 
 static void createSrcFile(const QString path)
@@ -326,7 +364,9 @@ static void createSrcFile(const QString path)
     QVERIFY2(srcFile.open(QFile::WriteOnly), qPrintable(srcFile.errorString()));
     srcFile.write("Hello world\n");
 }
+#endif
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 71)
 void KRunUnitTest::KRunRunService_data()
 {
     QTest::addColumn<bool>("tempFile");
@@ -337,6 +377,9 @@ void KRunUnitTest::KRunRunService_data()
     QTest::newRow("runApp") << false << true;
     QTest::newRow("runApp_tempfile") << true << true;
 }
+#endif
+
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 71)
 void KRunUnitTest::KRunRunService()
 {
     QFETCH(bool, tempFile);
@@ -358,7 +401,7 @@ void KRunUnitTest::KRunRunService()
     // When calling KRun::runService or KRun::runApplication
     qint64 pid = useRunApplication
         ? KRun::runApplication(service, urls, nullptr, tempFile ? KRun::RunFlags(KRun::DeleteTemporaryFiles) : KRun::RunFlags())
-        : KRun::runService(service, urls, nullptr, tempFile);
+        : KRun::runService(service, urls, nullptr, tempFile); // DEPRECATED
 
     // Then the service should be executed (which copies the source file to "dest")
     QVERIFY(pid != 0);
@@ -397,3 +440,5 @@ QString KRunUnitTest::createTempService()
     m_filesToRemove.append(fakeService);
     return fakeService;
 }
+
+#endif
