@@ -1,32 +1,19 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                       David Faure <faure@kde.org>
-    Copyright (C) 2007 Thiago Macieira <thiago@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2007 Thiago Macieira <thiago@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "connection_p.h"
 #include <QDebug>
 #include "connectionbackend_p.h"
+#include "kiocoredebug.h"
 
 #include <errno.h>
 
-#include <QQueue>
-#include <QCoreApplication>
 
 using namespace KIO;
 
@@ -36,7 +23,7 @@ void ConnectionPrivate::dequeue()
         return;
     }
 
-    foreach (const Task &task, outgoingTasks) {
+    for (const Task &task : qAsConst(outgoingTasks)) {
         q->sendnow(task.cmd, task.data);
     }
     outgoingTasks.clear();
@@ -49,16 +36,18 @@ void ConnectionPrivate::dequeue()
 void ConnectionPrivate::commandReceived(const Task &task)
 {
     //qDebug() << this << "Command " << task.cmd << " added to the queue";
-    if (!suspended && incomingTasks.isEmpty()) {
+    if (!suspended && incomingTasks.isEmpty() && readMode == Connection::ReadMode::EventDriven) {
         QMetaObject::invokeMethod(q, "dequeue", Qt::QueuedConnection);
     }
-    incomingTasks.enqueue(task);
+    incomingTasks.append(task);
 }
 
 void ConnectionPrivate::disconnected()
 {
     q->close();
-    QMetaObject::invokeMethod(q, "readyRead", Qt::QueuedConnection);
+    if (readMode == Connection::ReadMode::EventDriven) {
+        QMetaObject::invokeMethod(q, "readyRead", Qt::QueuedConnection);
+    }
 }
 
 void ConnectionPrivate::setBackend(ConnectionBackend *b)
@@ -96,7 +85,9 @@ void Connection::suspend()
 void Connection::resume()
 {
     // send any outgoing or incoming commands that may be in queue
-    QMetaObject::invokeMethod(this, "dequeue", Qt::QueuedConnection);
+    if (d->readMode == Connection::ReadMode::EventDriven) {
+        QMetaObject::invokeMethod(this, "dequeue", Qt::QueuedConnection);
+    }
 
     //qDebug() << this << "Resumed";
     d->suspended = false;
@@ -110,7 +101,7 @@ void Connection::close()
     if (d->backend) {
         d->backend->disconnect(this);
         d->backend->deleteLater();
-        d->backend = 0;
+        d->backend = nullptr;
     }
     d->outgoingTasks.clear();
     d->incomingTasks.clear();
@@ -137,11 +128,9 @@ void Connection::connectToRemote(const QUrl &address)
     const QString scheme = address.scheme();
 
     if (scheme == QLatin1String("local")) {
-        d->setBackend(new ConnectionBackend(ConnectionBackend::LocalSocketMode, this));
-    } else if (scheme == QLatin1String("tcp")) {
-        d->setBackend(new ConnectionBackend(ConnectionBackend::TcpSocketMode, this));
+        d->setBackend(new ConnectionBackend(this));
     } else {
-        qWarning() << "Unknown protocol requested:" << scheme << "(" << address << ")";
+        qCWarning(KIO_CORE) << "Unknown protocol requested:" << scheme << "(" << address << ")";
         Q_ASSERT(0);
         return;
     }
@@ -150,7 +139,7 @@ void Connection::connectToRemote(const QUrl &address)
     if (!d->backend->connectToRemote(address)) {
         //kWarning(7017) << "could not connect to" << address << "using scheme" << scheme ;
         delete d->backend;
-        d->backend = 0;
+        d->backend = nullptr;
         return;
     }
 
@@ -171,7 +160,7 @@ bool Connection::send(int cmd, const QByteArray &data)
         Task task;
         task.cmd = cmd;
         task.data = data;
-        d->outgoingTasks.append(task);
+        d->outgoingTasks.append(std::move(task));
         return true;
     } else {
         return sendnow(cmd, data);
@@ -212,18 +201,25 @@ int Connection::read(int *_cmd, QByteArray &data)
         //kWarning() << this << "Task list is empty!";
         return -1;
     }
-    const Task task = d->incomingTasks.dequeue();
+    const Task& task = d->incomingTasks.constFirst();
     //qDebug() << this << "Command " << task.cmd << " removed from the queue (size "
     //         << task.data.size() << ")";
     *_cmd = task.cmd;
     data = task.data;
 
+    d->incomingTasks.removeFirst();
+
     // if we didn't empty our reading queue, emit again
-    if (!d->suspended && !d->incomingTasks.isEmpty()) {
+    if (!d->suspended && !d->incomingTasks.isEmpty() && d->readMode == Connection::ReadMode::EventDriven) {
         QMetaObject::invokeMethod(this, "dequeue", Qt::QueuedConnection);
     }
 
     return data.size();
 }
 
+void Connection::setReadMode(ReadMode readMode)
+{
+    d->readMode = readMode;
+}
+
 #include "moc_connection_p.cpp"
