@@ -1,35 +1,24 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Torben Weis <weis@kde.org>
-    Copyright (C) 2006-2013 David Faure <faure@kde.org>
-    Copyright (C) 2009 Michael Pyne <michael.pyne@kdemail.net>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2006-2013 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2009 Michael Pyne <michael.pyne@kdemail.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "desktopexecparser.h"
 #include "kiofuse_interface.h"
 
-#include <kmacroexpander.h>
-#include <kshell.h>
-#include <ksharedconfig.h>
-#include <kdesktopfile.h>
-#include <kservice.h>
-#include <kconfiggroup.h>
+#include <KMacroExpander>
+#include <KShell>
+#include <KSharedConfig>
+#include <KDesktopFile>
+#include <KService>
+#include <KConfigGroup>
 #include <kprotocolinfo.h>
-#include <kmimetypetrader.h>
+#include <KApplicationTrader>
+#include <KLocalizedString>
 
 #include <QFile>
 #include <QDir>
@@ -237,7 +226,7 @@ bool KIO::DesktopExecParser::isProtocolInSupportedList(const QUrl &url, const QS
 //  A) if the .protocol file says "launch an application", then the new-style handler-app has priority
 //  B) but if the .protocol file is for a kioslave (e.g. kio_http) then this has priority over
 //     firefox or chromium saying x-scheme-handler/http. Gnome people want to send all HTTP urls
-//     to a webbrowser, but we want mimetype-determination-in-calling-application by default
+//     to a webbrowser, but we want MIME-type-determination-in-calling-application by default
 //     (the user can configure a BrowserApplication though)
 bool KIO::DesktopExecParser::hasSchemeHandler(const QUrl &url)
 {
@@ -247,7 +236,7 @@ bool KIO::DesktopExecParser::hasSchemeHandler(const QUrl &url)
     if (KProtocolInfo::isKnownProtocol(url)) {
         return false; // this is case B, we prefer kioslaves over the competition
     }
-    const KService::Ptr service = KMimeTypeTrader::self()->preferredService(QLatin1String("x-scheme-handler/") + url.scheme());
+    const KService::Ptr service = KApplicationTrader::preferredService(QLatin1String("x-scheme-handler/") + url.scheme());
     if (service) {
         qCDebug(KIO_CORE) << QLatin1String("preferred service for x-scheme-handler/") + url.scheme() << service->desktopEntryName();
     }
@@ -264,6 +253,7 @@ public:
     QList<QUrl> urls;
     bool tempFiles;
     QString suggestedFileName;
+    QString m_errorString;
 };
 
 KIO::DesktopExecParser::DesktopExecParser(const KService &service, const QList<QUrl> &urls)
@@ -294,14 +284,78 @@ static const QString kioexecPath()
     return kioexec;
 }
 
+static QString findNonExecutableProgram(const QString &executable)
+{
+    // Relative to current dir, or absolute path
+    const QFileInfo fi(executable);
+    if (fi.exists() && !fi.isExecutable()) {
+        return executable;
+    }
+
+#ifdef Q_OS_UNIX
+    // This is a *very* simplified version of QStandardPaths::findExecutable
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    const auto skipEmptyParts = QString::SkipEmptyParts;
+#else
+    const auto skipEmptyParts = Qt::SkipEmptyParts;
+#endif
+    const QStringList searchPaths = QString::fromLocal8Bit(qgetenv("PATH")).split(QDir::listSeparator(), skipEmptyParts);
+    for (const QString &searchPath : searchPaths) {
+        const QString candidate = searchPath + QLatin1Char('/') + executable;
+        const QFileInfo fileInfo(candidate);
+        if (fileInfo.exists()) {
+            if (fileInfo.isExecutable()) {
+                qWarning() << "Internal program error. QStandardPaths::findExecutable couldn't find" << executable << "but our own logic found it at" << candidate << ". Please report a bug at https://bugs.kde.org";
+            } else {
+                return candidate;
+            }
+        }
+    }
+#endif
+    return QString();
+}
+
 QStringList KIO::DesktopExecParser::resultingArguments() const
 {
     QString exec = d->service.exec();
     if (exec.isEmpty()) {
-        qCWarning(KIO_CORE) << "No Exec field in `" << d->service.entryPath() << "' !";
+        d->m_errorString = i18n("No Exec field in %1", d->service.entryPath());
+        qCWarning(KIO_CORE) << "No Exec field in" << d->service.entryPath();
         return QStringList();
     }
 
+    // Extract the name of the binary to execute from the full Exec line, to see if it exists
+    const QString binary = executablePath(exec);
+    QString executableFullPath;
+    if (!binary.isEmpty()) { // skip all this if the Exec line is a complex shell command
+        if (QDir::isRelativePath(binary)) {
+            // Resolve the executable to ensure that helpers in libexec are found.
+            // Too bad for commands that need a shell - they must reside in $PATH.
+            executableFullPath = QStandardPaths::findExecutable(binary);
+            if (executableFullPath.isEmpty()) {
+                executableFullPath = QFile::decodeName(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/") + binary;
+            }
+        } else {
+            executableFullPath = binary;
+        }
+
+        // Now check that the binary exists and has the executable flag
+        if (!QFileInfo(executableFullPath).isExecutable()) {
+            // Does it really not exist, or is it non-executable (on Unix)? (bug #415567)
+            const QString nonExecutable = findNonExecutableProgram(binary);
+            if (nonExecutable.isEmpty()) {
+                d->m_errorString = i18n("Could not find the program '%1'", binary);
+            } else {
+                if (QDir::isRelativePath(binary)) {
+                    d->m_errorString = i18n("The program '%1' was found at '%2' but it is missing executable permissions.", binary, nonExecutable);
+                } else {
+                    d->m_errorString = i18n("The program '%1' is missing executable permissions.", nonExecutable);
+                }
+            }
+            return QStringList();
+        }
+    }
+
     QStringList result;
     bool appHasTempFileOption;
 
@@ -309,6 +363,7 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
     KRunMX2 mx2(d->urls);
 
     if (!mx1.expandMacrosShellQuote(exec)) {    // Error in shell syntax
+        d->m_errorString = i18n("Syntax error in command %1 coming from %2", exec, d->service.entryPath());
         qCWarning(KIO_CORE) << "Syntax error in command" << d->service.exec() << ", service" << d->service.name();
         return QStringList();
     }
@@ -421,7 +476,16 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
     if (d->service.terminal()) {
         KConfigGroup cg(KSharedConfig::openConfig(), "General");
         QString terminal = cg.readPathEntry("TerminalApplication", QStringLiteral("konsole"));
-        if (terminal == QLatin1String("konsole")) {
+        const bool isKonsole = (terminal == QLatin1String("konsole"));
+
+        QString terminalPath = QStandardPaths::findExecutable(terminal);
+        if (terminalPath.isEmpty()) {
+            d->m_errorString = i18n("Terminal %1 not found while trying to run %2", terminal, d->service.entryPath());
+            qCWarning(KIO_CORE) << "Terminal" << terminal << "not found, service" << d->service.name();
+            return QStringList();
+        }
+        terminal = terminalPath;
+        if (isKonsole) {
             if (!d->service.workingDirectory().isEmpty()) {
                 terminal += QLatin1String(" --workdir ") + KShell::quoteArg(d->service.workingDirectory());
             }
@@ -432,6 +496,7 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
         }
         terminal += QLatin1Char(' ') + d->service.terminalOptions();
         if (!mx1.expandMacrosShellQuote(terminal)) {
+            d->m_errorString = i18n("Syntax error in command %1 while trying to run %2", terminal, d->service.entryPath());
             qCWarning(KIO_CORE) << "Syntax error in command" << terminal << ", service" << d->service.name();
             return QStringList();
         }
@@ -442,20 +507,10 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
 
     KShell::Errors err;
     QStringList execlist = KShell::splitArgs(exec, KShell::AbortOnMeta | KShell::TildeExpand, &err);
-    if (err == KShell::NoError && !execlist.isEmpty()) { // mx1 checked for syntax errors already
-        const QString executable = execlist.at(0);
-        if (QDir::isRelativePath(executable)) {
-            // Resolve the executable to ensure that helpers in libexec are found.
-            // Too bad for commands that need a shell - they must reside in $PATH.
-            QString exePath = QStandardPaths::findExecutable(executable);
-            if (exePath.isEmpty()) {
-                exePath = QFile::decodeName(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/") + executable;
-            }
-            if (QFile::exists(exePath)) {
-                execlist[0] = exePath;
-            }
-        }
+    if (!executableFullPath.isEmpty()) {
+        execlist[0] = executableFullPath;
     }
+
     if (d->service.substituteUid()) {
         if (d->service.terminal()) {
             result << QStringLiteral("su");
@@ -491,6 +546,11 @@ QStringList KIO::DesktopExecParser::resultingArguments() const
     return result;
 }
 
+QString KIO::DesktopExecParser::errorMessage() const
+{
+    return d->m_errorString;
+}
+
 //static
 QString KIO::DesktopExecParser::executableName(const QString &execLine)
 {
@@ -502,7 +562,7 @@ QString KIO::DesktopExecParser::executableName(const QString &execLine)
 QString KIO::DesktopExecParser::executablePath(const QString &execLine)
 {
     // Remove parameters and/or trailing spaces.
-    const QStringList args = KShell::splitArgs(execLine);
+    const QStringList args = KShell::splitArgs(execLine, KShell::AbortOnMeta | KShell::TildeExpand);
     for (const QString &arg : args) {
         if (!arg.contains(QLatin1Char('='))) {
             return arg;
