@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "filecopyjob.h"
@@ -340,7 +328,7 @@ void FileCopyJobPrivate::slotCanResume(KIO::Job *job, KIO::filesize_t offset)
     if (job == m_putJob || job == m_copyJob) {
         //qDebug() << "'can resume' from PUT job. offset=" << KIO::number(offset);
         if (offset) {
-            RenameDialog_Result res = R_RESUME;
+            RenameDialog_Result res = Result_Resume;
 
             if (!KProtocolManager::autoResume() && !(m_flags & Overwrite) && m_uiDelegateExtension) {
                 QString newPath;
@@ -354,9 +342,9 @@ void FileCopyJobPrivate::slotCanResume(KIO::Job *job, KIO::filesize_t offset)
                           m_sourceSize, offset);
             }
 
-            if (res == R_OVERWRITE || (m_flags & Overwrite)) {
+            if (res == Result_Overwrite || (m_flags & Overwrite)) {
                 offset = 0;
-            } else if (res == R_CANCEL) {
+            } else if (res == Result_Cancel) {
                 if (job == m_putJob) {
                     m_putJob->kill(FileCopyJob::Quietly);
                     q->removeSubjob(m_putJob);
@@ -403,7 +391,7 @@ void FileCopyJobPrivate::slotCanResume(KIO::Job *job, KIO::filesize_t offset)
             q->connect(m_getJob, &KIO::TransferJob::data, q, [this](KIO::Job *job, const QByteArray &data) {
                 slotData(job, data);
             });
-            q->connect(m_getJob, QOverload<KIO::Job *, const QString &>::of(&KIO::TransferJob::mimetype), q, [this](KIO::Job *job, const QString &type) {
+            q->connect(m_getJob, &KIO::TransferJob::mimeTypeFound, q, [this](KIO::Job *job, const QString &type) {
                 slotMimetype(job, type);
             });
         } else { // copyjob
@@ -465,7 +453,10 @@ void FileCopyJobPrivate::slotDataReq(KIO::Job *, QByteArray &data)
 void FileCopyJobPrivate::slotMimetype(KIO::Job *, const QString &type)
 {
     Q_Q(FileCopyJob);
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 78)
     emit q->mimetype(q, type);
+#endif
+    emit q->mimeTypeFound(q, type);
 }
 
 void FileCopyJob::slotResult(KJob *job)
