@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2005 - 2007 Till Adam <adam@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2005-2007 Till Adam <adam@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // $Id: kacl.cpp 424977 2005-06-13 15:13:22Z tilladam $
 
@@ -22,7 +10,6 @@
 
 #include <config-kiocore.h>
 
-#include <qplatformdefs.h>
 #if HAVE_POSIX_ACL
 #include <sys/acl.h>
 #include <acl/libacl.h>
@@ -31,8 +18,6 @@
 #include <QString>
 #include <QDataStream>
 
-#include <QList>
-#include <QPair>
 
 #include <memory>
 
@@ -200,17 +185,6 @@ static void permissionsToEntry(acl_entry_t entry, unsigned short v)
     }
 }
 
-#if HAVE_POSIX_ACL
-#if 0
-static void printACL(acl_t acl, const QString &comment)
-{
-    const char *txt = acl_to_text(acl);
-    qCDebug(KIO_CORE) << comment << txt;
-    acl_free(txt);
-}
-#endif
-#endif
-
 static int getUidForName(const QString &name)
 {
     struct passwd *user = getpwnam(name.toLocal8Bit().constData());
@@ -497,7 +471,6 @@ bool KACL::KACLPrivate::setAllUsersOrGroups(const QList< QPair<QString, unsigned
     acl_t newACL = acl_dup(m_acl);
     acl_entry_t entry;
 
-//printACL( newACL, "Before cleaning: " );
     // clear user entries
     int ret = acl_get_entry(newACL, ACL_FIRST_ENTRY, &entry);
     while (ret == 1) {
@@ -512,7 +485,6 @@ bool KACL::KACLPrivate::setAllUsersOrGroups(const QList< QPair<QString, unsigned
             ret = acl_get_entry(newACL, ACL_NEXT_ENTRY, &entry);
         }
     }
-//printACL( newACL, "After cleaning out entries: " );
 
     // now add the entries from the list
     QList< QPair<QString, unsigned short> >::const_iterator it = list.constBegin();
@@ -531,7 +503,6 @@ bool KACL::KACLPrivate::setAllUsersOrGroups(const QList< QPair<QString, unsigned
         }
         ++it;
     }
-//printACL( newACL, "After adding entries: " );
     if (allIsWell && atLeastOneUserOrGroup) {
         // 23.1.1 of 1003.1e states that as soon as there is a named user or
         // named group entry, there needs to be a mask entry as well, so add
