@@ -1,23 +1,10 @@
-/* This file is part of the KDE project
-   Copyright (C) 2008 by Peter Penz <peter.penz@gmx.at>
-   Copyright (C) 2008 by George Goldberg <grundleborg@googlemail.com>
-   Copyright     2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2008 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2008 George Goldberg <grundleborg@googlemail.com>
+    SPDX-FileCopyrightText: 2009 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef KFILEITEMLISTPROPERTIES_H
@@ -39,7 +26,7 @@ class KFileItemList;
  *        KFileItem objects.
  *
  * Given a list of KFileItems, this class can determine (and cache) the common
- * mimetype for all items, whether all items are directories, whether all items
+ * MIME type for all items, whether all items are directories, whether all items
  * are readable, writable, etc.
  * As soon as one file item does not support a specific capability (read, write etc.),
  * it is marked as unsupported for all items.
@@ -124,12 +111,18 @@ public:
     bool isDirectory() const;
 
     /**
-     * @return the mimetype of all items, if they all have the same, otherwise empty
+     * @return Whether all items are files, as reported by KFileItem::isFile().
+     * @since 5.47
+     */
+    bool isFile() const;
+
+    /**
+     * @return the MIME type of all items, if they all have the same, otherwise an empty string
      */
     QString mimeType() const;
 
     /**
-     * @return the mimetype group (e.g. "text") of all items, if they all have the same, otherwise empty
+     * @return the MIME type group (e.g. "text") of all items, if they all have the same, otherwise an empty string
      */
     QString mimeGroup() const;
 
