@@ -1,21 +1,10 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
-   Copyright     2012 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2012 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kprotocolinfofactory_p.h"
@@ -26,7 +15,7 @@
 
 #include <QCoreApplication>
 #include <QDirIterator>
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 
 #include "kiocoredebug.h"
 
