@@ -1,22 +1,11 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2000- Waldo Bastain <bastain@kde.org>
-   Copyright (C) 2000- Dawit Alemayehu <adawit@kde.org>
-   Copyright (C) 2008 Jarosław Staniek <staniek@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2000 Waldo Bastain <bastain@kde.org>
+    SPDX-FileCopyrightText: 2000 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2008 Jarosław Staniek <staniek@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kprotocolmanager.h"
@@ -44,8 +33,9 @@
 #include <QDBusInterface>
 #include <QCache>
 #include <QLocale>
-#include <qstandardpaths.h>
-#include <qmimedatabase.h>
+#include <QRegularExpression>
+#include <QStandardPaths>
+#include <QMimeDatabase>
 
 #if !defined(QT_NO_NETWORKPROXY) && (defined (Q_OS_WIN32) || defined(Q_OS_MAC))
 #include <QNetworkProxyFactory>
@@ -53,10 +43,10 @@
 #endif
 
 #include <kio_version.h>
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
 
-#include <kmimetypetrader.h>
+#include <KMimeTypeTrader>
 #include <kprotocolinfofactory_p.h>
 
 #include "slaveconfig.h"
@@ -777,9 +767,9 @@ QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
 
     /*
        The following code attempts to determine the default user agent string
-       from the 'X-KDE-UA-DEFAULT-STRING' property of the desktop file
+       from the 'X-KDE-Default-UserAgent' property of the desktop file
        for the preferred service that was configured to handle the 'text/html'
-       mime type. If the preferred service's desktop file does not specify this
+       MIME type. If the preferred service's desktop file does not specify this
        property, the long standing default user agent string will be used.
        The following keyword placeholders are automatically converted when the
        user agent string is read from the property:
@@ -900,9 +890,9 @@ QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
 
             // Clean up unnecessary separators that could be left over from the
             // possible keyword removal above...
-            agentStr.replace(QRegExp(QL1S("[(]\\s*[;]\\s*")), QStringLiteral("("));
-            agentStr.replace(QRegExp(QL1S("[;]\\s*[;]\\s*")), QStringLiteral("; "));
-            agentStr.replace(QRegExp(QL1S("\\s*[;]\\s*[)]")), QStringLiteral(")"));
+            agentStr.replace(QRegularExpression(QStringLiteral("[(]\\s*[;]\\s*")), QStringLiteral("("));
+            agentStr.replace(QRegularExpression(QStringLiteral("[;]\\s*[;]\\s*")), QStringLiteral("; "));
+            agentStr.replace(QRegularExpression(QStringLiteral("\\s*[;]\\s*[)]")), QStringLiteral(")"));
         } else {
             agentStr.remove(QStringLiteral("%osname%"));
             agentStr.remove(QStringLiteral("%osversion%"));
@@ -1222,6 +1212,16 @@ bool KProtocolManager::supportsOpening(const QUrl &url)
     return prot->m_supportsOpening;
 }
 
+bool KProtocolManager::supportsTruncating(const QUrl &url)
+{
+    KProtocolInfoPrivate *prot = findProtocol(url);
+    if (!prot) {
+        return false;
+    }
+
+    return prot->m_supportsTruncating;
+}
+
 bool KProtocolManager::canCopyFromFile(const QUrl &url)
 {
     KProtocolInfoPrivate *prot = findProtocol(url);
