@@ -1,23 +1,13 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2000- Waldo Bastain <bastain@kde.org>
-   Copyright (C) 2000- Dawit Alemayehu <adawit@kde.org>
-   Copyright (C) 2008 Jarosław Staniek <staniek@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2000 Waldo Bastain <bastain@kde.org>
+    SPDX-FileCopyrightText: 2000 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2008 Jarosław Staniek <staniek@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
+
 #ifndef KPROTOCOLMANAGER_H
 #define KPROTOCOLMANAGER_H
 
@@ -566,12 +556,12 @@ public:
     static KProtocolInfo::FileNameUsedForCopying fileNameUsedForCopying(const QUrl &url);
 
     /**
-     * Returns default mimetype for this URL based on the protocol.
+     * Returns default MIME type for this URL based on the protocol.
      *
      * This corresponds to the "defaultMimetype=" field in the protocol description file.
      *
      * @param url the url to check
-     * @return the default mime type of the protocol, or null if unknown
+     * @return the default MIME type of the protocol, or an empty string if unknown
      */
     static QString defaultMimetype(const QUrl &url);
 
@@ -629,14 +619,14 @@ public:
     static bool isSourceProtocol(const QUrl &url);
 
     /**
-     * Returns which protocol handles this mimetype, if it's an archive mimetype.
+     * Returns which protocol handles this MIME type, if it's an archive MIME type.
      * For instance zip:/ handles application/x-zip.
      *
      * This is defined in the protocol description file using an entry like
      * "archiveMimetype=application/x-zip"
      *
-     * @param mimeType the mimetype to check
-     * @return the protocol that can handle this archive mimetype, for instance "zip".
+     * @param mimeType the MIME type to check
+     * @return the protocol that can handle this archive MIME type, for instance "zip".
      * @since 4.1
      */
     static QString protocolForArchiveMimetype(const QString &mimeType);
