@@ -1,20 +1,10 @@
-/* This file is part of the KDE project
-   Copyright (c) 2004 Jan Schaefer <j_schaef@informatik.uni-kl.de>
-   Copyright 2010 Rodrigo Belem <rclbelem@gmail.com>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 Jan Schaefer <j_schaef@informatik.uni-kl.de>
+    SPDX-FileCopyrightText: 2010 Rodrigo Belem <rclbelem@gmail.com>
+    SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "ksambashare.h"
@@ -25,19 +15,21 @@
 
 #include <QMap>
 #include <QFile>
+#include <QHostInfo>
 #include <QLoggingCategory>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QFileInfo>
 #include <QTextStream>
+#include <QStandardPaths>
 #include <QStringList>
 #include <QProcess>
 #include <QDebug>
 
-#include <kdirwatch.h>
-#include <kuser.h>
+#include <KDirWatch>
+#include <KUser>
 
 Q_DECLARE_LOGGING_CATEGORY(KIO_CORE_SAMBASHARE)
-Q_LOGGING_CATEGORY(KIO_CORE_SAMBASHARE, "kf5.kio.core.sambashare", QtWarningMsg)
+Q_LOGGING_CATEGORY(KIO_CORE_SAMBASHARE, "kf.kio.core.sambashare", QtWarningMsg)
 
 // Default smb.conf locations
 // sorted by priority, most priority first
@@ -54,12 +46,13 @@ static const char *const DefaultSambaConfigFilePathList[] = {
 KSambaSharePrivate::KSambaSharePrivate(KSambaShare *parent)
     : q_ptr(parent)
     , data()
-    , smbConf()
     , userSharePath()
     , skipUserShare(false)
 {
     setUserSharePath();
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 6)
     findSmbConf();
+#endif
     data = parse(getNetUserShareInfo());
 }
 
@@ -69,16 +62,22 @@ KSambaSharePrivate::~KSambaSharePrivate()
 
 bool KSambaSharePrivate::isSambaInstalled()
 {
-    if (QFile::exists(QStringLiteral("/usr/sbin/smbd"))
-            || QFile::exists(QStringLiteral("/usr/local/sbin/smbd"))) {
-        return true;
+    const bool daemonExists =
+        !QStandardPaths::findExecutable(QStringLiteral("smbd"),
+                                       {QStringLiteral("/usr/sbin/"), QStringLiteral("/usr/local/sbin/")}).isEmpty();
+    if (!daemonExists) {
+        qCDebug(KIO_CORE_SAMBASHARE) << "KSambaShare: Could not find smbd";
     }
 
-    //qDebug() << "Samba is not installed!";
+    const bool clientExists = !QStandardPaths::findExecutable(QStringLiteral("testparm")).isEmpty();
+    if (!clientExists) {
+        qCDebug(KIO_CORE_SAMBASHARE) << "KSambaShare: Could not find testparm tool, most likely samba-client isn't installed";
+    }
 
-    return false;
+    return daemonExists && clientExists;
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 6)
 // Try to find the samba config file path
 // in several well-known paths
 bool KSambaSharePrivate::findSmbConf()
@@ -95,6 +94,7 @@ bool KSambaSharePrivate::findSmbConf()
 
     return false;
 }
+#endif
 
 void KSambaSharePrivate::setUserSharePath()
 {
@@ -144,12 +144,33 @@ QString KSambaSharePrivate::testparmParamValue(const QString &parameterName)
     if (!stdErr.isEmpty()) {
         QList<QByteArray> err;
         err << stdErr.trimmed().split('\n');
-        if ((err.count() == 2)
-                && err.at(0).startsWith("Load smb config files from")
-                && err.at(1).startsWith("Loaded services file OK.")) {
-            //qDebug() << "Running testparm" << args;
-        } else {
-            qCWarning(KIO_CORE) << "We got some errors while running testparm" << stdErr;
+        // ignore first two lines
+        if (err.count() > 0 && err.at(0).startsWith("Load smb config files from")) {
+            err.removeFirst();
+        }
+        if (err.count() > 0 && err.at(0).startsWith("Loaded services file OK.")) {
+            err.removeFirst();
+        }
+        if (err.count() > 0 && err.at(0).startsWith("WARNING: The 'netbios name' is too long (max. 15 chars).")) {
+            // netbios name must be of at most 15 characters long
+            // means either netbios name is badly configured
+            // or not set and the default value is being used, it being "$(hostname)-W"
+            // which means any hostname longer than 13 characters will cause this warning
+            // when no netbios name was defined
+            // See https://www.novell.com/documentation/open-enterprise-server-2018/file_samba_cifs_lx/data/bc855e3.html
+            const QString defaultNetbiosName = QHostInfo::localHostName().append(QStringLiteral("-W"));
+            if (defaultNetbiosName.length() > 14) {
+                qCDebug(KIO_CORE) << "Your samba 'netbios name' parameter was longer than the authorized 15 characters.\n"
+                                    << "It may be because your hostname is longer than 13 and samba default 'netbios name' defaults to 'hostname-W', here:" << defaultNetbiosName<< "\n"
+                                    << "If that it is the case simply define a 'netbios name' parameter in /etc/samba/smb.conf at most 15 characters long";
+            } else {
+                qCDebug(KIO_CORE) << "Your samba 'netbios name' parameter was longer than the authorized 15 characters."
+                                    << "Please define a 'netbios name' parameter in /etc/samba/smb.conf at most 15 characters long";
+            }
+            err.removeFirst();
+        }
+        if (err.count() > 0) {
+            qCDebug(KIO_CORE) << "We got some errors while running testparm" << err.join("\n");
         }
     }
 
@@ -185,8 +206,8 @@ QByteArray KSambaSharePrivate::getNetUserShareInfo()
             //TODO: parse and process other error messages.
             // create a parser for the error output and
             // send error message somewhere
-            qCWarning(KIO_CORE) << "We got some errors while running 'net usershare info'";
-            qCWarning(KIO_CORE) << stdErr;
+            qCDebug(KIO_CORE) << "We got some errors while running 'net usershare info'";
+            qCDebug(KIO_CORE) << stdErr;
         }
     }
 
@@ -234,8 +255,8 @@ QList<KSambaShareData> KSambaSharePrivate::getSharesByPath(const QString &path)
 bool KSambaSharePrivate::isShareNameValid(const QString &name) const
 {
     // Samba forbidden chars
-    const QRegExp notToMatchRx(QStringLiteral("[%<>*\?|/\\+=;:\",]"));
-    return (notToMatchRx.indexIn(name) == -1);
+    const QRegularExpression notToMatchRx(QStringLiteral("[%<>*\?|/+=;:\",]"));
+    return !notToMatchRx.match(name).hasMatch();
 }
 
 bool KSambaSharePrivate::isDirectoryShared(const QString &path) const
@@ -253,7 +274,7 @@ bool KSambaSharePrivate::isDirectoryShared(const QString &path) const
 bool KSambaSharePrivate::isShareNameAvailable(const QString &name) const
 {
     // Samba does not allow to name a share with a user name registered in the system
-    return (!KUser::allUserNames().contains(name) || !data.contains(name));
+    return (!KUser::allUserNames().contains(name) && !data.contains(name));
 }
 
 KSambaShareData::UserShareError KSambaSharePrivate::isPathValid(const QString &path) const
@@ -287,20 +308,25 @@ KSambaShareData::UserShareError KSambaSharePrivate::isPathValid(const QString &p
 
 KSambaShareData::UserShareError KSambaSharePrivate::isAclValid(const QString &acl) const
 {
-    const QRegExp aclRx(QStringLiteral("(?:(?:(\\w(\\w|\\s)*)\\\\|)(\\w+\\s*):([fFrRd]{1})(?:,|))*"));
+    // NOTE: capital D is not missing from the regex net usershare will in fact refuse to consider it valid
+    //   - verified 2020-08-20
+    const QRegularExpression aclRx(QRegularExpression::anchoredPattern(
+                                    QStringLiteral("(?:(?:(\\w(\\w|\\s)*)\\\\|)(\\w+\\s*):([fFrRd]{1})(?:,|))*")));
     // TODO: check if user is a valid smb user
-    return aclRx.exactMatch(acl) ? KSambaShareData::UserShareAclOk
-           : KSambaShareData::UserShareAclInvalid;
+    return aclRx.match(acl).hasMatch() ? KSambaShareData::UserShareAclOk
+                                         : KSambaShareData::UserShareAclInvalid;
+}
+
+bool KSambaSharePrivate::areGuestsAllowed() const
+{
+    return KSambaSharePrivate::testparmParamValue(QStringLiteral("usershare allow guests")) != QLatin1String("No");
 }
 
 KSambaShareData::UserShareError KSambaSharePrivate::guestsAllowed(const
         KSambaShareData::GuestPermission &guestok) const
 {
-    if (guestok == KSambaShareData::GuestsAllowed) {
-        if (KSambaSharePrivate::testparmParamValue(QStringLiteral("usershare allow guests"))
-                == QLatin1String("No")) {
-            return KSambaShareData::UserShareGuestsNotAllowed;
-        }
+    if (guestok == KSambaShareData::GuestsAllowed && !areGuestsAllowed()) {
+        return KSambaShareData::UserShareGuestsNotAllowed;
     }
 
     return KSambaShareData::UserShareGuestsOk;
@@ -315,17 +341,10 @@ KSambaShareData::UserShareError KSambaSharePrivate::add(const KSambaShareData &s
         return KSambaShareData::UserShareSystemError;
     }
 
-    QByteArray stdOut;
-    QByteArray stdErr;
-
     if (data.contains(shareData.name())) {
         if (data.value(shareData.name()).path() != shareData.path()) {
             return KSambaShareData::UserShareNameInUse;
         }
-    } else {
-        // It needs to be added here, otherwise another instance of KSambaShareDataPrivate
-        // will be created and added to data.
-        data.insert(shareData.name(), shareData);
     }
 
     QString guestok = QStringLiteral("guest_ok=%1").arg(
@@ -342,20 +361,28 @@ KSambaShareData::UserShareError KSambaSharePrivate::add(const KSambaShareData &s
         guestok,
     };
 
-    int ret = runProcess(QStringLiteral("net"), args, stdOut, stdErr);
+    QByteArray stdOut;
+    int ret = runProcess(QStringLiteral("net"), args, stdOut, m_stdErr);
 
     //TODO: parse and process error messages.
-    if (!stdErr.isEmpty()) {
+    if (!m_stdErr.isEmpty()) {
         // create a parser for the error output and
         // send error message somewhere
         qCWarning(KIO_CORE) << "We got some errors while running 'net usershare add'" << args;
-        qCWarning(KIO_CORE) << stdErr;
+        qCWarning(KIO_CORE) << m_stdErr;
+    }
+
+    if (ret == 0 && !data.contains(shareData.name())) {
+        // It needs to be added in this function explicitly, otherwise another instance of
+        // KSambaShareDataPrivate will be created and added to data when the share
+        // definiton changes on-disk and we re-parse the data.
+        data.insert(shareData.name(), shareData);
     }
 
     return (ret == 0) ? KSambaShareData::UserShareOk : KSambaShareData::UserShareSystemError;
 }
 
-KSambaShareData::UserShareError KSambaSharePrivate::remove(const KSambaShareData &shareData) const
+KSambaShareData::UserShareError KSambaSharePrivate::remove(const KSambaShareData &shareData)
 {
     if (!isSambaInstalled()) {
         return KSambaShareData::UserShareSystemError;
@@ -372,19 +399,33 @@ KSambaShareData::UserShareError KSambaSharePrivate::remove(const KSambaShareData
         shareData.name(),
     };
 
-    int result = QProcess::execute(QStringLiteral("net"), args);
-    return (result == 0) ? KSambaShareData::UserShareOk : KSambaShareData::UserShareSystemError;
+    QByteArray stdOut;
+    int ret = runProcess(QStringLiteral("net"), args, stdOut, m_stdErr);
+
+    //TODO: parse and process error messages.
+    if (!m_stdErr.isEmpty()) {
+        // create a parser for the error output and
+        // send error message somewhere
+        qCWarning(KIO_CORE) << "We got some errors while running 'net usershare delete'" << args;
+        qCWarning(KIO_CORE) << m_stdErr;
+    }
+
+    return (ret == 0) ? KSambaShareData::UserShareOk : KSambaShareData::UserShareSystemError;
+
+    // NB: the share file gets deleted which leads us to reload and drop the ShareData, hence no explicit remove
 }
 
 QMap<QString, KSambaShareData> KSambaSharePrivate::parse(const QByteArray &usershareData)
 {
-    const QRegExp headerRx(QString::fromLatin1("^\\s*\\["
-                                         "([^%<>*\?|/\\+=;:\",]+)"
-                                         "\\]"));
+    const QRegularExpression headerRx(QRegularExpression::anchoredPattern(
+                                        QStringLiteral("^\\s*\\["
+                                                       "([^%<>*\?|/+=;:\",]+)"
+                                                       "\\]")));
 
-    const QRegExp OptValRx(QString::fromLatin1("^\\s*([\\w\\d\\s]+)"
-                                         "="
-                                         "(.*)$"));
+    const QRegularExpression OptValRx(QRegularExpression::anchoredPattern(
+                                        QStringLiteral("^\\s*([\\w\\d\\s]+)"
+                                                       "="
+                                                       "(.*)$")));
 
     QTextStream stream(usershareData);
     QString currentShare;
@@ -393,27 +434,24 @@ QMap<QString, KSambaShareData> KSambaSharePrivate::parse(const QByteArray &users
     while (!stream.atEnd()) {
         const QString line = stream.readLine().trimmed();
 
-        if (headerRx.exactMatch(line)) {
-            currentShare = headerRx.cap(1).trimmed();
+        QRegularExpressionMatch match;
+        if ((match = headerRx.match(line)).hasMatch()) {
+            currentShare = match.captured(1).trimmed();
 
             if (!shares.contains(currentShare)) {
                 KSambaShareData shareData;
                 shareData.dd->name = currentShare;
                 shares.insert(currentShare, shareData);
             }
-        } else if (OptValRx.exactMatch(line)) {
-            const QString key = OptValRx.cap(1).trimmed();
-            const QString value = OptValRx.cap(2).trimmed();
+        } else if ((match = OptValRx.match(line)).hasMatch()) {
+            const QString key = match.captured(1).trimmed();
+            const QString value = match.captured(2).trimmed();
             KSambaShareData shareData = shares[currentShare];
 
             if (key == QLatin1String("path")) {
                 // Samba accepts paths with and w/o trailing slash, we
                 // use and expect path without slash
-                if (value.endsWith(QLatin1Char('/'))) {
-                    shareData.dd->path = value.left(value.size() - 1);
-                } else {
-                    shareData.dd->path = value;
-                }
+                shareData.dd->path = value.endsWith(QLatin1Char('/')) ? value.chopped(1) : value;
             } else if (key == QLatin1String("comment")) {
                 shareData.dd->comment = value;
             } else if (key == QLatin1String("usershare_acl")) {
@@ -440,7 +478,7 @@ void KSambaSharePrivate::_k_slotFileChange(const QString &path)
         return;
     }
     data = parse(getNetUserShareInfo());
-    //qDebug() << "path changed:" << path;
+    qCDebug(KIO_CORE) << "reloading data; path changed:" << path;
     Q_Q(KSambaShare);
     emit q->changed();
 }
@@ -466,11 +504,13 @@ KSambaShare::~KSambaShare()
     delete d_ptr;
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 6)
 QString KSambaShare::smbConfPath() const
 {
     Q_D(const KSambaShare);
     return d->smbConf;
 }
+#endif
 
 bool KSambaShare::isDirectoryShared(const QString &path) const
 {
@@ -508,6 +548,18 @@ QList<KSambaShareData> KSambaShare::getSharesByPath(const QString &path) const
     return d->getSharesByPath(path);
 }
 
+QString KSambaShare::lastSystemErrorString() const
+{
+    Q_D(const KSambaShare);
+    return QString::fromUtf8(d->m_stdErr);
+}
+
+bool KSambaShare::areGuestsAllowed() const
+{
+    Q_D(const KSambaShare);
+    return d->areGuestsAllowed();
+}
+
 class KSambaShareSingleton
 {
 public:
