@@ -1,21 +1,10 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                      Waldo Bastian <bastian@kde.org>
-   Copyright (C) 2009, 2010 Andreas Hartmetz <ahartmetz@gmail.com>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2009, 2010 Andreas Hartmetz <ahartmetz@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "scheduler.h"
@@ -29,17 +18,14 @@
 
 #include <kprotocolmanager.h>
 #include <kprotocolinfo.h>
-//#include <kjobwidgets.h>
+//#include <KJobWidgets>
 
-#include <QtCore/QHash>
+#include <QHash>
 #include <QThread>
 #include <QThreadStorage>
-#include <QCoreApplication>
 #include <QDBusConnection>
 #include <QDBusMessage>
 
-#include <QDBusConnection>
-
 // Slaves may be idle for a certain time (3 minutes) before they are killed.
 static const int s_idleSlaveLifetime = 3 * 60;
 
@@ -63,7 +49,7 @@ static inline void startJob(SimpleJob *job, Slave *slave)
 // here be uglies
 // forward declaration to break cross-dependency of SlaveKeeper and SchedulerPrivate
 static void setupSlave(KIO::Slave *slave, const QUrl &url, const QString &protocol,
-                       const QStringList &proxyList, bool newSlave, const KIO::MetaData *config = 0);
+                       const QStringList &proxyList, bool newSlave, const KIO::MetaData *config = nullptr);
 // same reason as above
 static Scheduler *scheduler();
 static Slave *heldSlaveForJob(SimpleJob *job);
@@ -79,7 +65,7 @@ int SerialPicker::changedPrioritySerial(int oldSerial, int newPriority) const
 SlaveKeeper::SlaveKeeper()
 {
     m_grimTimer.setSingleShot(true);
-    connect(&m_grimTimer, SIGNAL(timeout()), SLOT(grimReaper()));
+    connect(&m_grimTimer, &QTimer::timeout, this, &SlaveKeeper::grimReaper);
 }
 
 SlaveKeeper::~SlaveKeeper()
@@ -109,7 +95,7 @@ Slave *SlaveKeeper::takeSlaveForJob(SimpleJob *job)
         it = m_idleSlaves.begin();
     }
     if (it == m_idleSlaves.end()) {
-        return 0;
+        return nullptr;
     }
     slave = it.value();
     m_idleSlaves.erase(it);
@@ -129,6 +115,11 @@ bool SlaveKeeper::removeSlave(Slave *slave)
     return false;
 }
 
+void SlaveKeeper::clear()
+{
+    m_idleSlaves.clear();
+}
+
 QList<Slave *> SlaveKeeper::allSlaves() const
 {
     return m_idleSlaves.values();
@@ -208,7 +199,8 @@ bool HostQueue::removeJob(SimpleJob *job)
 QList<Slave *> HostQueue::allSlaves() const
 {
     QList<Slave *> ret;
-    Q_FOREACH (SimpleJob *job, m_runningJobs) {
+    ret.reserve(m_runningJobs.size());
+    for (SimpleJob *job : m_runningJobs) {
         Slave *slave = jobSlave(job);
         Q_ASSERT(slave);
         ret.append(slave);
@@ -219,7 +211,7 @@ QList<Slave *> HostQueue::allSlaves() const
 ConnectedSlaveQueue::ConnectedSlaveQueue()
 {
     m_startJobsTimer.setSingleShot(true);
-    connect(&m_startJobsTimer, SIGNAL(timeout()), SLOT(startRunnableJobs()));
+    connect(&m_startJobsTimer, &QTimer::timeout, this, &ConnectedSlaveQueue::startRunnableJobs);
 }
 
 bool ConnectedSlaveQueue::queueJob(SimpleJob *job, Slave *slave)
@@ -258,7 +250,7 @@ bool ConnectedSlaveQueue::removeJob(SimpleJob *job)
     const bool removedRunning = jobs.runningJob == job;
     const bool removedWaiting = jobs.waitingList.removeAll(job) != 0;
     if (removedRunning) {
-        jobs.runningJob = 0;
+        jobs.runningJob = nullptr;
         Q_ASSERT(!removedWaiting);
     }
     const bool removedTheJob = removedRunning || removedWaiting;
@@ -293,7 +285,9 @@ bool ConnectedSlaveQueue::removeSlave(Slave *slave)
         return false;
     }
     PerSlaveQueue &jobs = it.value();
-    Q_FOREACH (SimpleJob *job, jobs.waitingList) {
+    // we need a copy as kill() ends up removing the job from waitingList
+    const QList <SimpleJob *> waitingJobs = jobs.waitingList;
+    for (SimpleJob *job : waitingJobs) {
         // ### for compatibility with the old scheduler we don't touch the running job, if any.
         // make sure that the job doesn't call back into Scheduler::cancelJob(); this would
         // a) crash and b) be unnecessary because we clean up just fine.
@@ -314,7 +308,7 @@ bool ConnectedSlaveQueue::isIdle(Slave *slave)
     if (it == m_connectedSlaves.end()) {
         return false;
     }
-    return it.value().runningJob == 0;
+    return it.value().runningJob == nullptr;
 }
 
 //private slot
@@ -359,9 +353,10 @@ static void ensureNoDuplicates(QMap<int, HostQueue *> *queuesBySerial)
 #ifdef SCHEDULER_DEBUG
     // a host queue may *never* be in queuesBySerial twice.
     QSet<HostQueue *> seen;
-    Q_FOREACH (HostQueue *hq, *queuesBySerial) {
-        Q_ASSERT(!seen.contains(hq));
-        seen.insert(hq);
+    auto it = queuesBySerial->cbegin();
+    for (; it != queuesBySerial->cend(); ++it) {
+        Q_ASSERT(!seen.contains(it.value()));
+        seen.insert(it.value());
     }
 #endif
 }
@@ -372,15 +367,17 @@ static void verifyRunningJobsCount(QHash<QString, HostQueue> *queues, int runnin
     Q_UNUSED(runningJobsCount);
 #ifdef SCHEDULER_DEBUG
     int realRunningJobsCount = 0;
-    Q_FOREACH (const HostQueue &hq, *queues) {
-        realRunningJobsCount += hq.runningJobsCount();
+    auto it = queues->cbegin();
+    for (; it != queues->cend(); ++it) {
+        realRunningJobsCount += it.value().runningJobsCount();
     }
     Q_ASSERT(realRunningJobsCount == runningJobsCount);
 
     // ...and of course we may never run the same job twice!
     QSet<SimpleJob *> seenJobs;
-    Q_FOREACH (const HostQueue &hq, *queues) {
-        Q_FOREACH (SimpleJob *job, hq.runningJobs()) {
+    auto it2 = queues->cbegin();
+    for (; it2 != queues->cend(); ++it2) {
+        for (SimpleJob *job : it2.value().runningJobs()) {
             Q_ASSERT(!seenJobs.contains(job));
             seenJobs.insert(job);
         }
@@ -399,12 +396,16 @@ ProtoQueue::ProtoQueue(int maxSlaves, int maxSlavesPerHost)
     Q_ASSERT(m_maxConnectionsPerHost >= 1);
     Q_ASSERT(maxSlaves >= maxSlavesPerHost);
     m_startJobTimer.setSingleShot(true);
-    connect(&m_startJobTimer, SIGNAL(timeout()), SLOT(startAJob()));
+    connect(&m_startJobTimer, &QTimer::timeout, this, &ProtoQueue::startAJob);
 }
 
 ProtoQueue::~ProtoQueue()
 {
-    Q_FOREACH (Slave *slave, allSlaves()) {
+    // Gather list of all slaves first
+    const QList<Slave *> slaves = allSlaves();
+    // Clear the idle slaves in the keeper to avoid dangling pointers
+    m_slaveKeeper.clear();
+    for (Slave *slave : slaves) {
         // kill the slave process, then remove the interface in our process
         slave->kill();
         slave->deref();
@@ -556,8 +557,9 @@ bool ProtoQueue::removeSlave(KIO::Slave *slave)
 QList<Slave *> ProtoQueue::allSlaves() const
 {
     QList<Slave *> ret(m_slaveKeeper.allSlaves());
-    Q_FOREACH (const HostQueue &hq, m_queuesByHostname) {
-        ret.append(hq.allSlaves());
+    auto it = m_queuesByHostname.cbegin();
+    for (; it != m_queuesByHostname.cend(); ++it) {
+        ret.append(it.value().allSlaves());
     }
     ret.append(m_connectedSlaveQueue.allSlaves());
     return ret;
@@ -571,8 +573,10 @@ void ProtoQueue::startAJob()
 
 #ifdef SCHEDULER_DEBUG
     //qDebug() << "m_runningJobsCount:" << m_runningJobsCount;
-    Q_FOREACH (const HostQueue &hq, m_queuesByHostname) {
-        Q_FOREACH (SimpleJob *job, hq.runningJobs()) {
+    auto it = m_queuesByHostname.cbegin();
+    for (; it != m_queuesByHostname.cend(); ++it) {
+        const QList<KIO::SimpleJob *> list = it.value().runningJobs();
+        for (SimpleJob *job : list) {
             //qDebug() << SimpleJobPrivate::get(job)->m_url;
         }
     }
@@ -650,7 +654,7 @@ class KIO::SchedulerPrivate
 public:
     SchedulerPrivate()
         : q(new Scheduler()),
-          m_slaveOnHold(0),
+          m_slaveOnHold(nullptr),
           m_checkOnHold(true), // !! Always check with KLauncher for the first request
           m_ignoreConfigReparse(false)
     {
@@ -659,14 +663,19 @@ public:
     ~SchedulerPrivate()
     {
         delete q;
-        q = 0;
-        Q_FOREACH (ProtoQueue *p, m_protocols) {
-            Q_FOREACH (Slave *slave, p->allSlaves()) {
+        q = nullptr;
+        for (ProtoQueue *p : qAsConst(m_protocols)) {
+            const QList<KIO::Slave *> list = p->allSlaves();
+            for (Slave *slave : list) {
                 slave->kill();
             }
         }
         qDeleteAll(m_protocols);
     }
+
+    SchedulerPrivate(const SchedulerPrivate &) = delete;
+    SchedulerPrivate &operator=(const SchedulerPrivate &) = delete;
+
     Scheduler *q;
 
     Slave *m_slaveOnHold;
@@ -677,7 +686,7 @@ public:
     SessionData sessionData;
 
     void doJob(SimpleJob *job);
-#ifndef KIOCORE_NO_DEPRECATED
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 5)
     void scheduleJob(SimpleJob *job);
 #endif
     void setJobPriority(SimpleJob *job, int priority);
@@ -696,7 +705,7 @@ public:
 
     MetaData metaDataFor(const QString &protocol, const QStringList &proxyList, const QUrl &url);
     void setupSlave(KIO::Slave *slave, const QUrl &url, const QString &protocol,
-                    const QStringList &proxyList, bool newSlave, const KIO::MetaData *config = 0);
+                    const QStringList &proxyList, bool newSlave, const KIO::MetaData *config = nullptr);
 
     void slotSlaveDied(KIO::Slave *slave);
     void slotSlaveStatus(qint64 pid, const QByteArray &protocol,
@@ -710,7 +719,7 @@ public:
 
     ProtoQueue *protoQ(const QString &protocol, const QString &host)
     {
-        ProtoQueue *pq = m_protocols.value(protocol, 0);
+        ProtoQueue *pq = m_protocols.value(protocol, nullptr);
         if (!pq) {
             //qDebug() << "creating ProtoQueue instance for" << protocol;
 
@@ -775,7 +784,7 @@ Scheduler::Scheduler()
     const QString dbusInterface = QStringLiteral("org.kde.KIO.Scheduler");
     QDBusConnection dbus = QDBusConnection::sessionBus();
     // Not needed, right? We just want to emit two signals.
-    //dbus.registerObject("/KIO/Scheduler", this, QDBusConnection::ExportScriptableSlots |
+    //dbus.registerObject(dbusPath, this, QDBusConnection::ExportScriptableSlots |
     //                    QDBusConnection::ExportScriptableSignals);
     dbus.connect(QString(), dbusPath, dbusInterface, QStringLiteral("reparseSlaveConfiguration"),
                  this, SLOT(slotReparseSlaveConfiguration(QString,QDBusMessage)));
@@ -792,7 +801,7 @@ void Scheduler::doJob(SimpleJob *job)
     schedulerPrivate()->doJob(job);
 }
 
-#ifndef KIOCORE_NO_DEPRECATED
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 5)
 void Scheduler::scheduleJob(SimpleJob *job)
 {
     schedulerPrivate()->scheduleJob(job);
@@ -910,14 +919,21 @@ void SchedulerPrivate::slotReparseSlaveConfiguration(const QString &proto, const
 
     QHash<QString, ProtoQueue *>::ConstIterator it = proto.isEmpty() ? m_protocols.constBegin() :
             m_protocols.constFind(proto);
+    QHash<QString, ProtoQueue *>::ConstIterator endIt = m_protocols.constEnd();
+
     // not found?
-    if (it == m_protocols.constEnd()) {
+    if (it == endIt) {
         return;
     }
-    QHash<QString, ProtoQueue *>::ConstIterator endIt = proto.isEmpty() ? m_protocols.constEnd() :
-            it + 1;
+
+    if (!proto.isEmpty()) {
+        endIt = it;
+        ++endIt;
+    }
+
     for (; it != endIt; ++it) {
-        Q_FOREACH (Slave *slave, (*it)->allSlaves()) {
+        const QList<KIO::Slave *> list = it.value()->allSlaves();
+        for (Slave *slave : list) {
             slave->send(CMD_REPARSECONFIGURATION);
             slave->resetHost();
         }
@@ -962,7 +978,7 @@ void SchedulerPrivate::doJob(SimpleJob *job)
     proto->queueJob(job);
 }
 
-#ifndef KIOCORE_NO_DEPRECATED
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 5)
 void SchedulerPrivate::scheduleJob(SimpleJob *job)
 {
     //qDebug() << job;
@@ -973,8 +989,11 @@ void SchedulerPrivate::scheduleJob(SimpleJob *job)
 void SchedulerPrivate::setJobPriority(SimpleJob *job, int priority)
 {
     //qDebug() << job << priority;
-    ProtoQueue *proto = protoQ(SimpleJobPrivate::get(job)->m_protocol, job->url().host());
-    proto->changeJobPriority(job, priority);
+    const QString protocol = SimpleJobPrivate::get(job)->m_protocol;
+    if (!protocol.isEmpty()) {
+        ProtoQueue *proto = protoQ(SimpleJobPrivate::get(job)->m_protocol, job->url().host());
+        proto->changeJobPriority(job, priority);
+    }
 }
 
 void SchedulerPrivate::cancelJob(SimpleJob *job)
@@ -1025,11 +1044,11 @@ void SchedulerPrivate::jobFinished(SimpleJob *job, Slave *slave)
                 }
             }
         }
-        slave->setJob(0);
+        slave->setJob(nullptr);
         slave->disconnect(job);
     }
     jobPriv->m_schedSerial = 0; // this marks the job as unscheduled again
-    jobPriv->m_slave = 0;
+    jobPriv->m_slave = nullptr;
     // Clear the values in the internal metadata container since they have
     // already been taken care of above...
     jobPriv->m_internalMetaData.clear();
@@ -1052,10 +1071,10 @@ MetaData SchedulerPrivate::metaDataFor(const QString &protocol, const QStringLis
         configData.remove(QStringLiteral("ProxyUrls"));
     } else {
         configData[QStringLiteral("UseProxy")] = proxyList.first();
-        configData[QStringLiteral("ProxyUrls")] = proxyList.join(QStringLiteral(","));
+        configData[QStringLiteral("ProxyUrls")] = proxyList.join(QLatin1Char(','));
     }
 
-    if (configData.contains(QStringLiteral("EnableAutoLogin")) &&
+    if (configData.contains(QLatin1String("EnableAutoLogin")) &&
             configData.value(QStringLiteral("EnableAutoLogin")).compare(QLatin1String("true"), Qt::CaseInsensitive) == 0) {
         NetRC::AutoLogin l;
         l.login = url.userName();
@@ -1067,7 +1086,7 @@ MetaData SchedulerPrivate::metaDataFor(const QString &protocol, const QStringLis
                 QString macdef;
                 QMap<QString, QStringList>::ConstIterator it = l.macdef.constBegin();
                 for (; it != l.macdef.constEnd(); ++it) {
-                    macdef += it.key() + '\\' + it.value().join(QStringLiteral("\\")) + '\n';
+                    macdef += it.key() + QLatin1Char('\\') + it.value().join(QLatin1Char('\\')) + QLatin1Char('\n');
                 }
                 configData[QStringLiteral("autoLoginMacro")] = macdef;
             }
@@ -1120,10 +1139,12 @@ void SchedulerPrivate::slotSlaveDied(KIO::Slave *slave)
         pq->removeSlave(slave);
     }
     if (slave == m_slaveOnHold) {
-        m_slaveOnHold = 0;
+        m_slaveOnHold = nullptr;
         m_urlOnHold.clear();
     }
-    slave->deref(); // Delete slave
+    // can't use slave->deref() here because we need to use deleteLater
+    slave->aboutToDelete();
+    slave->deleteLater();
 }
 
 void SchedulerPrivate::putSlaveOnHold(KIO::SimpleJob *job, const QUrl &url)
@@ -1133,8 +1154,8 @@ void SchedulerPrivate::putSlaveOnHold(KIO::SimpleJob *job, const QUrl &url)
     slave->disconnect(job);
     // prevent the fake death of the slave from trying to kill the job again;
     // cf. Slave::hold(const QUrl &url) called in SchedulerPrivate::publishSlaveOnHold().
-    slave->setJob(0);
-    SimpleJobPrivate::get(job)->m_slave = 0;
+    slave->setJob(nullptr);
+    SimpleJobPrivate::get(job)->m_slave = nullptr;
 
     if (m_slaveOnHold) {
         m_slaveOnHold->kill();
@@ -1166,7 +1187,7 @@ bool SchedulerPrivate::isSlaveOnHoldFor(const QUrl &url)
 
 Slave *SchedulerPrivate::heldSlaveForJob(SimpleJob *job)
 {
-    Slave *slave = 0;
+    Slave *slave = nullptr;
     KIO::SimpleJobPrivate *const jobPriv = SimpleJobPrivate::get(job);
 
     if (jobPriv->m_checkOnHold) {
@@ -1185,7 +1206,7 @@ Slave *SchedulerPrivate::heldSlaveForJob(SimpleJob *job)
                 const QString resume = outgoing.value(QStringLiteral("resume"));
                 const QString rangeStart = outgoing.value(QStringLiteral("range-start"));
                 //qDebug() << "Resume metadata is" << resume;
-                canJobReuse = (resume.isEmpty() || resume == QLatin1String("0")) && (rangeStart.isEmpty() || rangeStart == QLatin1String("0"));
+                canJobReuse = (resume.isEmpty() || resume == QLatin1Char('0')) && (rangeStart.isEmpty() || rangeStart == QLatin1Char('0'));
             }
         }
 
@@ -1197,7 +1218,7 @@ Slave *SchedulerPrivate::heldSlaveForJob(SimpleJob *job)
                 //qDebug() << "HOLD: Discarding held slave (" << m_slaveOnHold << ")";
                 m_slaveOnHold->kill();
             }
-            m_slaveOnHold = 0;
+            m_slaveOnHold = nullptr;
             m_urlOnHold.clear();
         }
     } else if (slave) {
@@ -1213,7 +1234,7 @@ void SchedulerPrivate::removeSlaveOnHold()
     if (m_slaveOnHold) {
         m_slaveOnHold->kill();
     }
-    m_slaveOnHold = 0;
+    m_slaveOnHold = nullptr;
     m_urlOnHold.clear();
 }
 
@@ -1223,7 +1244,7 @@ Slave *SchedulerPrivate::getConnectedSlave(const QUrl &url, const KIO::MetaData
     const QString protocol = KProtocolManager::slaveProtocol(url, proxyList);
     ProtoQueue *pq = protoQ(protocol, url.host());
 
-    Slave *slave = pq->createSlave(protocol, /* job */0, url);
+    Slave *slave = pq->createSlave(protocol, /* job */nullptr, url);
     if (slave) {
         setupSlave(slave, url, protocol, proxyList, true, &config);
         pq->m_connectedSlaveQueue.addSlave(slave);
