@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2000 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef __kio_slaveinterface_h
@@ -22,8 +10,8 @@
 
 #include <qplatformdefs.h>
 
-#include <QtCore/QObject>
-#include <QtNetwork/QHostInfo>
+#include <QObject>
+#include <QHostInfo>
 
 #include <kio/global.h>
 #include <kio/udsentry.h>
@@ -51,13 +39,18 @@ enum Info {
     INF_MIME_TYPE = 21,
     INF_ERROR_PAGE = 22,
     INF_WARNING = 23,
-    INF_GETTING_FILE, ///< @deprecated
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(3, 0)
+    INF_GETTING_FILE, ///< @deprecated Since 3.0
+#else
+    INF_GETTING_FILE_DEPRECATED_DO_NOT_USE,
+#endif
     INF_UNUSED = 25, ///< now unused
     INF_INFOMESSAGE,
     INF_META_DATA,
     INF_NETWORK_STATUS,
     INF_MESSAGEBOX,
-    INF_POSITION
+    INF_POSITION,
+    INF_TRUNCATED
     // add new ones here once a release is done, to avoid breaking binary compatibility
 };
 
@@ -74,18 +67,28 @@ enum Message {
     MSG_LIST_ENTRIES,
     MSG_RENAMED, ///< unused
     MSG_RESUME,
-    MSG_SLAVE_STATUS,
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 45)
+    MSG_SLAVE_STATUS, ///< @deprecated Since 5.45, use MSG_SLAVE_STATUS_V2
+#else
+    MSG_SLAVE_STATUS_DEPRECATED_DO_NOT_USE,
+#endif
     MSG_SLAVE_ACK, // 110
     MSG_NET_REQUEST,
     MSG_NET_DROP,
     MSG_NEED_SUBURL_DATA,
     MSG_CANRESUME,
-    MSG_AUTH_KEY, ///< @deprecated
-    MSG_DEL_AUTH_KEY, ///< @deprecated
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(3, 1)
+    MSG_AUTH_KEY, ///< @deprecated Since 3.1
+    MSG_DEL_AUTH_KEY, ///< @deprecated Since 3.1
+#else
+    MSG_AUTH_KEY_DEPRECATED_DO_NOT_USE,
+    MSG_DEL_AUTH_KEY_DEPRECATED_DO_NOT_USE,
+#endif
     MSG_OPENED,
     MSG_WRITTEN,
     MSG_HOST_INFO_REQ,
-    MSG_PRIVILEGE_EXEC
+    MSG_PRIVILEGE_EXEC,
+    MSG_SLAVE_STATUS_V2
     // add new ones here once a release is done, to avoid breaking binary compatibility
 };
 
@@ -108,8 +111,13 @@ public:
 
     virtual ~SlaveInterface();
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
+    // TODO KF6: remove these methods, Connection isn't an exported class
+    KIOCORE_DEPRECATED_VERSION(5, 0, "Do not use")
     void setConnection(Connection *connection);
+    KIOCORE_DEPRECATED_VERSION(5, 0, "Do not use")
     Connection *connection() const;
+#endif
 
     // Send our answer to the MSG_RESUME (canResume) request
     // (to tell the "put" job whether to resume or not)
@@ -144,6 +152,7 @@ Q_SIGNALS:
 
     void open();
     void written(KIO::filesize_t);
+    void close();
 
     void privilegeOperationRequested();
 
@@ -155,6 +164,7 @@ Q_SIGNALS:
     void processedSize(KIO::filesize_t);
     void redirection(const QUrl &);
     void position(KIO::filesize_t);
+    void truncated(KIO::filesize_t);
 
     void speed(unsigned long);
     void errorPage();
