@@ -1,27 +1,17 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "job_p.h"
 #include "statjob.h"
+
+#include "job_p.h"
 #include "slave.h"
 #include "scheduler.h"
+#include <KProtocolInfo>
 #include <kurlauthorized.h>
 #include <QTimer>
 
@@ -31,13 +21,13 @@ class KIO::StatJobPrivate: public SimpleJobPrivate
 {
 public:
     inline StatJobPrivate(const QUrl &url, int command, const QByteArray &packedArgs)
-        : SimpleJobPrivate(url, command, packedArgs), m_bSource(true), m_details(2)
+        : SimpleJobPrivate(url, command, packedArgs), m_bSource(true), m_details(KIO::StatDefaultDetails)
     {}
 
     UDSEntry m_statResult;
     QUrl m_redirectionURL;
     bool m_bSource;
-    short int m_details;
+    KIO::StatDetails m_details;
     void slotStatEntry(const KIO::UDSEntry &entry);
     void slotRedirection(const QUrl &url);
 
@@ -47,7 +37,7 @@ public:
      * work on this job.
      * @param slave the slave that starts working on this job
      */
-    void start(Slave *slave) Q_DECL_OVERRIDE;
+    void start(Slave *slave) override;
 
     Q_DECLARE_PUBLIC(StatJob)
 
@@ -73,7 +63,7 @@ StatJob::~StatJob()
 {
 }
 
-#ifndef KIOCORE_NO_DEPRECATED
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
 void StatJob::setSide(bool source)
 {
     d_func()->m_bSource = source;
@@ -85,11 +75,39 @@ void StatJob::setSide(StatSide side)
     d_func()->m_bSource = side == SourceSide;
 }
 
-void StatJob::setDetails(short int details)
+void StatJob::setDetails(KIO::StatDetails details)
 {
     d_func()->m_details = details;
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
+void StatJob::setDetails(short int details)
+{
+    // for backward compatibility
+    d_func()->m_details = detailsToStatDetails(details);
+}
+
+void StatJob::setDetails(KIO::StatDetail detail)
+{
+    d_func()->m_details = detail;
+}
+
+KIO::StatDetails KIO::detailsToStatDetails(int details)
+{
+    KIO::StatDetails detailsFlag = KIO::StatBasic;
+    if (details > 0) {
+        detailsFlag |= KIO::StatUser | KIO::StatTime;
+    }
+    if (details > 1) {
+         detailsFlag |= KIO::StatResolveSymlink | KIO::StatAcl;
+    }
+    if (details > 2) {
+        detailsFlag |= KIO::StatInode;
+    }
+    return detailsFlag;
+}
+#endif
+
 const UDSEntry &StatJob::statResult() const
 {
     return d_func()->m_statResult;
@@ -97,21 +115,35 @@ const UDSEntry &StatJob::statResult() const
 
 QUrl StatJob::mostLocalUrl() const
 {
-    if (!url().isLocalFile()) {
-        const UDSEntry &udsEntry = d_func()->m_statResult;
-        const QString path = udsEntry.stringValue(KIO::UDSEntry::UDS_LOCAL_PATH);
-        if (!path.isEmpty()) {
-            return QUrl::fromLocalFile(path);
-        }
+    const QUrl _url = url();
+
+    if (_url.isLocalFile()) {
+        return _url;
     }
-    return url();
+
+    const UDSEntry &udsEntry = d_func()->m_statResult;
+    const QString path = udsEntry.stringValue(KIO::UDSEntry::UDS_LOCAL_PATH);
+
+    if (path.isEmpty()) { // Return url as-is
+        return _url;
+    }
+
+    const QString protoClass = KProtocolInfo::protocolClass(_url.scheme());
+    if (protoClass != QLatin1String(":local")) { // UDS_LOCAL_PATH was set but wrong Class
+        qCWarning(KIO_CORE) << "The protocol Class of the url that was being stat'ed" << _url << ", is" << protoClass
+                            << ", however UDS_LOCAL_PATH was set; if you use UDS_LOCAL_PATH, the protocolClass"
+                               " should be :local, see KProtocolInfo API docs for more details.";
+        return _url;
+    }
+
+    return QUrl::fromLocalFile(path);
 }
 
 void StatJobPrivate::start(Slave *slave)
 {
     Q_Q(StatJob);
     m_outgoingMetaData.insert(QStringLiteral("statSide"), m_bSource ? QStringLiteral("source") : QStringLiteral("dest"));
-    m_outgoingMetaData.insert(QStringLiteral("details"), QString::number(m_details));
+    m_outgoingMetaData.insert(QStringLiteral("statDetails"), QString::number(m_details));
 
     q->connect(slave, SIGNAL(statEntry(KIO::UDSEntry)),
                SLOT(slotStatEntry(KIO::UDSEntry)));
@@ -177,20 +209,40 @@ void StatJob::slotMetaData(const KIO::MetaData &_metaData)
 StatJob *KIO::stat(const QUrl &url, JobFlags flags)
 {
     // Assume sideIsSource. Gets are more common than puts.
-    return stat(url, StatJob::SourceSide, 2, flags);
+    return statDetails(url, StatJob::SourceSide, KIO::StatDefaultDetails, flags);
+}
+
+static bool isUrlValid(const QUrl &url)
+{
+    if (!url.isValid()) {
+        qCWarning(KIO_CORE) << "Invalid url:" << url << ", cancelling job.";
+        return false;
+    }
+
+    if (url.isLocalFile()) {
+        qCWarning(KIO_CORE) << "Url" << url << "already represents a local file, cancelling job.";
+        return false;
+    }
+
+    if (KProtocolInfo::protocolClass(url.scheme()) != QLatin1String(":local")) {
+        qCWarning(KIO_CORE) << "Protocol Class of url" << url << ", isn't ':local', cancelling job.";
+        return false;
+    }
+
+    return true;
 }
 
 StatJob *KIO::mostLocalUrl(const QUrl &url, JobFlags flags)
 {
-    StatJob *job = stat(url, StatJob::SourceSide, 2, flags);
-    if (url.isLocalFile()) {
-        QTimer::singleShot(0, job, SLOT(slotFinished()));
+    StatJob *job = statDetails(url, StatJob::SourceSide, KIO::StatDefaultDetails, flags);
+    if (!isUrlValid(url)) {
+        QTimer::singleShot(0, job, &StatJob::slotFinished);
         Scheduler::cancelJob(job); // deletes the slave if not 0
     }
     return job;
 }
 
-#ifndef KIOCORE_NO_DEPRECATED
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
 StatJob *KIO::stat(const QUrl &url, bool sideIsSource, short int details, JobFlags flags)
 {
     //qCDebug(KIO_CORE) << "stat" << url;
@@ -202,6 +254,18 @@ StatJob *KIO::stat(const QUrl &url, bool sideIsSource, short int details, JobFla
 }
 #endif
 
+StatJob *KIO::statDetails(const QUrl &url, KIO::StatJob::StatSide side, KIO::StatDetails details, JobFlags flags)
+{
+    // TODO KF6: rename to stat
+    //qCDebug(KIO_CORE) << "stat" << url;
+    KIO_ARGS << url;
+    StatJob *job = StatJobPrivate::newJob(url, CMD_STAT, packedArgs, flags);
+    job->setSide(side);
+    job->setDetails(details);
+    return job;
+}
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
 StatJob *KIO::stat(const QUrl &url, KIO::StatJob::StatSide side, short int details, JobFlags flags)
 {
     //qCDebug(KIO_CORE) << "stat" << url;
@@ -211,5 +275,6 @@ StatJob *KIO::stat(const QUrl &url, KIO::StatJob::StatSide side, short int detai
     job->setDetails(details);
     return job;
 }
+#endif
 
 #include "moc_statjob.cpp"
