@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2013 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2013 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "transferjob.h"
@@ -129,7 +117,6 @@ void TransferJob::slotFinished()
             }
             d->m_internalSuspended = false;
             // The very tricky part is the packed arguments business
-            QString dummyStr;
             QUrl dummyUrl;
             QDataStream istream(d->m_packedArgs);
             switch (d->m_command) {
@@ -186,7 +173,9 @@ void TransferJob::sendAsyncData(const QByteArray &dataForSlave)
 {
     Q_D(TransferJob);
     if (d->m_extraFlags & JobPrivate::EF_TransferJobNeedData) {
-        d->m_slave->send(MSG_DATA, dataForSlave);
+        if (d->m_slave) {
+            d->m_slave->send(MSG_DATA, dataForSlave);
+        }
         if (d->m_extraFlags & JobPrivate::EF_TransferJobDataSent) { // put job -> emit progress
             KIO::filesize_t size = processedAmount(KJob::Bytes) + dataForSlave.size();
             setProcessedAmount(KJob::Bytes, size);
@@ -196,7 +185,7 @@ void TransferJob::sendAsyncData(const QByteArray &dataForSlave)
     d->m_extraFlags &= ~JobPrivate::EF_TransferJobNeedData;
 }
 
-#ifndef KIOCORE_NO_DEPRECATED
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 3)
 void TransferJob::setReportDataSent(bool enabled)
 {
     Q_D(TransferJob);
@@ -208,7 +197,7 @@ void TransferJob::setReportDataSent(bool enabled)
 }
 #endif
 
-#ifndef KIOCORE_NO_DEPRECATED
+#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 3)
 bool TransferJob::reportDataSent() const
 {
     return (d_func()->m_extraFlags & JobPrivate::EF_TransferJobDataSent);
@@ -268,7 +257,10 @@ void TransferJob::slotMimetype(const QString &type)
         qCWarning(KIO_CORE) << "mimetype() emitted again, or after sending first data!; job URL =" << d->m_url;
     }
     d->m_isMimetypeEmitted = true;
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 78)
     emit mimetype(this, type);
+#endif
+    emit mimeTypeFound(this, type);
 }
 
 void TransferJobPrivate::internalSuspend()
@@ -309,13 +301,14 @@ void TransferJobPrivate::start(Slave *slave)
     Q_Q(TransferJob);
     Q_ASSERT(slave);
     JobPrivate::emitTransferring(q, m_url);
-    q->connect(slave, SIGNAL(data(QByteArray)),
-               SLOT(slotData(QByteArray)));
+    q->connect(slave, &SlaveInterface::data,
+               q, &TransferJob::slotData);
 
     if (m_outgoingDataSource) {
         if (m_extraFlags & JobPrivate::EF_TransferJobAsync) {
-            q->connect(m_outgoingDataSource, SIGNAL(readyRead()),
-                    SLOT(slotDataReqFromDevice()));
+            q->connect(m_outgoingDataSource, &QIODevice::readyRead, q, [this]() {
+                slotDataReqFromDevice();
+            });
             q->connect(m_outgoingDataSource, SIGNAL(readChannelFinished()),
                     SLOT(slotIODeviceClosed()));
             // We don't really need to disconnect since we're never checking
@@ -328,27 +321,31 @@ void TransferJobPrivate::start(Slave *slave)
                 QMetaObject::invokeMethod(q, "slotDataReqFromDevice", Qt::QueuedConnection);
             }
         } else {
-            q->connect(slave, SIGNAL(dataReq()),
-                    SLOT(slotDataReqFromDevice()));
+            q->connect(slave, &SlaveInterface::dataReq, q, [this]() {
+                slotDataReqFromDevice();
+            });
         }
     } else
-        q->connect(slave, SIGNAL(dataReq()),
-                   SLOT(slotDataReq()));
+        q->connect(slave, &SlaveInterface::dataReq,
+                   q, &TransferJob::slotDataReq);
 
-    q->connect(slave, SIGNAL(redirection(QUrl)),
-               SLOT(slotRedirection(QUrl)));
+    q->connect(slave, &SlaveInterface::redirection,
+               q, &TransferJob::slotRedirection);
 
-    q->connect(slave, SIGNAL(mimeType(QString)),
-               SLOT(slotMimetype(QString)));
+    q->connect(slave, &SlaveInterface::mimeType,
+               q, &TransferJob::slotMimetype);
 
-    q->connect(slave, SIGNAL(errorPage()),
-               SLOT(slotErrorPage()));
+    q->connect(slave, &SlaveInterface::errorPage, q, [this]() {
+        m_errorPage = true;
+    });
 
-    q->connect(slave, SIGNAL(needSubUrlData()),
-               SLOT(slotNeedSubUrlData()));
+    q->connect(slave, &SlaveInterface::needSubUrlData, q, [this]() {
+        slotNeedSubUrlData();
+    });
 
-    q->connect(slave, SIGNAL(canResume(KIO::filesize_t)),
-               SLOT(slotCanResume(KIO::filesize_t)));
+    q->connect(slave, &SlaveInterface::canResume, q, [q](KIO::filesize_t offset) {
+        emit q->canResume(q, offset);
+    });
 
     if (slave->suspended()) {
         m_mimetype = QStringLiteral("unknown");
@@ -368,8 +365,9 @@ void TransferJobPrivate::slotNeedSubUrlData()
     // Job needs data from subURL.
     m_subJob = KIO::get(m_subUrl, NoReload, HideProgressInfo);
     internalSuspend(); // Put job on hold until we have some data.
-    q->connect(m_subJob, SIGNAL(data(KIO::Job*,QByteArray)),
-               SLOT(slotSubUrlData(KIO::Job*,QByteArray)));
+    q->connect(m_subJob, &TransferJob::data, q, [this](KIO::Job *job, const QByteArray &data) {
+        slotSubUrlData(job, data);
+    });
     q->addSubjob(m_subJob);
 }
 
@@ -388,17 +386,6 @@ void TransferJob::slotMetaData(const KIO::MetaData &_metaData)
     storeSSLSessionFromJob(d->m_redirectionURL);
 }
 
-void TransferJobPrivate::slotErrorPage()
-{
-    m_errorPage = true;
-}
-
-void TransferJobPrivate::slotCanResume(KIO::filesize_t offset)
-{
-    Q_Q(TransferJob);
-    emit q->canResume(q, offset);
-}
-
 void TransferJobPrivate::slotDataReqFromDevice()
 {
     Q_Q(TransferJob);
