@@ -1,22 +1,10 @@
 // -*- c++ -*-
-/* This file is part of the KDE libraries
-    Copyright (C) 1999 Stephan Kulow <coolo@kde.org>
-    2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef KDIROPERATOR_H_
 #define KDIROPERATOR_H_
@@ -25,8 +13,8 @@
 #include <QStack>
 #include <QStyleOptionViewItem>
 
-#include <ktoggleaction.h>
-#include <kcompletion.h>
+#include <KToggleAction>
+#include <KCompletion>
 #include <kdirlister.h>
 #include <kfileitem.h>
 #include <kfile.h>
@@ -49,6 +37,8 @@ class CopyJob;
 class DeleteJob;
 }
 
+class KDirOperatorPrivate;
+
 /**
  * @class KDirOperator kdiroperator.h <KDirOperator>
  *
@@ -161,7 +151,7 @@ public:
     QString nameFilter() const;
 
     /**
-     * Sets a list of mimetypes as filter. Only files of those mimetypes
+     * Sets a list of MIME types as filter. Only files of those MIME types
      * will be shown.
      *
      * Example:
@@ -171,7 +161,7 @@ public:
      * dirOperator->setMimefilter( filter );
      * \endcode
      *
-     * Node: Without the mimetype inode/directory, only files would be shown.
+     * Node: Without the MIME type inode/directory, only files would be shown.
      * Call updateDir() to apply it.
      *
      * @see KDirLister::setMimeFilter
@@ -180,14 +170,14 @@ public:
     void setMimeFilter(const QStringList &mimetypes);
 
     /**
-     * @returns the current mime filter.
+     * @returns the current MIME type filter.
      */
     QStringList mimeFilter() const;
 
     /**
-     * Only show the files in a given set of mimetypes.
+     * Only show the files in a given set of MIME types.
      * This is useful in specialized applications (while file managers, on
-     * the other hand, want to show all mimetypes). Internally uses
+     * the other hand, want to show all MIME types). Internally uses
      * KNewFileMenu::setSupportedMimeTypes
      *
      * Example:
@@ -198,7 +188,7 @@ public:
      * \endcode
      *
      * Note: If the list is empty, all options will be shown. Otherwise,
-     * without the mimetype inode/directory, only file options will be shown.
+     * without the MIME type inode/directory, only file options will be shown.
      *
      * @see KNewFileMenu::setSupportedMimeTypes
      * @see newFileMenuSupportedMimeTypes
@@ -213,7 +203,14 @@ public:
     QStringList newFileMenuSupportedMimeTypes() const;
 
     /**
-     * Clears both the namefilter and mimetype filter, so that all files and
+     * Setting this to true will make a directory get selected when trying to create a new one that has the same name.
+     *
+     * @since 5.76
+     */
+    void setNewFileMenuSelectDirWhenAlreadyExist(bool selectOnDirExists);
+
+    /**
+     * Clears both the namefilter and MIME type filter, so that all files and
      * directories will be shown. Call updateDir() to apply it.
      *
      * @see setMimeFilter
@@ -518,6 +515,7 @@ public:
      */
     bool followSelectedDirectories() const;
 
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(5, 78)
     /**
      * Creates the given directory/url. If it is a relative path,
      * it will be completed with the current directory.
@@ -526,7 +524,10 @@ public:
      * to the user.
      * @returns true if the directory could be created.
      */
+    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 78, "Deprecated for lack of usage; use the other"
+                                             " KDirOperator::mkdir() method instead.")
     virtual bool mkdir(const QString &directory, bool enterDirectory = true);
+#endif
 
     /**
      * Starts and returns a KIO::DeleteJob to delete the given @p items.
@@ -545,21 +546,26 @@ public:
     void clearHistory();
 
     /**
-     * When going up in the directory hierarchy, KDirOperator can highlight
-     * the directory that was just left.
+     * When using the up or back actions to navigate the directory hierarchy, KDirOperator
+     * can highlight the directory that was just left.
      *
-     * I.e. when you go from /home/gis/src to /home/gis, the item "src" will
-     * be made the current item.
+     * For example:
+     *  - starting in /a/b/c/, going up to /a/b, "c" will be highlighted
+     *  - starting in /a/b/c, going up (twice) to /a, "b" will be highlighted;
+     *    using the back action to go to /a/b/, "c" will be highlighted
+     *  - starting in /a, going to "b", then going to "c", using the back action
+     *    to go to /a/b/, "c" will be highlighted; using the back action again to go
+     *    to /a/, "b" will be highlighted
      *
-     * Default is off.
+     * @see dirHighlighting. The default is to highlight directories when going back/up.
      */
     virtual void setEnableDirHighlighting(bool enable);
 
     /**
      * @returns whether the last directory will be made the current item
-     * when going up in the directory hierarchy.
+     * (and hence highlighted) when going up or back in the directory hierarchy
      *
-     * Default is false.
+     * Directories are highlighted by default.
      */
     bool dirHighlighting() const;
 
@@ -634,11 +640,22 @@ public:
      */
     bool isInlinePreviewShown() const;
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 76)
     /**
      * Returns the icon zoom.
      * @since 4.2
      */
+    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 76, "Use KDirOperator::iconSize()")
     int iconsZoom() const;
+#endif
+
+    /**
+     * Returns the icon size in pixels, ranged from KIconLoader::SizeSmall (16) to
+     * KIconLoader::SizeEnormous (128).
+     *
+     * @since 5.76
+     */
+    int iconSize() const;
 
     /**
      * If the system is set up to trigger items on single click, if @p isSaving
@@ -794,6 +811,13 @@ public Q_SLOTS:
      */
     QString makeDirCompletion(const QString &);
 
+    /**
+     * Initiates a rename operation on the currently selected files/directories,
+     * prompting the user to choose a new name(s) for the currently selected items
+     * @since 5.67
+     */
+    void renameSelected();
+
     /**
      * Trashes the currently selected files/directories.
      *
@@ -805,12 +829,23 @@ public Q_SLOTS:
      */
     virtual void trashSelected();
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 76)
     /**
      * Notifies that the icons size should change. @p value is an int ranged from 0 to 100.
      * 100 means KIconLoader::SizeEnormous.
      * @since 4.2
      */
+    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 76, "Use KDirOperator::setIconSize(int)")
     void setIconsZoom(int value);
+#endif
+
+    /**
+     * Notifies that the icons size should change. @p value is the icon size in pixels, ranged
+     * from KIconLoader::SizeSmall (16) to KIconLoader::SizeEnormous (128).
+     *
+     * @since 5.76
+     */
+    void setIconSize(int value);
 
     /**
      * Set the URL schemes that the file widget should allow navigating to.
@@ -947,47 +982,8 @@ Q_SIGNALS:
     void keyEnterReturnPressed();
 
 private:
-    class Private;
-    Private *const d;
-
-    Q_PRIVATE_SLOT(d, void _k_slotDetailedView())
-    Q_PRIVATE_SLOT(d, void _k_slotSimpleView())
-    Q_PRIVATE_SLOT(d, void _k_slotTreeView())
-    Q_PRIVATE_SLOT(d, void _k_slotDetailedTreeView())
-    Q_PRIVATE_SLOT(d, void _k_slotToggleAllowExpansion(bool))
-    Q_PRIVATE_SLOT(d, void _k_slotToggleHidden(bool))
-    Q_PRIVATE_SLOT(d, void _k_togglePreview(bool))
-    Q_PRIVATE_SLOT(d, void _k_toggleInlinePreviews(bool))
-    Q_PRIVATE_SLOT(d, void _k_slotOpenFileManager())
-    Q_PRIVATE_SLOT(d, void _k_slotSortByName())
-    Q_PRIVATE_SLOT(d, void _k_slotSortBySize())
-    Q_PRIVATE_SLOT(d, void _k_slotSortByDate())
-    Q_PRIVATE_SLOT(d, void _k_slotSortByType())
-    Q_PRIVATE_SLOT(d, void _k_slotSortReversed(bool))
-    Q_PRIVATE_SLOT(d, void _k_slotToggleDirsFirst())
-    Q_PRIVATE_SLOT(d, void _k_slotIconsView())
-    Q_PRIVATE_SLOT(d, void _k_slotCompactView())
-    Q_PRIVATE_SLOT(d, void _k_slotDetailsView())
-    Q_PRIVATE_SLOT(d, void _k_slotToggleIgnoreCase())
-    Q_PRIVATE_SLOT(d, void _k_slotStarted())
-    Q_PRIVATE_SLOT(d, void _k_slotProgress(int))
-    Q_PRIVATE_SLOT(d, void _k_slotShowProgress())
-    Q_PRIVATE_SLOT(d, void _k_slotIOFinished())
-    Q_PRIVATE_SLOT(d, void _k_slotCanceled())
-    Q_PRIVATE_SLOT(d, void _k_slotRedirected(const QUrl &))
-    Q_PRIVATE_SLOT(d, void _k_slotProperties())
-    Q_PRIVATE_SLOT(d, void _k_slotActivated(const QModelIndex &))
-    Q_PRIVATE_SLOT(d, void _k_slotSelectionChanged())
-    Q_PRIVATE_SLOT(d, void _k_openContextMenu(const QPoint &))
-    Q_PRIVATE_SLOT(d, void _k_triggerPreview(const QModelIndex &))
-    Q_PRIVATE_SLOT(d, void _k_showPreview())
-    Q_PRIVATE_SLOT(d, void _k_slotSplitterMoved(int, int))
-    Q_PRIVATE_SLOT(d, void _k_assureVisibleSelection())
-    Q_PRIVATE_SLOT(d, void _k_synchronizeSortingState(int, Qt::SortOrder))
-    Q_PRIVATE_SLOT(d, void _k_slotChangeDecorationPosition())
-    Q_PRIVATE_SLOT(d, void _k_slotExpandToUrl(const QModelIndex &))
-    Q_PRIVATE_SLOT(d, void _k_slotItemsChanged())
-    Q_PRIVATE_SLOT(d, void _k_slotDirectoryCreated(const QUrl &))
+    friend class KDirOperatorPrivate;
+    std::unique_ptr<KDirOperatorPrivate> d;
 };
 
 #endif
