@@ -1,23 +1,11 @@
 // -*- c++ -*-
-/* This file is part of the KDE libraries
-    Copyright (C) 2003 Joseph Wenninger <jowenn@kde.org>
-                  2003 Andras Mantia <amantia@freemail.hu>
-                  2013 Teo Mrnjavac <teo@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2003 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2003 Andras Mantia <amantia@freemail.hu>
+    SPDX-FileCopyrightText: 2013 Teo Mrnjavac <teo@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef __KENCODINGFILEDIALOG_H__
@@ -30,6 +18,8 @@
 struct KEncodingFileDialogPrivate;
 
 /**
+ * @class KEncodingFileDialog kencodingfiledialog.h <KEncodingFileDialog>
+ *
  * Provides a user (and developer) friendly way to select files with support for
  * choosing encoding.
  * This class comes with a private constructor, the only way to show a file dialog
@@ -68,8 +58,8 @@ public:
      *         @li '::&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
-     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     * @param filter A shell glob or a MIME type filter that specifies which files to display.
+     *    The preferred option is to set a list of MIME type names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
@@ -100,8 +90,8 @@ public:
      *         @li '::&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
-     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     * @param filter A shell glob or a MIME type filter that specifies which files to display.
+     *    The preferred option is to set a list of MIME type names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
@@ -132,8 +122,8 @@ public:
      *         @li '::&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
-     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     * @param filter A shell glob or a MIME type filter that specifies which files to display.
+     *    The preferred option is to set a list of MIME type names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
@@ -164,8 +154,8 @@ public:
      *         @li '::&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
-     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     * @param filter A shell glob or a MIME type filter that specifies which files to display.
+     *    The preferred option is to set a list of MIME type names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
@@ -198,8 +188,8 @@ public:
      *         @li '::&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
-     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     * @param filter A shell glob or a MIME type filter that specifies which files to display.
+     *    The preferred option is to set a list of MIME type names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
@@ -232,8 +222,8 @@ public:
      *         @li '::&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in any application that specified the
      *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
-     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     * @param filter A shell glob or a MIME type filter that specifies which files to display.
+     *    The preferred option is to set a list of MIME type names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
@@ -245,13 +235,13 @@ public:
             QWidget *parent = nullptr,
             const QString &caption = QString());
 
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
 protected:
-    void hideEvent(QHideEvent *e) Q_DECL_OVERRIDE;
+    void hideEvent(QHideEvent *e) override;
 
 private Q_SLOTS:
-    void accept() Q_DECL_OVERRIDE;
+    void accept() override;
 
     void slotOk();
     void slotCancel();
@@ -275,8 +265,8 @@ private:
      * @param encoding The encoding shown in the encoding combo. If it's
      *          QString(), the global default encoding will be shown.
      *
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
-     *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
+     * @param filter A shell glob or a MIME type filter that specifies which files to display.
+     *    The preferred option is to set a list of MIME type names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      *
