@@ -1,20 +1,7 @@
-/* Copyright 2008, 2009, 2015 David Faure <faure@kde.org>
+/*
+    SPDX-FileCopyrightText: 2008, 2009, 2015 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "kfilecopytomenu.h"
@@ -120,7 +107,8 @@ void KFileCopyToMainMenu::slotAboutToShow()
     act = addMenu(subMenu);
     act->setObjectName(QStringLiteral("root"));
 #else
-    foreach (const QFileInfo &info, QDir::drives()) {
+    const QFileInfoList drives = QDir::drives();
+    for (const QFileInfo &info : drives) {
         QString driveIcon = QStringLiteral("drive-harddisk");
         const uint type = GetDriveTypeW((wchar_t *)info.absoluteFilePath().utf16());
         switch (type) {
@@ -210,7 +198,9 @@ void KFileCopyToMainMenu::copyOrMoveTo(const QUrl &dest)
     KIO::CopyJob *job = m_menuType == Copy ? KIO::copy(d->m_urls, dirDest) : KIO::move(d->m_urls, dirDest);
     KIO::FileUndoManager::self()->recordCopyJob(job);
     KJobWidgets::setWindow(job, d->m_parentWidget ? d->m_parentWidget : this);
-    job->uiDelegate()->setAutoErrorHandlingEnabled(d->m_autoErrorHandling);
+    if (job->uiDelegate()) {
+        job->uiDelegate()->setAutoErrorHandlingEnabled(d->m_autoErrorHandling);
+    }
     connect(job, &KIO::CopyJob::result, this, [this](KJob * job) {
         emit d->q->error(job->error(), job->errorString());
     });
