@@ -1,35 +1,24 @@
-/* This file is part of the KDE libraries
-    Copyright (C) Stephan Kulow <coolo@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: Stephan Kulow <coolo@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kfilefiltercombo.h"
+#include "kfilefiltercombo_debug.h"
 
 #include <QDebug>
-#include <klocalizedstring.h>
-#include <qmimedatabase.h>
+#include <KLocalizedString>
+#include <QMimeDatabase>
 #include <config-kiofilewidgets.h>
-#include <QtCore/QEvent>
+#include <QEvent>
 #include <QLineEdit>
 
 class Q_DECL_HIDDEN KFileFilterCombo::Private
 {
 public:
-    Private(KFileFilterCombo *_parent)
+    explicit Private(KFileFilterCombo *_parent)
         : parent(_parent),
           hasAllSupportedFiles(false),
           isMimeFilter(false),
@@ -39,7 +28,7 @@ public:
 
     void _k_slotFilterChanged();
 
-    KFileFilterCombo *parent;
+    KFileFilterCombo * const parent;
     // when we have more than 3 mimefilters and no default-filter,
     // we don't show the comments of all mimefilters in one line,
     // instead we show "All supported files". We have to translate
@@ -59,8 +48,8 @@ KFileFilterCombo::KFileFilterCombo(QWidget *parent)
 {
     setTrapReturnKey(true);
     setInsertPolicy(QComboBox::NoInsert);
-    connect(this, SIGNAL(activated(int)), this, SIGNAL(filterChanged()));
-    connect(this, SIGNAL(returnPressed()), this, SIGNAL(filterChanged()));
+    connect(this, QOverload<int>::of(&QComboBox::activated), this, &KFileFilterCombo::filterChanged);
+    connect(this, QOverload<>::of(&KComboBox::returnPressed), this, &KFileFilterCombo::filterChanged);
     connect(this, SIGNAL(filterChanged()), SLOT(_k_slotFilterChanged()));
     d->m_allTypes = false;
 }
@@ -78,11 +67,11 @@ void KFileFilterCombo::setFilter(const QString &filter)
 
     if (!filter.isEmpty()) {
         QString tmp = filter;
-        int index = tmp.indexOf('\n');
+        int index = tmp.indexOf(QLatin1Char('\n'));
         while (index > 0) {
             d->m_filters.append(tmp.left(index));
-            tmp = tmp.mid(index + 1);
-            index = tmp.indexOf('\n');
+            tmp.remove(0, index + 1);
+            index = tmp.indexOf(QLatin1Char('\n'));
         }
         d->m_filters.append(tmp);
     } else {
@@ -92,7 +81,7 @@ void KFileFilterCombo::setFilter(const QString &filter)
     QStringList::ConstIterator it;
     QStringList::ConstIterator end(d->m_filters.constEnd());
     for (it = d->m_filters.constBegin(); it != end; ++it) {
-        int tab = (*it).indexOf('|');
+        int tab = (*it).indexOf(QLatin1Char('|'));
         addItem((tab < 0) ? *it :
                 (*it).mid(tab + 1));
     }
@@ -107,11 +96,11 @@ QString KFileFilterCombo::currentFilter() const
     if (f == itemText(currentIndex())) { // user didn't edit the text
         f = d->m_filters.value(currentIndex());
         if (d->isMimeFilter || (currentIndex() == 0 && d->hasAllSupportedFiles)) {
-            return f; // we have a mimetype as filter
+            return f; // we have a MIME type as filter
         }
     }
 
-    int tab = f.indexOf('|');
+    int tab = f.indexOf(QLatin1Char('|'));
     if (tab < 0) {
         return f;
     } else {
@@ -132,7 +121,7 @@ QStringList KFileFilterCombo::filters() const
 void KFileFilterCombo::setCurrentFilter(const QString &filter)
 {
     setCurrentIndex(d->m_filters.indexOf(filter));
-    filterChanged();
+    emit filterChanged();
 }
 
 void KFileFilterCombo::setMimeFilter(const QStringList &types,
@@ -148,18 +137,36 @@ void KFileFilterCombo::setMimeFilter(const QStringList &types,
     d->m_allTypes = defaultType.isEmpty() && (types.count() > 1);
 
     QString allComments, allTypes;
+
+    // If there's MIME types that have the same comment, we will show the extension
+    // in addition to the MIME type comment
+    QHash<QString, int> allTypeComments;
+    for (QStringList::ConstIterator it = types.begin(); it != types.end(); ++it) {
+        const QMimeType type = db.mimeTypeForName(*it);
+        if (!type.isValid()) {
+            qCWarning(KIO_KFILEWIDGETS_KFILEFILTERCOMBO) << *it << "is not a valid MIME type";
+            continue;
+        }
+
+        allTypeComments[type.comment()] += 1;
+    }
+
     for (QStringList::ConstIterator it = types.begin(); it != types.end(); ++it) {
         // qDebug() << *it;
-        QMimeType type = db.mimeTypeForName(*it);
+        const QMimeType type = db.mimeTypeForName(*it);
+        if (!type.isValid()) {
+            qCWarning(KIO_KFILEWIDGETS_KFILEFILTERCOMBO) << *it << "is not a valid MIME type";
+            continue;
+        }
 
-        if (type.name().startsWith(QLatin1String("all/"))) {
+        if (type.name().startsWith(QLatin1String("all/")) || type.isDefault()) {
             hasAllFilesFilter = true;
             continue;
         }
 
         if (d->m_allTypes && it != types.begin()) {
             allComments += delim;
-            allTypes += ' ';
+            allTypes += QLatin1Char(' ');
         }
 
         d->m_filters.append(type.name());
@@ -167,14 +174,22 @@ void KFileFilterCombo::setMimeFilter(const QStringList &types,
             allTypes += type.name();
             allComments += type.comment();
         }
-        addItem(type.comment());
+        if (allTypeComments.value(type.comment()) > 1) {
+            addItem(i18nc("%1 is the mimetype name, %2 is the extensions", "%1 (%2)", type.comment(), type.suffixes().join(QStringLiteral(", "))));
+        } else {
+            addItem(type.comment());
+        }
         if (type.name() == defaultType) {
             setCurrentIndex(count() - 1);
         }
     }
 
+    if (count() == 1) {
+        d->m_allTypes = false;
+    }
+
     if (d->m_allTypes) {
-        if (count() <= 3) { // show the mime-comments of at max 3 types
+        if (count() <= 3) { // show the MIME type comments of at max 3 types
             insertItem(0, allComments);
         } else {
             insertItem(0, i18n("All Supported Files"));
