@@ -1,20 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2001,2002,2003 Carsten Pfeiffer <pfeiffer@kde.org>
-    Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2001, 2002, 2003 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
 
-    library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation, version 2.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KFILEPLACEEDITDIALOG_H
@@ -24,7 +13,7 @@
 
 #include <QDialog>
 #include <QUrl>
-#include <kiconloader.h>
+#include <KIconLoader>
 
 class QCheckBox;
 class QDialogButtonBox;
