@@ -1,20 +1,8 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KFILEPLACESITEM_P_H
@@ -24,7 +12,7 @@
 #include <QPointer>
 #include <QStringList>
 #include <QUrl>
-#include <kbookmark.h>
+#include <KBookmark>
 #include <solid/device.h>
 #include "kfileplacesmodel.h"
 
@@ -81,7 +69,8 @@ public:
                                           const char *translationContext,
                                           const QByteArray &untranslatedLabel,
                                           const QUrl &url,
-                                          const QString &iconName);
+                                          const QString &iconName,
+                                          const KBookmark &after = KBookmark());
     static KBookmark createDeviceBookmark(KBookmarkManager *manager,
                                           const QString &udi);
     static KBookmark createTagBookmark(KBookmarkManager *manager,
@@ -113,7 +102,7 @@ private:
     QPointer<Solid::StorageVolume> m_volume;
     QPointer<Solid::StorageDrive> m_drive;
     QPointer<Solid::OpticalDisc> m_disc;
-    QPointer<Solid::PortableMediaPlayer> m_mtp;
+    QPointer<Solid::PortableMediaPlayer> m_player;
     QPointer<Solid::NetworkShare> m_networkShare;
     QString m_iconPath;
     QStringList m_emblems;
