@@ -1,21 +1,9 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
-    Copyright (C) 2007 David Faure <faure@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kfileplacesmodel.h"
@@ -32,23 +20,22 @@
 #include <QTimer>
 #include <QFile>
 #include <QAction>
-#include <qmimedatabase.h>
+#include <QMimeDatabase>
 
 #include <kfileitem.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QDebug>
-#include <kurlmimedata.h>
+#include <KUrlMimeData>
 
-#include <kbookmarkmanager.h>
-#include <kbookmark.h>
+#include <KBookmarkManager>
 
 #include <kio/job.h>
 #include <kprotocolinfo.h>
 #include <KCoreDirLister>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 
 #include <solid/devicenotifier.h>
 #include <solid/storageaccess.h>
@@ -58,7 +45,7 @@
 #include <solid/opticaldisc.h>
 #include <solid/portablemediaplayer.h>
 #include <solid/predicate.h>
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 
 namespace {
     QString stateNameForGroupType(KFilePlacesModel::GroupType type)
@@ -260,6 +247,8 @@ KBookmark KFilePlacesModel::bookmarkForUrl(const QUrl &searchUrl) const
     return KBookmark();
 }
 
+static inline QString versionKey() { return QStringLiteral("kde_places_version"); }
+
 KFilePlacesModel::KFilePlacesModel(const QString &alternativeApplicationName, QObject *parent)
     : QAbstractItemModel(parent), d(new Private(this))
 {
@@ -274,51 +263,142 @@ KFilePlacesModel::KFilePlacesModel(const QString &alternativeApplicationName, QO
         root.setMetaDataItem(stateNameForGroupType(type), QStringLiteral("false"));
     };
 
-    if (root.first().isNull() || !QFile::exists(file)) {
-        // NOTE: The context for these I18NC_NOOP calls has to be "KFile System Bookmarks".
-        // The real i18nc call is made later, with this context, so the two must match.
-        // createSystemBookmark actually does nothing with its second argument, the context,
-        KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                              I18NC_NOOP("KFile System Bookmarks", "Home"),
-                                              QUrl::fromLocalFile(QDir::homePath()), QStringLiteral("user-home"));
+    // Increase this version number and use the following logic to handle the update process for existing installations.
+    static const int s_currentVersion = 4;
 
-        // Some distros may not create various standard XDG folders by default
-        // so check for their existence before adding bookmarks for them
-        const QString desktopFolder = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
-        if (QDir(desktopFolder).exists()) {
-            KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                                I18NC_NOOP("KFile System Bookmarks", "Desktop"),
-                                                QUrl::fromLocalFile(desktopFolder), QStringLiteral("user-desktop"));
-        }
-        const QString documentsFolder = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
-        if (QDir(documentsFolder).exists()) {
-            KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                                I18NC_NOOP("KFile System Bookmarks", "Documents"),
-                                                QUrl::fromLocalFile(documentsFolder), QStringLiteral("folder-documents"));
-        }
-        const QString downloadFolder = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
-        if (QDir(downloadFolder).exists()) {
-            KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                                I18NC_NOOP("KFile System Bookmarks", "Downloads"),
-                                                QUrl::fromLocalFile(downloadFolder), QStringLiteral("folder-downloads"));
+    const bool newFile = root.first().isNull() || !QFile::exists(file);
+    const int fileVersion = root.metaDataItem(versionKey()).toInt();
+
+    if (newFile || fileVersion < s_currentVersion) {
+        root.setMetaDataItem(versionKey(), QString::number(s_currentVersion));
+
+        const QList<QUrl> seenUrls = root.groupUrlList();
+
+        auto createSystemBookmark = [this, &seenUrls](const char *translationContext,
+                const QByteArray &untranslatedLabel,
+                const QUrl &url,
+                const QString &iconName,
+                const KBookmark &after) {
+            if (!seenUrls.contains(url)) {
+                return KFilePlacesItem::createSystemBookmark(d->bookmarkManager, translationContext, untranslatedLabel, url, iconName, after);
+            }
+            return KBookmark();
+        };
+
+        if (fileVersion < 2) {
+            // NOTE: The context for these I18NC_NOOP calls has to be "KFile System Bookmarks".
+            // The real i18nc call is made later, with this context, so the two must match.
+            // createSystemBookmark actually does nothing with its second argument, the context.
+            createSystemBookmark(I18NC_NOOP("KFile System Bookmarks", "Home"),
+                                 QUrl::fromLocalFile(QDir::homePath()), QStringLiteral("user-home"), KBookmark());
+
+            // Some distros may not create various standard XDG folders by default
+            // so check for their existence before adding bookmarks for them
+            const QString desktopFolder = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+            if (QDir(desktopFolder).exists()) {
+                createSystemBookmark(I18NC_NOOP("KFile System Bookmarks", "Desktop"),
+                                     QUrl::fromLocalFile(desktopFolder), QStringLiteral("user-desktop"), KBookmark());
+            }
+            const QString documentsFolder = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+            if (QDir(documentsFolder).exists()) {
+                createSystemBookmark(I18NC_NOOP("KFile System Bookmarks", "Documents"),
+                                     QUrl::fromLocalFile(documentsFolder), QStringLiteral("folder-documents"), KBookmark());
+            }
+            const QString downloadFolder = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
+            if (QDir(downloadFolder).exists()) {
+                createSystemBookmark(I18NC_NOOP("KFile System Bookmarks", "Downloads"),
+                                     QUrl::fromLocalFile(downloadFolder), QStringLiteral("folder-downloads"), KBookmark());
+            }
+            createSystemBookmark(I18NC_NOOP("KFile System Bookmarks", "Network"),
+                                 QUrl(QStringLiteral("remote:/")), QStringLiteral("folder-network"), KBookmark());
+
+            createSystemBookmark(I18NC_NOOP("KFile System Bookmarks", "Trash"),
+                                 QUrl(QStringLiteral("trash:/")), QStringLiteral("user-trash"), KBookmark());
         }
 
-        KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                              I18NC_NOOP("KFile System Bookmarks", "Network"),
-                                              QUrl(QStringLiteral("remote:/")), QStringLiteral("folder-network"));
+        if (!newFile && fileVersion < 3) {
+            KBookmarkGroup root = d->bookmarkManager->root();
+            KBookmark bItem = root.first();
+            while (!bItem.isNull()) {
+                KBookmark nextbItem = root.next(bItem);
+                const bool isSystemItem = bItem.metaDataItem(QStringLiteral("isSystemItem")) == QLatin1String("true");
+                if (isSystemItem) {
+                    const QString text = bItem.fullText();
+                    // Because of b8a4c2223453932202397d812a0c6b30c6186c70 we need to find the system bookmark named Audio Files
+                    // and rename it to Audio, otherwise users are getting untranslated strings
+                    if (text == QLatin1String("Audio Files")) {
+                        bItem.setFullText(QStringLiteral("Audio"));
+                    } else if (text == QLatin1String("Today")) {
+                        // Because of 19feef732085b444515da3f6c66f3352bbcb1824 we need to find the system bookmark named Today
+                        // and rename it to Modified Today, otherwise users are getting untranslated strings
+                        bItem.setFullText(QStringLiteral("Modified Today"));
+                    } else if (text == QLatin1String("Yesterday")) {
+                        // Because of 19feef732085b444515da3f6c66f3352bbcb1824 we need to find the system bookmark named Yesterday
+                        // and rename it to Modified Yesterday, otherwise users are getting untranslated strings
+                        bItem.setFullText(QStringLiteral("Modified Yesterday"));
+                    } else if (text == QLatin1String("This Month")) {
+                        // Because of 7e1d2fb84546506c91684dd222c2485f0783848f we need to find the system bookmark named This Month
+                        // and remove it, otherwise users are getting untranslated strings
+                        root.deleteBookmark(bItem);
+                    } else if (text == QLatin1String("Last Month")) {
+                        // Because of 7e1d2fb84546506c91684dd222c2485f0783848f we need to find the system bookmark named Last Month
+                        // and remove it, otherwise users are getting untranslated strings
+                        root.deleteBookmark(bItem);
+                    }
+                }
 
-        KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                              I18NC_NOOP("KFile System Bookmarks", "Trash"),
-                                              QUrl(QStringLiteral("trash:/")), QStringLiteral("user-trash"));
+                bItem = nextbItem;
+            }
+        }
+        if (fileVersion < 4) {
+            auto findSystemBookmark = [this](const QString &untranslatedText) {
+                KBookmarkGroup root = d->bookmarkManager->root();
+                KBookmark bItem = root.first();
+                while (!bItem.isNull()) {
+                    const bool isSystemItem = bItem.metaDataItem(QStringLiteral("isSystemItem")) == QLatin1String("true");
+                    if (isSystemItem && bItem.fullText() == untranslatedText) {
+                        return bItem;
+                    }
+                    bItem = root.next(bItem);
+                }
+                return KBookmark();
+            };
+            // This variable is used to insert the new bookmarks at the correct place starting after the "Downloads"
+            // bookmark. When the user already has some of the bookmarks set up manually, the createSystemBookmark()
+            // function returns an empty KBookmark so the following entries will be added at the end of the bookmark
+            // section to not mess with the users setup.
+            KBookmark after = findSystemBookmark(QLatin1String("Downloads"));
 
-        setDefaultMetadataItemForGroup(PlacesType);
-        setDefaultMetadataItemForGroup(RemoteType);
-        setDefaultMetadataItemForGroup(DevicesType);
-        setDefaultMetadataItemForGroup(RemovableDevicesType);
-        setDefaultMetadataItemForGroup(TagsType);
+            const QString musicFolder = QStandardPaths::writableLocation(QStandardPaths::MusicLocation);
+            if (QDir(musicFolder).exists()) {
+                after = createSystemBookmark(I18NC_NOOP("KFile System Bookmarks", "Music"),
+                                             QUrl::fromLocalFile(musicFolder), QStringLiteral("folder-music"), after);
+            }
+            const QString pictureFolder = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
+            if (QDir(pictureFolder).exists()) {
+                after = createSystemBookmark(I18NC_NOOP("KFile System Bookmarks", "Pictures"),
+                                             QUrl::fromLocalFile(pictureFolder), QStringLiteral("folder-pictures"), after);
+            }
+            // Choosing the name "Videos" instead of "Movies", since that is how the folder
+            // is called normally on Linux: https://cgit.freedesktop.org/xdg/xdg-user-dirs/tree/user-dirs.defaults
+            const QString videoFolder = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation);
+            if (QDir(videoFolder).exists()) {
+                after = createSystemBookmark(I18NC_NOOP("KFile System Bookmarks", "Videos"),
+                                             QUrl::fromLocalFile(videoFolder), QStringLiteral("folder-videos"), after);
+            }
+
+        }
+
+        if (newFile) {
+            setDefaultMetadataItemForGroup(PlacesType);
+            setDefaultMetadataItemForGroup(RemoteType);
+            setDefaultMetadataItemForGroup(DevicesType);
+            setDefaultMetadataItemForGroup(RemovableDevicesType);
+            setDefaultMetadataItemForGroup(TagsType);
+        }
 
         // Force bookmarks to be saved. If on open/save dialog and the bookmarks are not saved, QFile::exists
-        // will always return false, which opening/closing all the time the open/save dialog would case the
+        // will always return false, which opening/closing all the time the open/save dialog would cause the
         // bookmarks to be added once each time, having lots of times each bookmark. (ereslibre)
         d->bookmarkManager->saveAs(file);
     }
@@ -451,7 +531,7 @@ bool KFilePlacesModel::isHidden(const QModelIndex &index) const
 bool KFilePlacesModel::isGroupHidden(const GroupType type) const
 {
     const QString hidden = d->bookmarkManager->root().metaDataItem(stateNameForGroupType(type));
-    return hidden == QLatin1String("true") ? true : false;
+    return hidden == QLatin1String("true");
 }
 
 bool KFilePlacesModel::isGroupHidden(const QModelIndex &index) const
@@ -587,6 +667,11 @@ QModelIndex KFilePlacesModel::closestItem(const QUrl &url) const
     // which covers the bigger range of the URL.
     for (int row = 0; row < d->items.size(); ++row) {
         KFilePlacesItem *item = d->items[row];
+
+        if (item->isHidden()) {
+            continue;
+        }
+
         const QUrl itemUrl(item->data(UrlRole).toUrl());
 
         if (itemUrl.matches(url, QUrl::StripTrailingSlash) || itemUrl.isParentOf(url)) {
@@ -697,7 +782,7 @@ void KFilePlacesModel::Private::_k_reloadBookmarks()
             }
             ++it_i;
             ++it_c;
-        } else if ((*it_i)->id() != (*it_c)->id()) {
+        } else {
             int row = items.indexOf(*it_i);
 
             if (it_i + 1 != end_i && (*(it_i + 1))->id() == (*it_c)->id()) { // if the next one matches, it's a remove
@@ -877,10 +962,10 @@ Qt::DropActions KFilePlacesModel::supportedDropActions() const
 
 Qt::ItemFlags KFilePlacesModel::flags(const QModelIndex &index) const
 {
-    Qt::ItemFlags res = Qt::ItemIsSelectable | Qt::ItemIsEnabled;
+    Qt::ItemFlags res;
 
     if (index.isValid()) {
-        res |= Qt::ItemIsDragEnabled;
+        res |= Qt::ItemIsDragEnabled | Qt::ItemIsSelectable | Qt::ItemIsEnabled;
     }
 
     if (!index.isValid()) {
@@ -999,7 +1084,7 @@ bool KFilePlacesModel::dropMimeData(const QMimeData *data, Qt::DropAction action
             QMimeType mimetype = db.mimeTypeForName(mimeString);
 
             if (!mimetype.isValid()) {
-                qWarning() << "URL not added to Places as mimetype could not be determined!";
+                qWarning() << "URL not added to Places as MIME type could not be determined!";
                 continue;
             }
 
