@@ -1,21 +1,9 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
-    Copyright (C) 2008 Rafael Fernández López <ereslibre@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2008 Rafael Fernández López <ereslibre@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kfileplacesview.h"
@@ -32,19 +20,22 @@
 #include <QPointer>
 #include <QScrollBar>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <defaults-kfile.h> // ConfigGroup, PlacesIconsAutoresize, PlacesIconsStaticSize
+#include <KConfig>
+#include <KConfigGroup>
 #include <kdirnotify.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <kmountpoint.h>
 #include <kpropertiesdialog.h>
 #include <kio/emptytrashjob.h>
 #include <kio/filesystemfreespacejob.h>
 #include <kio/jobuidelegate.h>
-#include <kjob.h>
-#include <kjobwidgets.h>
-#include <kcapacitybar.h>
+#include <widgetsaskuseractionhandler.h>
+#include <KJob>
+#include <KJobWidgets>
+#include <KCapacityBar>
+#include <KSharedConfig>
 #include <solid/storageaccess.h>
 #include <solid/storagedrive.h>
 #include <solid/storagevolume.h>
@@ -523,8 +514,9 @@ class Q_DECL_HIDDEN KFilePlacesView::Private
 {
 public:
     explicit Private(KFilePlacesView *parent)
-        : q(parent)
-        , watcher(new KFilePlacesEventWatcher(q))
+        : q(parent),
+          m_watcher(new KFilePlacesEventWatcher(q)),
+          m_delegate(new KFilePlacesViewDelegate(q))
     {}
 
     enum FadeType {
@@ -532,20 +524,8 @@ public:
         FadeOut
     };
 
-    KFilePlacesView *const q;
-
-    QUrl currentUrl;
-    bool autoResizeItems;
-    bool showAll;
-    bool smoothItemResizing;
-    bool dropOnPlace;
-    bool dragging;
-    Solid::StorageAccess *lastClickedStorage = nullptr;
-    QPersistentModelIndex lastClickedIndex;
-
-    QRect dropRect;
-
     void setCurrentIndex(const QModelIndex &index);
+    // If m_autoResizeItems is true, calculates a proper size for the icons in the places panel
     void adaptItemSize();
     void updateHiddenRows();
     void clearFreeSpaceInfos();
@@ -556,10 +536,16 @@ public:
     int sectionsCount() const;
 
     void addDisappearingItem(KFilePlacesViewDelegate *delegate, const QModelIndex &index);
-
     void triggerItemAppearingAnimation();
     void triggerItemDisappearingAnimation();
 
+    void writeConfig();
+    void readConfig();
+    // Sets the size of the icons in the places panel
+    void relayoutIconSize(int size);
+    // Adds the "Icon Size" sub-menu items
+    void setupIconSizeSubMenu(QMenu *submenu);
+
     void _k_placeClicked(const QModelIndex &index);
     void _k_placeEntered(const QModelIndex &index);
     void _k_placeLeft(const QModelIndex &index);
@@ -571,29 +557,44 @@ public:
     void _k_capacityBarFadeValueChanged();
     void _k_triggerDevicePolling();
 
-    QTimeLine adaptItemsTimeline;
-    int oldSize, endSize;
+    KFilePlacesView *const q;
 
-    QTimeLine itemAppearTimeline;
-    QTimeLine itemDisappearTimeline;
+    KFilePlacesEventWatcher *const m_watcher;
+    KFilePlacesViewDelegate *m_delegate;
 
-    KFilePlacesEventWatcher *const watcher;
-    KFilePlacesViewDelegate *delegate = nullptr;
-    QTimer pollDevices;
-    int pollingRequestCount;
+    Solid::StorageAccess *m_lastClickedStorage = nullptr;
+    QPersistentModelIndex m_lastClickedIndex;
+
+    std::unique_ptr<KIO::WidgetsAskUserActionHandler> m_askUserHandler;
+
+    QTimeLine m_adaptItemsTimeline;
+    QTimeLine m_itemAppearTimeline;
+    QTimeLine m_itemDisappearTimeline;
+
+    QTimer m_pollDevices;
+
+    QRect m_dropRect;
+
+    QUrl m_currentUrl;
+
+    int m_oldSize = 0;
+    int m_endSize = 0;
+    int m_iconSz = 0;
+    int m_pollingRequestCount = 0;
+
+    bool m_autoResizeItems = true;
+    bool m_smoothItemResizing = false;
+    bool m_showAll = false;
+    bool m_dropOnPlace = false;
+    bool m_dragging = false;
 };
 
 KFilePlacesView::KFilePlacesView(QWidget *parent)
     : QListView(parent), d(new Private(this))
 {
-    d->showAll = false;
-    d->smoothItemResizing = false;
-    d->dropOnPlace = false;
-    d->autoResizeItems = true;
-    d->dragging = false;
-    d->lastClickedStorage = nullptr;
-    d->pollingRequestCount = 0;
-    d->delegate = new KFilePlacesViewDelegate(this);
+    setItemDelegate(d->m_delegate);
+
+    d->readConfig();
 
     setSelectionRectVisible(false);
     setSelectionMode(SingleSelection);
@@ -605,7 +606,6 @@ KFilePlacesView::KFilePlacesView(QWidget *parent)
     setFrameStyle(QFrame::NoFrame);
 
     setResizeMode(Adjust);
-    setItemDelegate(d->delegate);
 
     QPalette palette = viewport()->palette();
     palette.setColor(viewport()->backgroundRole(), Qt::transparent);
@@ -618,32 +618,32 @@ KFilePlacesView::KFilePlacesView(QWidget *parent)
     // committed depends on the used widget style. The click behavior of
     // KFilePlacesView should be style independent.
 
-    connect(&d->adaptItemsTimeline, SIGNAL(valueChanged(qreal)),
+    connect(&d->m_adaptItemsTimeline, SIGNAL(valueChanged(qreal)),
             this, SLOT(_k_adaptItemsUpdate(qreal)));
-    d->adaptItemsTimeline.setDuration(500);
-    d->adaptItemsTimeline.setUpdateInterval(5);
-    d->adaptItemsTimeline.setCurveShape(QTimeLine::EaseInOutCurve);
+    d->m_adaptItemsTimeline.setDuration(500);
+    d->m_adaptItemsTimeline.setUpdateInterval(5);
+    d->m_adaptItemsTimeline.setEasingCurve(QEasingCurve::InOutSine);
 
-    connect(&d->itemAppearTimeline, SIGNAL(valueChanged(qreal)),
+    connect(&d->m_itemAppearTimeline, SIGNAL(valueChanged(qreal)),
             this, SLOT(_k_itemAppearUpdate(qreal)));
-    d->itemAppearTimeline.setDuration(500);
-    d->itemAppearTimeline.setUpdateInterval(5);
-    d->itemAppearTimeline.setCurveShape(QTimeLine::EaseInOutCurve);
+    d->m_itemAppearTimeline.setDuration(500);
+    d->m_itemAppearTimeline.setUpdateInterval(5);
+    d->m_itemAppearTimeline.setEasingCurve(QEasingCurve::InOutSine);
 
-    connect(&d->itemDisappearTimeline, SIGNAL(valueChanged(qreal)),
+    connect(&d->m_itemDisappearTimeline, SIGNAL(valueChanged(qreal)),
             this, SLOT(_k_itemDisappearUpdate(qreal)));
-    d->itemDisappearTimeline.setDuration(500);
-    d->itemDisappearTimeline.setUpdateInterval(5);
-    d->itemDisappearTimeline.setCurveShape(QTimeLine::EaseInOutCurve);
+    d->m_itemDisappearTimeline.setDuration(500);
+    d->m_itemDisappearTimeline.setUpdateInterval(5);
+    d->m_itemDisappearTimeline.setEasingCurve(QEasingCurve::InOutSine);
 
-    viewport()->installEventFilter(d->watcher);
-    connect(d->watcher, SIGNAL(entryEntered(QModelIndex)),
+    viewport()->installEventFilter(d->m_watcher);
+    connect(d->m_watcher, SIGNAL(entryEntered(QModelIndex)),
             this, SLOT(_k_placeEntered(QModelIndex)));
-    connect(d->watcher, SIGNAL(entryLeft(QModelIndex)),
+    connect(d->m_watcher, SIGNAL(entryLeft(QModelIndex)),
             this, SLOT(_k_placeLeft(QModelIndex)));
 
-    d->pollDevices.setInterval(5000);
-    connect(&d->pollDevices, SIGNAL(timeout()), this, SLOT(_k_triggerDevicePolling()));
+    d->m_pollDevices.setInterval(5000);
+    connect(&d->m_pollDevices, SIGNAL(timeout()), this, SLOT(_k_triggerDevicePolling()));
 
     // FIXME: this is necessary to avoid flashes of black with some widget styles.
     // could be a bug in Qt (e.g. QAbstractScrollArea) or KFilePlacesView, but has not
@@ -660,22 +660,22 @@ KFilePlacesView::~KFilePlacesView()
 
 void KFilePlacesView::setDropOnPlaceEnabled(bool enabled)
 {
-    d->dropOnPlace = enabled;
+    d->m_dropOnPlace = enabled;
 }
 
 bool KFilePlacesView::isDropOnPlaceEnabled() const
 {
-    return d->dropOnPlace;
+    return d->m_dropOnPlace;
 }
 
 void KFilePlacesView::setAutoResizeItemsEnabled(bool enabled)
 {
-    d->autoResizeItems = enabled;
+    d->m_autoResizeItems = enabled;
 }
 
 bool KFilePlacesView::isAutoResizeItemsEnabled() const
 {
-    return d->autoResizeItems;
+    return d->m_autoResizeItems;
 }
 
 void KFilePlacesView::setUrl(const QUrl &url)
@@ -690,22 +690,25 @@ void KFilePlacesView::setUrl(const QUrl &url)
     QModelIndex current = selectionModel()->currentIndex();
 
     if (index.isValid()) {
-        if (current != index && placesModel->isHidden(current) && !d->showAll) {
-            KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
-            d->addDisappearingItem(delegate, current);
+        if (current != index && placesModel->isHidden(current) && !d->m_showAll) {
+            d->addDisappearingItem(d->m_delegate, current);
         }
 
-        if (current != index && placesModel->isHidden(index) && !d->showAll) {
-            KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
-            delegate->addAppearingItem(index);
+        if (current != index && placesModel->isHidden(index) && !d->m_showAll) {
+            d->m_delegate->addAppearingItem(index);
             d->triggerItemAppearingAnimation();
             setRowHidden(index.row(), false);
         }
 
-        d->currentUrl = url;
-        selectionModel()->setCurrentIndex(index, QItemSelectionModel::ClearAndSelect);
+        d->m_currentUrl = url;
+
+        if (placesModel->url(index) == url.adjusted(QUrl::StripTrailingSlash) ) {
+            selectionModel()->setCurrentIndex(index, QItemSelectionModel::ClearAndSelect);
+        } else {
+            selectionModel()->clear();
+        }
     } else {
-        d->currentUrl = QUrl();
+        d->m_currentUrl = QUrl();
         selectionModel()->clear();
     }
 
@@ -722,12 +725,10 @@ void KFilePlacesView::setShowAll(bool showAll)
         return;
     }
 
-    d->showAll = showAll;
-
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
+    d->m_showAll = showAll;
 
     int rowCount = placesModel->rowCount();
-    QModelIndex current = placesModel->closestItem(d->currentUrl);
+    QModelIndex current = placesModel->closestItem(d->m_currentUrl);
 
     if (showAll) {
         d->updateHiddenRows();
@@ -735,7 +736,7 @@ void KFilePlacesView::setShowAll(bool showAll)
         for (int i = 0; i < rowCount; ++i) {
             QModelIndex index = placesModel->index(i, 0);
             if (index != current && placesModel->isHidden(index)) {
-                delegate->addAppearingItem(index);
+                d->m_delegate->addAppearingItem(index);
             }
         }
         d->triggerItemAppearingAnimation();
@@ -743,7 +744,7 @@ void KFilePlacesView::setShowAll(bool showAll)
         for (int i = 0; i < rowCount; ++i) {
             QModelIndex index = placesModel->index(i, 0);
             if (index != current && placesModel->isHidden(index)) {
-                delegate->addDisappearingItem(index);
+                d->m_delegate->addDisappearingItem(index);
             }
         }
         d->triggerItemDisappearingAnimation();
@@ -758,6 +759,25 @@ void KFilePlacesView::keyPressEvent(QKeyEvent *event)
     }
 }
 
+void KFilePlacesView::Private::readConfig()
+{
+    KConfigGroup cg(KSharedConfig::openConfig(), ConfigGroup);
+    m_autoResizeItems = cg.readEntry(PlacesIconsAutoresize, true);
+    m_delegate->setIconSize(cg.readEntry(PlacesIconsStaticSize, static_cast<int>(KIconLoader::SizeMedium)));
+}
+
+void KFilePlacesView::Private::writeConfig()
+{
+    KConfigGroup cg(KSharedConfig::openConfig(), ConfigGroup);
+    cg.writeEntry(PlacesIconsAutoresize, m_autoResizeItems);
+
+    if (!m_autoResizeItems) {
+        cg.writeEntry(PlacesIconsStaticSize, m_iconSz);
+    }
+
+    cg.sync();
+}
+
 void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
 {
     KFilePlacesModel *placesModel = qobject_cast<KFilePlacesModel *>(model());
@@ -766,8 +786,6 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
         return;
     }
 
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
-
     QModelIndex index = indexAt(event->pos());
     const QString label = placesModel->text(index).replace(QLatin1Char('&'), QLatin1String("&&"));
     const QUrl placeUrl = placesModel->url(index);
@@ -785,7 +803,7 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
     QAction *properties = nullptr;
     QAction *mount = nullptr;
 
-    const bool clickOverHeader = delegate->pointIsHeaderArea(event->pos());
+    const bool clickOverHeader = d->m_delegate->pointIsHeaderArea(event->pos());
     if (clickOverHeader) {
         const KFilePlacesModel::GroupType type = placesModel->groupType(index);
         hideSection = menu.addAction(QIcon::fromTheme(QStringLiteral("hint")), i18n("Hide Section"));
@@ -857,7 +875,7 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
     if (placesModel->hiddenCount() > 0) {
         showAll = new QAction(QIcon::fromTheme(QStringLiteral("visibility")), i18n("&Show All Entries"), &menu);
         showAll->setCheckable(true);
-        showAll->setChecked(d->showAll);
+        showAll->setChecked(d->m_showAll);
         if (mainSeparator == nullptr) {
             mainSeparator = menu.addSeparator();
         }
@@ -869,6 +887,10 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
         remove = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Remove Entry '%1'", label));
     }
 
+    QMenu *iconSizeMenu = new QMenu(i18nc("@item:inmenu", "Icon Size"), &menu);
+    menu.insertMenu(mainSeparator, iconSizeMenu);
+    d->setupIconSizeSubMenu(iconSizeMenu);
+
     menu.addActions(actions());
 
     if (menu.isEmpty()) {
@@ -878,14 +900,27 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
     QAction *result = menu.exec(event->globalPos());
 
     if (emptyTrash && (result == emptyTrash)) {
+        auto *parentWindow = window();
 
-        KIO::JobUiDelegate uiDelegate;
-        uiDelegate.setWindow(window());
-        if (uiDelegate.askDeleteConfirmation(QList<QUrl>(), KIO::JobUiDelegate::EmptyTrash, KIO::JobUiDelegate::DefaultConfirmation)) {
-            KIO::Job* job = KIO::emptyTrash();
-            KJobWidgets::setWindow(job, window());
-            job->uiDelegate()->setAutoErrorHandlingEnabled(true);
+        if (!d->m_askUserHandler) {
+            d->m_askUserHandler.reset(new KIO::WidgetsAskUserActionHandler{});
+
+            connect(d->m_askUserHandler.get(), &KIO::AskUserActionInterface::askUserDeleteResult,
+                    this, [this, parentWindow](bool allowDelete, const QList<QUrl> &,
+                                            KIO::AskUserActionInterface::DeletionType, QWidget *parent) {
+                if (parent != parentWindow || !allowDelete) {
+                    return;
+                }
+
+                KIO::Job *job = KIO::emptyTrash();
+                job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, parentWindow));
+            });
         }
+
+        d->m_askUserHandler->askUserDelete(QList<QUrl>{}, KIO::AskUserActionInterface::EmptyTrash,
+                                           KIO::AskUserActionInterface::DefaultConfirmation,
+                                           parentWindow);
+
     } else if (properties && (result == properties)) {
         KPropertiesDialog::showDialog(placeUrl, this);
     } else if (edit && (result == edit)) {
@@ -911,16 +946,16 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
         const KFilePlacesModel::GroupType type = placesModel->groupType(index);
         placesModel->setGroupHidden(type, hideSection->isChecked());
 
-        if (!d->showAll && hideSection->isChecked()) {
-            delegate->addDisappearingItemGroup(index);
+        if (!d->m_showAll && hideSection->isChecked()) {
+            d->m_delegate->addDisappearingItemGroup(index);
             d->triggerItemDisappearingAnimation();
         }
     } else if (hide && (result == hide)) {
         placesModel->setPlaceHidden(index, hide->isChecked());
-        QModelIndex current = placesModel->closestItem(d->currentUrl);
+        QModelIndex current = placesModel->closestItem(d->m_currentUrl);
 
-        if (index != current && !d->showAll && hide->isChecked()) {
-            delegate->addDisappearingItem(index);
+        if (index != current && !d->m_showAll && hide->isChecked()) {
+            d->m_delegate->addDisappearingItem(index);
             d->triggerItemDisappearingAnimation();
         }
     } else if (showAll && (result == showAll)) {
@@ -930,7 +965,7 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
     } else if (eject && (result == eject)) {
         placesModel->requestEject(index);
     } else if (add && (result == add)) {
-        QUrl url = d->currentUrl;
+        QUrl url = d->m_currentUrl;
         QString label;
         QString iconName = QStringLiteral("folder");
         bool appLocal = true;
@@ -947,10 +982,72 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
         placesModel->requestSetup(index);
     }
 
-    index = placesModel->closestItem(d->currentUrl);
+    index = placesModel->closestItem(d->m_currentUrl);
     selectionModel()->setCurrentIndex(index, QItemSelectionModel::ClearAndSelect);
 }
 
+void KFilePlacesView::Private::setupIconSizeSubMenu(QMenu *submenu)
+{
+    QActionGroup *group = new QActionGroup(submenu);
+
+    auto *autoAct = new QAction(i18nc("@item:inmenu Auto set icon size based on available space in"
+                                      "the Places side-panel", "Auto Resize"),
+                                group);
+    autoAct->setCheckable(true);
+    autoAct->setChecked(m_autoResizeItems);
+    QObject::connect(autoAct, &QAction::toggled, q, [this]() {
+        m_autoResizeItems = true;
+        adaptItemSize();
+        writeConfig();
+    });
+    submenu->addAction(autoAct);
+
+    constexpr KIconLoader::StdSizes iconSizes[] = { KIconLoader::SizeSmall,
+                                                    KIconLoader::SizeSmallMedium,
+                                                    KIconLoader::SizeMedium,
+                                                    KIconLoader::SizeLarge
+                                                  };
+
+    for (const auto iconSize : iconSizes) {
+        auto *act = new QAction(group);
+        act->setCheckable(true);
+
+        switch (iconSize) {
+        case KIconLoader::SizeSmall:
+            act->setText(i18nc("Small icon size", "Small (%1x%1)", KIconLoader::SizeSmall));
+            break;
+        case KIconLoader::SizeSmallMedium:
+            act->setText(i18nc("Medium icon size", "Medium (%1x%1)", KIconLoader::SizeSmallMedium));
+            break;
+        case KIconLoader::SizeMedium:
+            act->setText(i18nc("Large icon size", "Large (%1x%1)", KIconLoader::SizeMedium));
+            break;
+        case KIconLoader::SizeLarge:
+            act->setText(i18nc("Huge icon size", "Huge (%1x%1)", KIconLoader::SizeLarge));
+            break;
+        default:
+            break;
+        }
+
+        QObject::connect(act, &QAction::toggled, q, [this, iconSize]() {
+            m_autoResizeItems = false;
+            relayoutIconSize(iconSize);
+            // Store the new icon size in m_iconSz; which will be used by writeConfig(),
+            // otherwise if m_smoothItemResizing is true, the delegate icon size will be
+            // changed after the m_adaptItemsTimeline times out, by which time writeConfig
+            // has already finished, which means it won't save the new icon size
+            m_iconSz = iconSize;
+            writeConfig();
+        });
+
+        if (!m_autoResizeItems) {
+            act->setChecked(iconSize == m_delegate->iconSize());
+        }
+
+        submenu->addAction(act);
+    }
+}
+
 void KFilePlacesView::resizeEvent(QResizeEvent *event)
 {
     QListView::resizeEvent(event);
@@ -966,29 +1063,27 @@ void KFilePlacesView::showEvent(QShowEvent *event)
 void KFilePlacesView::hideEvent(QHideEvent *event)
 {
     QListView::hideEvent(event);
-    d->smoothItemResizing = false;
+    d->m_smoothItemResizing = false;
 }
 
 void KFilePlacesView::dragEnterEvent(QDragEnterEvent *event)
 {
     QListView::dragEnterEvent(event);
-    d->dragging = true;
+    d->m_dragging = true;
 
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
-    delegate->setShowHoverIndication(false);
+    d->m_delegate->setShowHoverIndication(false);
 
-    d->dropRect = QRect();
+    d->m_dropRect = QRect();
 }
 
 void KFilePlacesView::dragLeaveEvent(QDragLeaveEvent *event)
 {
     QListView::dragLeaveEvent(event);
-    d->dragging = false;
+    d->m_dragging = false;
 
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
-    delegate->setShowHoverIndication(true);
+    d->m_delegate->setShowHoverIndication(true);
 
-    setDirtyRegion(d->dropRect);
+    setDirtyRegion(d->m_dropRect);
 }
 
 void KFilePlacesView::dragMoveEvent(QDragMoveEvent *event)
@@ -998,25 +1093,25 @@ void KFilePlacesView::dragMoveEvent(QDragMoveEvent *event)
     // update the drop indicator
     const QPoint pos = event->pos();
     const QModelIndex index = indexAt(pos);
-    setDirtyRegion(d->dropRect);
+    setDirtyRegion(d->m_dropRect);
     if (index.isValid()) {
         const QRect rect = visualRect(index);
         const int gap = d->insertIndicatorHeight(rect.height());
         if (d->insertAbove(rect, pos)) {
             // indicate that the item will be inserted above the current place
-            d->dropRect = QRect(rect.left(), rect.top() - gap / 2,
+            d->m_dropRect = QRect(rect.left(), rect.top() - gap / 2,
                                 rect.width(), gap);
         } else if (d->insertBelow(rect, pos)) {
             // indicate that the item will be inserted below the current place
-            d->dropRect = QRect(rect.left(), rect.bottom() + 1 -  gap / 2,
+            d->m_dropRect = QRect(rect.left(), rect.bottom() + 1 -  gap / 2,
                                 rect.width(), gap);
         } else {
             // indicate that the item be dropped above the current place
-            d->dropRect = rect;
+            d->m_dropRect = rect;
         }
     }
 
-    setDirtyRegion(d->dropRect);
+    setDirtyRegion(d->m_dropRect);
 }
 
 void KFilePlacesView::dropEvent(QDropEvent *event)
@@ -1034,31 +1129,30 @@ void KFilePlacesView::dropEvent(QDropEvent *event)
     }
 
     QListView::dropEvent(event);
-    d->dragging = false;
+    d->m_dragging = false;
 
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
-    delegate->setShowHoverIndication(true);
+    d->m_delegate->setShowHoverIndication(true);
 }
 
 void KFilePlacesView::paintEvent(QPaintEvent *event)
 {
     QListView::paintEvent(event);
-    if (d->dragging && !d->dropRect.isEmpty()) {
+    if (d->m_dragging && !d->m_dropRect.isEmpty()) {
         // draw drop indicator
         QPainter painter(viewport());
 
-        const QModelIndex index = indexAt(d->dropRect.topLeft());
+        const QModelIndex index = indexAt(d->m_dropRect.topLeft());
         const QRect itemRect = visualRect(index);
-        const bool drawInsertIndicator = !d->dropOnPlace ||
-                                         d->dropRect.height() <= d->insertIndicatorHeight(itemRect.height());
+        const bool drawInsertIndicator = !d->m_dropOnPlace ||
+                                         d->m_dropRect.height() <= d->insertIndicatorHeight(itemRect.height());
 
         if (drawInsertIndicator) {
             // draw indicator for inserting items
             QBrush blendedBrush = viewOptions().palette.brush(QPalette::Normal, QPalette::Highlight);
             QColor color = blendedBrush.color();
 
-            const int y = (d->dropRect.top() + d->dropRect.bottom()) / 2;
-            const int thickness = d->dropRect.height() / 2;
+            const int y = (d->m_dropRect.top() + d->m_dropRect.bottom()) / 2;
+            const int thickness = d->m_dropRect.height() / 2;
             Q_ASSERT(thickness >= 1);
             int alpha = 255;
             const int alphaDec = alpha / (thickness + 1);
@@ -1066,8 +1160,8 @@ void KFilePlacesView::paintEvent(QPaintEvent *event)
                 color.setAlpha(alpha);
                 alpha -= alphaDec;
                 painter.setPen(color);
-                painter.drawLine(d->dropRect.left(), y - i, d->dropRect.right(), y - i);
-                painter.drawLine(d->dropRect.left(), y + i, d->dropRect.right(), y + i);
+                painter.drawLine(d->m_dropRect.left(), y - i, d->m_dropRect.right(), y - i);
+                painter.drawLine(d->m_dropRect.left(), y + i, d->m_dropRect.right(), y + i);
             }
         } else {
             // draw indicator for copying/moving/linking to items
@@ -1082,18 +1176,15 @@ void KFilePlacesView::paintEvent(QPaintEvent *event)
 
 void KFilePlacesView::startDrag(Qt::DropActions supportedActions)
 {
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
-
-    delegate->startDrag();
+    d->m_delegate->startDrag();
     QListView::startDrag(supportedActions);
 }
 
 void KFilePlacesView::mousePressEvent(QMouseEvent *event)
 {
     if (event->button() == Qt::LeftButton) {
-        KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
         // does not accept drags from section header area
-        if (delegate->pointIsHeaderArea(event->pos())) {
+        if (d->m_delegate->pointIsHeaderArea(event->pos())) {
             return;
         }
     }
@@ -1111,23 +1202,22 @@ void KFilePlacesView::setModel(QAbstractItemModel *model)
     connect(model, SIGNAL(rowsRemoved(QModelIndex,int,int)),
             this, SLOT(adaptItemSize()), Qt::QueuedConnection);
     connect(selectionModel(), &QItemSelectionModel::currentChanged,
-            d->watcher, &KFilePlacesEventWatcher::currentIndexChanged);
+            d->m_watcher, &KFilePlacesEventWatcher::currentIndexChanged);
 
-    static_cast<KFilePlacesViewDelegate *>(itemDelegate())->clearFreeSpaceInfo();
+    d->m_delegate->clearFreeSpaceInfo();
 }
 
 void KFilePlacesView::rowsInserted(const QModelIndex &parent, int start, int end)
 {
     QListView::rowsInserted(parent, start, end);
-    setUrl(d->currentUrl);
+    setUrl(d->m_currentUrl);
 
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(itemDelegate());
     KFilePlacesModel *placesModel = static_cast<KFilePlacesModel *>(model());
 
     for (int i = start; i <= end; ++i) {
         QModelIndex index = placesModel->index(i, 0, parent);
-        if (d->showAll || !placesModel->isHidden(index)) {
-            delegate->addAppearingItem(index);
+        if (d->m_showAll || !placesModel->isHidden(index)) {
+            d->m_delegate->addAppearingItem(index);
             d->triggerItemAppearingAnimation();
         } else {
             setRowHidden(i, true);
@@ -1156,16 +1246,16 @@ QSize KFilePlacesView::sizeHint() const
         }
     }
 
-    const int iconSize = KIconLoader::global()->currentSize(KIconLoader::Small) + 3 * LATERAL_MARGIN;
+    const int iconSize = style()->pixelMetric(QStyle::PM_SmallIconSize) + 3 * LATERAL_MARGIN;
     return QSize(iconSize + textWidth + fm.height() / 2, height);
 }
 
 void KFilePlacesView::Private::addDisappearingItem(KFilePlacesViewDelegate *delegate, const QModelIndex &index)
 {
     delegate->addDisappearingItem(index);
-    if (itemDisappearTimeline.state() != QTimeLine::Running) {
+    if (m_itemDisappearTimeline.state() != QTimeLine::Running) {
         delegate->setDisappearingItemProgress(0.0);
-        itemDisappearTimeline.start();
+        m_itemDisappearTimeline.start();
     }
 }
 
@@ -1180,25 +1270,20 @@ void KFilePlacesView::Private::setCurrentIndex(const QModelIndex &index)
     QUrl url = placesModel->url(index);
 
     if (url.isValid()) {
-        currentUrl = url;
+        m_currentUrl = url;
         updateHiddenRows();
         emit q->urlChanged(KFilePlacesModel::convertedUrl(url));
-        if (showAll) {
+        if (m_showAll) {
             q->setShowAll(false);
         }
     } else {
-        q->setUrl(currentUrl);
+        q->setUrl(m_currentUrl);
     }
 }
 
 void KFilePlacesView::Private::adaptItemSize()
 {
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(q->itemDelegate());
-
-    if (!autoResizeItems) {
-        const int size = q->iconSize().width(); // Assume width == height
-        delegate->setIconSize(size);
-        q->scheduleDelayedItemsLayout();
+    if (!m_autoResizeItems) {
         return;
     }
 
@@ -1210,13 +1295,13 @@ void KFilePlacesView::Private::adaptItemSize()
 
     int rowCount = placesModel->rowCount();
 
-    if (!showAll) {
+    if (!m_showAll) {
         rowCount -= placesModel->hiddenCount();
 
-        QModelIndex current = placesModel->closestItem(currentUrl);
+        QModelIndex current = placesModel->closestItem(m_currentUrl);
 
         if (placesModel->isHidden(current)) {
-            rowCount++;
+            ++rowCount;
         }
     }
 
@@ -1224,7 +1309,7 @@ void KFilePlacesView::Private::adaptItemSize()
         return;    // We've nothing to display anyway
     }
 
-    const int minSize = IconSize(KIconLoader::Small);
+    const int minSize = q->style()->pixelMetric(QStyle::PM_SmallIconSize);
     const int maxSize = 64;
 
     int textWidth = 0;
@@ -1241,7 +1326,7 @@ void KFilePlacesView::Private::adaptItemSize()
     const int maxWidth = q->viewport()->width() - textWidth - 4 * margin - 1;
 
     const int totalItemsHeight = (fm.height() / 2) * rowCount;
-    const int totalSectionsHeight = delegate->sectionHeaderHeight() * sectionsCount();
+    const int totalSectionsHeight = m_delegate->sectionHeaderHeight() * sectionsCount();
     const int maxHeight = ((q->height() - totalSectionsHeight - totalItemsHeight) / rowCount) - 1;
 
     int size = qMin(maxHeight, maxWidth);
@@ -1255,18 +1340,23 @@ void KFilePlacesView::Private::adaptItemSize()
         size &= ~0xf;
     }
 
-    if (size == delegate->iconSize()) {
+    relayoutIconSize(size);
+}
+
+void KFilePlacesView::Private::relayoutIconSize(const int size)
+{
+    if (size == m_delegate->iconSize()) {
         return;
     }
 
-    if (smoothItemResizing) {
-        oldSize = delegate->iconSize();
-        endSize = size;
-        if (adaptItemsTimeline.state() != QTimeLine::Running) {
-            adaptItemsTimeline.start();
+    if (m_smoothItemResizing) {
+        m_oldSize = m_delegate->iconSize();
+        m_endSize = size;
+        if (m_adaptItemsTimeline.state() != QTimeLine::Running) {
+            m_adaptItemsTimeline.start();
         }
     } else {
-        delegate->setIconSize(size);
+        m_delegate->setIconSize(size);
         q->scheduleDelayedItemsLayout();
     }
 }
@@ -1280,11 +1370,11 @@ void KFilePlacesView::Private::updateHiddenRows()
     }
 
     int rowCount = placesModel->rowCount();
-    QModelIndex current = placesModel->closestItem(currentUrl);
+    QModelIndex current = placesModel->closestItem(m_currentUrl);
 
     for (int i = 0; i < rowCount; ++i) {
         QModelIndex index = placesModel->index(i, 0);
-        if (index != current && placesModel->isHidden(index) && !showAll) {
+        if (index != current && placesModel->isHidden(index) && !m_showAll) {
             q->setRowHidden(i, true);
         } else {
             q->setRowHidden(i, false);
@@ -1296,7 +1386,7 @@ void KFilePlacesView::Private::updateHiddenRows()
 
 bool KFilePlacesView::Private::insertAbove(const QRect &itemRect, const QPoint &pos) const
 {
-    if (dropOnPlace) {
+    if (m_dropOnPlace) {
         return pos.y() < itemRect.top() + insertIndicatorHeight(itemRect.height()) / 2;
     }
 
@@ -1305,7 +1395,7 @@ bool KFilePlacesView::Private::insertAbove(const QRect &itemRect, const QPoint &
 
 bool KFilePlacesView::Private::insertBelow(const QRect &itemRect, const QPoint &pos) const
 {
-    if (dropOnPlace) {
+    if (m_dropOnPlace) {
         return pos.y() > itemRect.bottom() - insertIndicatorHeight(itemRect.height()) / 2;
     }
 
@@ -1328,9 +1418,9 @@ int KFilePlacesView::Private::insertIndicatorHeight(int itemHeight) const
 
 void KFilePlacesView::Private::fadeCapacityBar(const QModelIndex &index, FadeType fadeType)
 {
-    QTimeLine *timeLine = delegate->fadeAnimationForIndex(index);
+    QTimeLine *timeLine = m_delegate->fadeAnimationForIndex(index);
     delete timeLine;
-    delegate->removeFadeAnimation(index);
+    m_delegate->removeFadeAnimation(index);
     timeLine = new QTimeLine(250, q);
     connect(timeLine, SIGNAL(valueChanged(qreal)), q, SLOT(_k_capacityBarFadeValueChanged()));
     if (fadeType == FadeIn) {
@@ -1340,7 +1430,7 @@ void KFilePlacesView::Private::fadeCapacityBar(const QModelIndex &index, FadeTyp
         timeLine->setDirection(QTimeLine::Backward);
         timeLine->setCurrentTime(250);
     }
-    delegate->addFadeAnimation(index, timeLine);
+    m_delegate->addFadeAnimation(index, timeLine);
     timeLine->start();
 }
 
@@ -1356,7 +1446,7 @@ int KFilePlacesView::Private::sectionsCount() const
             const QString sectionName = index.data(KFilePlacesModel::GroupRole).toString();
             if (prevSection != sectionName) {
                 prevSection = sectionName;
-                count++;
+                ++count;
             }
         }
     }
@@ -1366,17 +1456,17 @@ int KFilePlacesView::Private::sectionsCount() const
 
 void KFilePlacesView::Private::triggerItemAppearingAnimation()
 {
-    if (itemAppearTimeline.state() != QTimeLine::Running) {
-        delegate->setAppearingItemProgress(0.0);
-        itemAppearTimeline.start();
+    if (m_itemAppearTimeline.state() != QTimeLine::Running) {
+        m_delegate->setAppearingItemProgress(0.0);
+        m_itemAppearTimeline.start();
     }
 }
 
 void KFilePlacesView::Private::triggerItemDisappearingAnimation()
 {
-    if (itemDisappearTimeline.state() != QTimeLine::Running) {
-        delegate->setDisappearingItemProgress(0.0);
-        itemDisappearTimeline.start();
+    if (m_itemDisappearTimeline.state() != QTimeLine::Running) {
+        m_delegate->setDisappearingItemProgress(0.0);
+        m_itemDisappearTimeline.start();
     }
 }
 
@@ -1388,13 +1478,13 @@ void KFilePlacesView::Private::_k_placeClicked(const QModelIndex &index)
         return;
     }
 
-    lastClickedIndex = QPersistentModelIndex();
+    m_lastClickedIndex = QPersistentModelIndex();
 
     if (placesModel->setupNeeded(index)) {
         QObject::connect(placesModel, SIGNAL(setupDone(QModelIndex,bool)),
                          q, SLOT(_k_storageSetupDone(QModelIndex,bool)));
 
-        lastClickedIndex = index;
+        m_lastClickedIndex = index;
         placesModel->requestSetup(index);
         return;
     }
@@ -1405,24 +1495,24 @@ void KFilePlacesView::Private::_k_placeClicked(const QModelIndex &index)
 void KFilePlacesView::Private::_k_placeEntered(const QModelIndex &index)
 {
     fadeCapacityBar(index, FadeIn);
-    pollingRequestCount++;
-    if (pollingRequestCount == 1) {
-        pollDevices.start();
+    ++m_pollingRequestCount;
+    if (m_pollingRequestCount == 1) {
+        m_pollDevices.start();
     }
 }
 
 void KFilePlacesView::Private::_k_placeLeft(const QModelIndex &index)
 {
     fadeCapacityBar(index, FadeOut);
-    pollingRequestCount--;
-    if (!pollingRequestCount) {
-        pollDevices.stop();
+    --m_pollingRequestCount;
+    if (!m_pollingRequestCount) {
+        m_pollDevices.stop();
     }
 }
 
 void KFilePlacesView::Private::_k_storageSetupDone(const QModelIndex &index, bool success)
 {
-    if (index != lastClickedIndex) {
+    if (index != m_lastClickedIndex) {
         return;
     }
 
@@ -1434,38 +1524,32 @@ void KFilePlacesView::Private::_k_storageSetupDone(const QModelIndex &index, boo
     }
 
     if (success) {
-        setCurrentIndex(lastClickedIndex);
+        setCurrentIndex(m_lastClickedIndex);
     } else {
-        q->setUrl(currentUrl);
+        q->setUrl(m_currentUrl);
     }
 
-    lastClickedIndex = QPersistentModelIndex();
+    m_lastClickedIndex = QPersistentModelIndex();
 }
 
 void KFilePlacesView::Private::_k_adaptItemsUpdate(qreal value)
 {
-    int add = (endSize - oldSize) * value;
+    const int add = (m_endSize - m_oldSize) * value;
+    const int size = m_oldSize + add;
 
-    int size = oldSize + add;
-
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(q->itemDelegate());
-    delegate->setIconSize(size);
+    m_delegate->setIconSize(size);
     q->scheduleDelayedItemsLayout();
 }
 
 void KFilePlacesView::Private::_k_itemAppearUpdate(qreal value)
 {
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(q->itemDelegate());
-
-    delegate->setAppearingItemProgress(value);
+    m_delegate->setAppearingItemProgress(value);
     q->scheduleDelayedItemsLayout();
 }
 
 void KFilePlacesView::Private::_k_itemDisappearUpdate(qreal value)
 {
-    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate *>(q->itemDelegate());
-
-    delegate->setDisappearingItemProgress(value);
+    m_delegate->setDisappearingItemProgress(value);
 
     if (value >= 1.0) {
         updateHiddenRows();
@@ -1476,12 +1560,12 @@ void KFilePlacesView::Private::_k_itemDisappearUpdate(qreal value)
 
 void KFilePlacesView::Private::_k_enableSmoothItemResizing()
 {
-    smoothItemResizing = true;
+    m_smoothItemResizing = true;
 }
 
 void KFilePlacesView::Private::_k_capacityBarFadeValueChanged()
 {
-    const QModelIndex index = delegate->indexForFadeAnimation(static_cast<QTimeLine *>(q->sender()));
+    const QModelIndex index = m_delegate->indexForFadeAnimation(static_cast<QTimeLine *>(q->sender()));
     if (!index.isValid()) {
         return;
     }
@@ -1490,14 +1574,14 @@ void KFilePlacesView::Private::_k_capacityBarFadeValueChanged()
 
 void KFilePlacesView::Private::_k_triggerDevicePolling()
 {
-    const QModelIndex hoveredIndex = watcher->hoveredIndex();
+    const QModelIndex hoveredIndex = m_watcher->hoveredIndex();
     if (hoveredIndex.isValid()) {
         const KFilePlacesModel *placesModel = static_cast<const KFilePlacesModel *>(hoveredIndex.model());
         if (placesModel->isDevice(hoveredIndex)) {
             q->update(hoveredIndex);
         }
     }
-    const QModelIndex focusedIndex = watcher->focusedIndex();
+    const QModelIndex focusedIndex = m_watcher->focusedIndex();
     if (focusedIndex.isValid() && focusedIndex != hoveredIndex) {
         const KFilePlacesModel *placesModel = static_cast<const KFilePlacesModel *>(focusedIndex.model());
         if (placesModel->isDevice(focusedIndex)) {
