@@ -1,20 +1,8 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2008 Rafael Fernández López <ereslibre@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2008 Rafael Fernández López <ereslibre@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KFILEPLACESVIEW_P_H
@@ -28,7 +16,7 @@ class KFilePlacesEventWatcher
     Q_OBJECT
 
 public:
-    KFilePlacesEventWatcher(QObject *parent = nullptr)
+    explicit KFilePlacesEventWatcher(QObject *parent = nullptr)
         : QObject(parent) {}
 
     const QModelIndex &hoveredIndex() const
@@ -62,7 +50,7 @@ public Q_SLOTS:
     }
 
 protected:
-    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE
+    bool eventFilter(QObject *watched, QEvent *event) override
     {
         switch (event->type()) {
         case QEvent::MouseMove: {
