@@ -1,37 +1,24 @@
-/*******************************************************************************
- *   Copyright (C) 2008-2009 by Peter Penz <peter.penz@gmx.at>                 *
- *                                                                             *
- *   This library is free software; you can redistribute it and/or             *
- *   modify it under the terms of the GNU Library General Public               *
- *   License as published by the Free Software Foundation; either              *
- *   version 2 of the License, or (at your option) any later version.          *
- *                                                                             *
- *   This library is distributed in the hope that it will be useful,           *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- *   Library General Public License for more details.                          *
- *                                                                             *
- *   You should have received a copy of the GNU Library General Public License *
- *   along with this library; see the file COPYING.LIB.  If not, write to      *
- *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                               *
- *******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2009 Peter Penz <peter.penz@gmx.at>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kfilepreviewgenerator.h"
 
 #include "defaultviewadapter_p.h"
 #include <imagefilter_p.h> // from kiowidgets
 #include <config-kiofilewidgets.h> // for HAVE_XRENDER
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #include <kfileitem.h>
-#include <kiconeffect.h>
+#include <KIconEffect>
 #include <kio/previewjob.h>
 #include <kio/paste.h>
 #include <kdirlister.h>
 #include <kdirmodel.h>
-#include <kiconloader.h>
-#include <ksharedconfig.h>
-#include <kurlmimedata.h>
+#include <KIconLoader>
+#include <KSharedConfig>
+#include <KUrlMimeData>
 
 #include <QApplication>
 #include <QAbstractItemView>
@@ -529,7 +516,7 @@ void KFilePreviewGenerator::Private::requestSequenceIcon(const QModelIndex &inde
         }
 
         ///@todo Update directly, without using m_sequenceIndices
-        updateIcons(KFileItemList() << item);
+        updateIcons(KFileItemList{item});
     }
 }
 
@@ -772,7 +759,7 @@ void KFilePreviewGenerator::Private::dispatchIconUpdateQueue()
             m_previews.clear();
         }
 
-        // dispatch mime type queue
+        // dispatch MIME type queue
         for (const KFileItem &item : qAsConst(m_resolvedMimeTypes)) {
             const QModelIndex idx = dirModel->indexForItem(item);
             dirModel->itemChanged(idx);
@@ -914,11 +901,7 @@ void KFilePreviewGenerator::Private::applyCutItemEffect(const KFileItemList &ite
     }
 
     const QList<QUrl> urlsList = KUrlMimeData::urlsFromMimeData(mimeData);
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    const QSet<QUrl> cutUrls = urlsList.toSet();
-#else
     const QSet<QUrl> cutUrls(urlsList.begin(), urlsList.end());
-#endif
 
     DataChangeObtainer obt(this);
     KIconEffect *iconEffect = KIconLoader::global()->iconEffect();
