@@ -1,27 +1,15 @@
 // -*- c++ -*-
-/* This file is part of the KDE libraries
-    Copyright (C) 1997, 1998 Richard Moore <rich@kde.org>
-                  1998 Stephan Kulow <coolo@kde.org>
-                  1998 Daniel Grana <grana@ie.iwi.unibe.ch>
-                  2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
-                  2001 Frerich Raabe <raabe@kde.org>
-                  2007 David Faure <faure@kde.org>
-                  2008 Rafael Fernández López <ereslibre@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1997, 1998 Richard Moore <rich@kde.org>
+    SPDX-FileCopyrightText: 1998 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 1998 Daniel Grana <grana@ie.iwi.unibe.ch>
+    SPDX-FileCopyrightText: 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2001 Frerich Raabe <raabe@kde.org>
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2008 Rafael Fernández López <ereslibre@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KFILEWIDGET_H
@@ -171,6 +159,14 @@ public:
      */
     void setSelectedUrl(const QUrl &url);
 
+    /**
+     * Sets a list of URLs as preselected
+     * 
+     * @see setSelectedUrl
+     * @since 5.75
+     */
+    void setSelectedUrls(const QList<QUrl> &urls);
+
     /**
      * Sets the operational mode of the filedialog to @p Saving, @p Opening
      * or @p Other. This will set some flags that are specific to loading
@@ -239,9 +235,9 @@ public:
      * want to show the suffix to select by a specific filter, you must
      * repeat it.
      *
-     * If the filter contains an unescaped '/', a mimetype-filter is assumed.
+     * If the filter contains an unescaped '/', a MIME type filter is assumed.
      * If you would like a '/' visible in your filter it can be escaped with
-     * a '\'. You can specify multiple mimetypes like this (separated with
+     * a '\'. You can specify multiple MIME types like this (separated with
      * space):
      *
      * \code
@@ -264,7 +260,7 @@ public:
     QString currentFilter() const;
 
     /**
-     * Returns the mimetype for the desired output format.
+     * Returns the MIME type for the desired output format.
      *
      * This is only valid if setFilterMimeType() has been called
      * previously.
@@ -276,10 +272,10 @@ public:
     /**
      * Sets the filter up to specify the output type.
      *
-     * @param types a list of mimetypes that can be used as output format
-     * @param defaultType the default mimetype to use as output format, if any.
+     * @param types a list of MIME types that can be used as output format
+     * @param defaultType the default MIME type to use as output format, if any.
      * If @p defaultType is set, it will be set as the current item.
-     * Otherwise, a first item showing all the mimetypes will be created.
+     * Otherwise, a first item showing all the MIME types will be created.
      * Typically, @p defaultType should be empty for loading and set for saving.
      *
      * Do not use in conjunction with setFilter()
@@ -288,7 +284,7 @@ public:
                        const QString &defaultType = QString());
 
     /**
-     * The mimetype for the desired output format.
+     * The MIME type for the desired output format.
      *
      * This is only valid if setMimeFilter() has been called
      * previously.
@@ -298,7 +294,7 @@ public:
     QString currentMimeFilter() const;
 
     /**
-     *  Clears any mime- or namefilter. Does not reload the directory.
+     *  Clears any MIME type or name filter. Does not reload the directory.
      */
     void clearFilter();
 
