@@ -1,22 +1,8 @@
 /*
     This file is part of the KDE libraries
-    Copyright (c) 2020 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2020 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 2 of the License or ( at
-    your option ) version 3 or, at the discretion of KDE e.V. ( which shall
-    act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "openurljob.h"
@@ -27,6 +13,7 @@
 #include "commandlauncherjob.h"
 #include "desktopexecparser.h"
 #include "untrustedprogramhandlerinterface.h"
+#include "jobuidelegatefactory.h"
 #include "kiogui_debug.h"
 
 #include <KApplicationTrader>
@@ -47,14 +34,6 @@
 
 #include <kio/scheduler.h>
 
-KIO::OpenWithHandlerInterface *s_openWithHandler = nullptr;
-KIO::OpenOrExecuteFileInterface *s_openOrExecuteFileHandler = nullptr;
-namespace KIO {
-// Hidden API because in KF6 we'll just check if the job's uiDelegate implements these interfaces
-KIOGUI_EXPORT void setDefaultOpenWithHandler(KIO::OpenWithHandlerInterface *iface) { s_openWithHandler = iface; }
-KIOGUI_EXPORT void setDefaultOpenOrExecuteFileHandler(KIO::OpenOrExecuteFileInterface *iface) { s_openOrExecuteFileHandler = iface; }
-}
-
 class KIO::OpenUrlJobPrivate
 {
 public:
@@ -87,9 +66,10 @@ public:
 
 private:
     void executeCommand();
-    void handleExecutables(const QMimeType &mimeType);
+    void handleBinaries(const QMimeType &mimeType);
+    void handleBinariesHelper(const QString &localPath, bool isNativeBinary);
     void handleDesktopFiles();
-    void handleShellscripts();
+    void handleScripts();
     void openInPreferredApp();
     void runLink(const QString &filePath, const QString &urlStr, const QString &optionalServiceName);
 
@@ -185,7 +165,7 @@ void KIO::OpenUrlJob::start()
         return;
     }
 
-    // If we know the mimetype, proceed
+    // If we know the MIME type, proceed
     if (!d->m_mimeTypeName.isEmpty()) {
         d->runUrlWithMimeType();
         return;
@@ -270,7 +250,7 @@ void KIO::OpenUrlJobPrivate::useSchemeHandler()
     Q_ASSERT(KProtocolInfo::isHelperProtocol(m_url.scheme()));
     const auto exec = KProtocolInfo::exec(m_url.scheme());
     if (exec.isEmpty()) {
-        // use default mimetype opener for file
+        // use default MIME type opener for file
         m_mimeTypeName = KProtocolManager::defaultMimetype(m_url);
         runUrlWithMimeType();
     } else {
@@ -309,7 +289,7 @@ void KIO::OpenUrlJobPrivate::statFile()
             m_url = QUrl::fromLocalFile(localPath);
         }
 
-        // mimetype already known? (e.g. print:/manager)
+        // MIME type already known? (e.g. print:/manager)
         m_mimeTypeName = entry.stringValue(KIO::UDSEntry::UDS_MIME_TYPE);
         if (!m_mimeTypeName.isEmpty()) {
             runUrlWithMimeType();
@@ -367,9 +347,9 @@ void KIO::OpenUrlJobPrivate::scanFileWithGet()
         }
     }
 
-    // No mimetype found, and the URL is not local  (or fast mode not allowed).
+    // No MIME type found, and the URL is not local  (or fast mode not allowed).
     // We need to apply the 'KIO' method, i.e. either asking the server or
-    // getting some data out of the file, to know what mimetype it is.
+    // getting some data out of the file, to know what MIME type it is.
 
     if (!KProtocolManager::supportsReading(m_url)) {
         qCWarning(KIO_GUI) << "#### NO SUPPORT FOR READING!";
@@ -395,18 +375,18 @@ void KIO::OpenUrlJobPrivate::scanFileWithGet()
         }
         // if the job succeeded, we certainly hope it emitted mimetype()...
     });
-    QObject::connect(job, QOverload<KIO::Job*,const QString&>::of(&KIO::TransferJob::mimetype),
+    QObject::connect(job, &KIO::TransferJob::mimeTypeFound,
                      q, [=](KIO::Job *, const QString &mimetype) {
         if (m_followRedirections) { // Update our URL in case of a redirection
             m_url = job->url();
         }
         if (mimetype.isEmpty()) {
-            qCWarning(KIO_GUI) << "get() didn't emit a mimetype! Probably a kioslave bug, please check the implementation of" << m_url.scheme();
+            qCWarning(KIO_GUI) << "get() didn't emit a MIME type! Probably a kioslave bug, please check the implementation of" << m_url.scheme();
         }
         m_mimeTypeName = mimetype;
 
-        // If the current mime-type is the default mime-type, then attempt to
-        // determine the "real" mimetype from the file name (bug #279675)
+        // If the current MIME type is the default MIME type, then attempt to
+        // determine the "real" MIME type from the file name (bug #279675)
         const QMimeType mime = fixupMimeType(m_mimeTypeName, m_suggestedFileName.isEmpty() ? m_url.fileName() : m_suggestedFileName);
         const QString mimeName = mime.name();
         if (mime.isValid() && mimeName != m_mimeTypeName) {
@@ -453,14 +433,29 @@ void KIO::OpenUrlJobPrivate::emitAccessDenied()
     q->emitResult();
 }
 
-// was: KRun::isExecutable (minus application/x-desktop and application/x-shellscript mimetypes).
+// was: KRun::isExecutable (minus application/x-desktop MIME type).
 // Feel free to make public if needed.
-static bool isExecutableMime(const QMimeType &mimeType)
+static bool isBinary(const QMimeType &mimeType)
 {
-    return (mimeType.inherits(QStringLiteral("application/x-executable")) ||
-            /* e.g. /usr/bin/ls, see https://gitlab.freedesktop.org/xdg/shared-mime-info/-/issues/11 */
-            mimeType.inherits(QStringLiteral("application/x-sharedlib")) ||
-            mimeType.inherits(QStringLiteral("application/x-ms-dos-executable")));
+    // - Binaries could be e.g.:
+    //   - application/x-executable
+    //   - application/x-sharedlib e.g. /usr/bin/ls, see
+    //     https://gitlab.freedesktop.org/xdg/shared-mime-info/-/issues/11
+    //
+    // - MIME types that inherit application/x-executable _and_ text/plain are scripts, these are
+    //   handled by handleScripts()
+
+    return (mimeType.inherits(QStringLiteral("application/x-executable"))
+            || mimeType.inherits(QStringLiteral("application/x-sharedlib"))
+            || mimeType.inherits(QStringLiteral("application/x-ms-dos-executable")));
+}
+
+// Helper function that returns whether a file is a text-based script
+// e.g. ".sh", ".csh", ".py", ".js"
+static bool isTextScript(const QMimeType &mimeType)
+{
+    return (mimeType.inherits(QStringLiteral("application/x-executable"))
+            && mimeType.inherits(QStringLiteral("text/plain")));
 }
 
 // Helper function that returns whether a file has the execute bit set or not.
@@ -470,7 +465,7 @@ static bool hasExecuteBit(const QString &fileName)
 }
 
 // Handle native binaries (.e.g. /usr/bin/*); and .exe files
-void KIO::OpenUrlJobPrivate::handleExecutables(const QMimeType &mimeType)
+void KIO::OpenUrlJobPrivate::handleBinaries(const QMimeType &mimeType)
 {
     if (!KAuthorized::authorize(QStringLiteral("shell_access"))) {
         emitAccessDenied();
@@ -489,32 +484,31 @@ void KIO::OpenUrlJobPrivate::handleExecutables(const QMimeType &mimeType)
 
     const QString localPath = m_url.toLocalFile();
 
-    // Check whether file is an executable script
-#ifdef Q_OS_WIN
-    const bool isNativeBinary = !mimeType.inherits(QStringLiteral("text/plain"));
-#else
-    const bool isNativeBinary = !mimeType.inherits(QStringLiteral("text/plain")) && !mimeType.inherits(QStringLiteral("application/x-ms-dos-executable"));
+    bool isNativeBinary = true;
+#ifndef Q_OS_WIN
+    isNativeBinary = !mimeType.inherits(QStringLiteral("application/x-ms-dos-executable"));
 #endif
 
     if (m_showOpenOrExecuteDialog) {
         auto dialogFinished = [this, localPath, isNativeBinary](bool shouldExecute) {
-            if (shouldExecute) {
-                if (isNativeBinary) {
-                    if (!hasExecuteBit(localPath)) {
-                        showUntrustedProgramWarningDialog(localPath);
-                        return;
-                    }
-                    executeCommand(); // Local executable with execute bit, proceed
-                } else { // For .exe files, open in the default app (e.g. WINE)
-                    openInPreferredApp();
-                }
-            }
+            // shouldExecute is always true if we get here, because for binaries the
+            // dialog only offers Execute/Cancel
+            Q_UNUSED(shouldExecute)
+
+            handleBinariesHelper(localPath, isNativeBinary);
         };
 
+        // Ask the user for confirmation before executing this binary (for binaries
+        // the dialog will only show Execute/Cancel)
         showOpenOrExecuteFileDialog(dialogFinished);
         return;
     }
 
+    handleBinariesHelper(localPath, isNativeBinary);
+}
+
+void KIO::OpenUrlJobPrivate::handleBinariesHelper(const QString &localPath, bool isNativeBinary)
+{
     // For local .exe files, open in the default app (e.g. WINE)
     if (!isNativeBinary) {
         openInPreferredApp();
@@ -540,15 +534,11 @@ void KIO::OpenUrlJobPrivate::handleExecutables(const QMimeType &mimeType)
     executeCommand();
 }
 
-namespace KIO {
-extern KIO::UntrustedProgramHandlerInterface *defaultUntrustedProgramHandler();
-}
-
 // For local, native executables (i.e. not shell scripts) without execute bit,
 // show a prompt asking the user if he wants to run the program.
 void KIO::OpenUrlJobPrivate::showUntrustedProgramWarningDialog(const QString &filePath)
 {
-    KIO::UntrustedProgramHandlerInterface *untrustedProgramHandler = defaultUntrustedProgramHandler();
+    auto *untrustedProgramHandler = KIO::delegateExtension<KIO::UntrustedProgramHandlerInterface *>(q);
     if (!untrustedProgramHandler) {
         // No way to ask the user to make it executable
         q->setError(KJob::UserDefinedError);
@@ -615,15 +605,15 @@ void KIO::OpenUrlJobPrivate::runUrlWithMimeType()
         return;
     }
 
-    // Shell scripts
-    if (mimeType.inherits(QStringLiteral("application/x-shellscript"))) {
-        handleShellscripts();
+    // Scripts (e.g. .sh, .csh, .py, .js)
+    if (isTextScript(mimeType)) {
+        handleScripts();
         return;
     }
 
-    // Binaries (e.g. /usr/bin/konsole) and .exe files
-    if (isExecutableMime(mimeType)) {
-        handleExecutables(mimeType);
+    // Binaries (e.g. /usr/bin/{konsole,ls}) and .exe files
+    if (isBinary(mimeType)) {
+        handleBinaries(mimeType);
         return;
     }
 
@@ -662,37 +652,37 @@ void KIO::OpenUrlJobPrivate::handleDesktopFiles()
         return;
     }
 
-    if ((cfg.hasApplicationType()
-         || cfg.readType() == QLatin1String("Service")) // for kio_settings
-        && !cfgGroup.readEntry("Exec").isEmpty()) { // type Application or Service
-        if (m_showOpenOrExecuteDialog) { // Show the openOrExecute dialog
-            auto dialogFinished = [this, filePath](bool shouldExecute) {
-                if (shouldExecute) { // Run the file
-                    KService::Ptr service(new KService(filePath));
-                    startService(service, {});
-                    return;
-                }
-                // The user selected "open"
-                openInPreferredApp();
-            };
+    if ((cfg.hasApplicationType() || cfg.readType() == QLatin1String("Service"))) { // kio_settings lets users run Type=Service desktop files
+        KService::Ptr service(new KService(filePath));
+        if (!service->exec().isEmpty()) {
+            if (m_showOpenOrExecuteDialog) { // Show the openOrExecute dialog
+                auto dialogFinished = [this, filePath, service](bool shouldExecute) {
+                    if (shouldExecute) { // Run the file
+                        startService(service, {});
+                        return;
+                    }
+                    // The user selected "open"
+                    openInPreferredApp();
+                };
 
-            showOpenOrExecuteFileDialog(dialogFinished);
-            return;
-        }
+                showOpenOrExecuteFileDialog(dialogFinished);
+                return;
+            }
 
-        if (m_runExecutables) {
-            KService::Ptr service(new KService(filePath));
-            startService(service, {});
-            return;
-        }
+            if (m_runExecutables) {
+                startService(service, {});
+                return;
+            }
+        } // exec is not empty
     } // type Application or Service
 
     // Fallback to opening in the default app
     openInPreferredApp();
 }
 
-void KIO::OpenUrlJobPrivate::handleShellscripts()
+void KIO::OpenUrlJobPrivate::handleScripts()
 {
+    // Executable scripts of any type can run arbitrary shell commands
     if (!KAuthorized::authorize(QStringLiteral("shell_access"))) {
         emitAccessDenied();
         return;
@@ -701,8 +691,7 @@ void KIO::OpenUrlJobPrivate::handleShellscripts()
     const bool isLocal = m_url.isLocalFile();
     const QString localPath = m_url.toLocalFile();
     if (!isLocal || !hasExecuteBit(localPath)) {
-        // Open remote shell scripts or ones without the execute bit, with the
-        // default application
+        // Open remote scripts or ones without the execute bit, with the default application
         openInPreferredApp();
         return;
     }
@@ -720,7 +709,7 @@ void KIO::OpenUrlJobPrivate::handleShellscripts()
         return;
     }
 
-    if (m_runExecutables) { // Local executable shell script, proceed
+    if (m_runExecutables) { // Local executable script, proceed
         executeCommand();
     } else { // Open in the default (text editor) app
         openInPreferredApp();
@@ -746,7 +735,8 @@ void KIO::OpenUrlJobPrivate::showOpenWithDialog()
         return;
     }
 
-    if (!s_openWithHandler || QOperatingSystemVersion::currentType() == QOperatingSystemVersion::Windows) {
+    auto *openWithHandler = KIO::delegateExtension<KIO::OpenWithHandlerInterface *>(q);
+    if (!openWithHandler || QOperatingSystemVersion::currentType() == QOperatingSystemVersion::Windows) {
         // As KDE on windows doesn't know about the windows default applications, offers will be empty in nearly all cases.
         // So we use QDesktopServices::openUrl to let windows decide how to open the file.
         // It's also our fallback if there's no handler to show an open-with dialog.
@@ -758,20 +748,20 @@ void KIO::OpenUrlJobPrivate::showOpenWithDialog()
         return;
     }
 
-    QObject::connect(s_openWithHandler, &KIO::OpenWithHandlerInterface::canceled, q, [this]() {
+    QObject::connect(openWithHandler, &KIO::OpenWithHandlerInterface::canceled, q, [this]() {
         q->setError(KIO::ERR_USER_CANCELED);
         q->emitResult();
     });
 
-    QObject::connect(s_openWithHandler, &KIO::OpenWithHandlerInterface::serviceSelected, q, [this](const KService::Ptr &service) {
+    QObject::connect(openWithHandler, &KIO::OpenWithHandlerInterface::serviceSelected, q, [this](const KService::Ptr &service) {
         startService(service);
     });
 
-    QObject::connect(s_openWithHandler, &KIO::OpenWithHandlerInterface::handled, q, [this]() {
+    QObject::connect(openWithHandler, &KIO::OpenWithHandlerInterface::handled, q, [this]() {
         q->emitResult();
     });
 
-    s_openWithHandler->promptUserForApplication(q, {m_url}, m_mimeTypeName);
+    openWithHandler->promptUserForApplication(q, {m_url}, m_mimeTypeName);
 }
 
 void KIO::OpenUrlJobPrivate::showOpenOrExecuteFileDialog(std::function<void(bool)> dialogFinished)
@@ -779,9 +769,10 @@ void KIO::OpenUrlJobPrivate::showOpenOrExecuteFileDialog(std::function<void(bool
     QMimeDatabase db;
     QMimeType mimeType = db.mimeTypeForName(m_mimeTypeName);
 
-    if (!s_openOrExecuteFileHandler) {
+    auto *openOrExecuteFileHandler = KIO::delegateExtension<KIO::OpenOrExecuteFileInterface *>(q);
+    if (!openOrExecuteFileHandler) {
         // No way to ask the user whether to execute or open
-        if (mimeType.inherits(QStringLiteral("application/x-shellscript"))
+        if (isTextScript(mimeType)
             || mimeType.inherits(QStringLiteral("application/x-desktop"))) { // Open text-based ones in the default app
             openInPreferredApp();
         } else {
@@ -792,18 +783,18 @@ void KIO::OpenUrlJobPrivate::showOpenOrExecuteFileDialog(std::function<void(bool
         return;
     }
 
-    QObject::connect(s_openOrExecuteFileHandler, &KIO::OpenOrExecuteFileInterface::canceled, q, [this]() {
+    QObject::connect(openOrExecuteFileHandler, &KIO::OpenOrExecuteFileInterface::canceled, q, [this]() {
         q->setError(KIO::ERR_USER_CANCELED);
         q->emitResult();
     });
 
-    QObject::connect(s_openOrExecuteFileHandler, &KIO::OpenOrExecuteFileInterface::executeFile,
+    QObject::connect(openOrExecuteFileHandler, &KIO::OpenOrExecuteFileInterface::executeFile,
                      q, [this, dialogFinished](bool shouldExecute) {
         m_runExecutables = shouldExecute;
         dialogFinished(shouldExecute);
     });
 
-    s_openOrExecuteFileHandler->promptUserOpenOrExecute(q, m_mimeTypeName);
+    openOrExecuteFileHandler->promptUserOpenOrExecute(q, m_mimeTypeName);
 }
 
 void KIO::OpenUrlJob::slotResult(KJob *job)
