@@ -1,23 +1,9 @@
 /*
-   Copyright (C) 2000-2002 Stephan Kulow <coolo@kde.org>
-   Copyright (C) 2000-2002 David Faure <faure@kde.org>
-   Copyright (C) 2000-2002 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 Waldo Bastian <bastian@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License (LGPL) as published by the Free Software Foundation;
-   either version 2 of the License, or (at your option) any later
-   version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef __file_h__
@@ -73,6 +59,7 @@ public:
     void write(const QByteArray &data) override;
     void seek(KIO::filesize_t offset) override;
     void truncate(KIO::filesize_t length);
+    bool copyXattrs(const int src_fd, const int dest_fd);
     void close() override;
 
     /**
@@ -94,8 +81,6 @@ protected:
     void virtual_hook(int id, void *data) override;
 
 private:
-    bool createUDSEntry(const QString &filename, const QByteArray &path, KIO::UDSEntry &entry,
-                        short int details);
     int setACL(const char *path, mode_t perm, bool _directoryDefault);
     QString getUserName(KUserId uid) const;
     QString getGroupName(KGroupId gid) const;
@@ -118,11 +103,10 @@ private:
     void closeWithoutFinish();
 
 private:
-    mutable QHash<KUserId, QString> mUsercache;
-    mutable QHash<KGroupId, QString> mGroupcache;
     QFile *mFile;
 
     bool testMode = false;
+    KIO::StatDetails getStatDetails();
 };
 
 #endif
