@@ -1,21 +1,9 @@
-/*  This file is part of the KDE libraries
-    Copyright (C) 2000-2006 David Faure <faure@kde.org>
-    Copyright (C) 2019 Harald Sitter <sitter@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000-2006 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 /*
@@ -52,19 +40,19 @@
 #include <QTcpServer>
 #include <QSslSocket>
 #include <QAuthenticator>
-#include <qmimedatabase.h>
+#include <QMimeDatabase>
 
 #include <QDebug>
 #include <ioslave_defaults.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <kremoteencoding.h>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 
 #include "kioglobal_p.h"
 
 #include <QLoggingCategory>
 Q_DECLARE_LOGGING_CATEGORY(KIO_FTP)
-Q_LOGGING_CATEGORY(KIO_FTP, "kf5.kio.kio_ftp", QtWarningMsg)
+Q_LOGGING_CATEGORY(KIO_FTP, "kf.kio.slaves.ftp", QtWarningMsg)
 
 #if HAVE_STRTOLL
 #define charToLongLong(a) strtoll(a, nullptr, 10)
@@ -317,7 +305,11 @@ void FtpInternal::setHost(const QString &_host, quint16 _port, const QString &_u
     qCDebug(KIO_FTP) << _host << "port=" << _port << "user=" << _user;
 
     m_proxyURL.clear();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     m_proxyUrls = q->mapConfig().value(QStringLiteral("ProxyUrls"), QString()).toString().split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+    m_proxyUrls = q->mapConfig().value(QStringLiteral("ProxyUrls"), QString()).toString().split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
     qCDebug(KIO_FTP) << "proxy urls:" << m_proxyUrls;
 
     if (m_host != _host || m_port != _port ||
@@ -364,7 +356,7 @@ Result FtpInternal::ftpOpenConnection(LoginMode loginMode)
     q->infoMessage(i18n("Connected to host %1", m_host));
 
     bool userNameChanged = false;
-    if (loginMode != LoginMode::Defered) {
+    if (loginMode != LoginMode::Deferred) {
         const Result result = ftpLogin(&userNameChanged);
         m_bLoggedOn = result.success;
         if (!m_bLoggedOn) {
@@ -475,11 +467,7 @@ Result FtpInternal::ftpOpenControlConnection(const QString &host, int port)
             iErrorCode = ERR_CANNOT_CONNECT;
         }
     } else {
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
         const auto socketError = m_control->error();
-#else
-        const auto socketError = m_control->socketError();
-#endif
         if (socketError == QAbstractSocket::HostNotFoundError) {
             iErrorCode = ERR_UNKNOWN_HOST;
         }
@@ -694,7 +682,7 @@ Result FtpInternal::ftpLogin(bool *userChanged)
     const int iEnd = sTmp.lastIndexOf(QLatin1Char('"'));
     if (iBeg > 0 && iBeg < iEnd) {
         m_initialPath = sTmp.mid(iBeg + 1, iEnd - iBeg - 1);
-        if (m_initialPath[0] != QLatin1Char('/')) {
+        if (!m_initialPath.startsWith(QLatin1Char('/'))) {
             m_initialPath.prepend(QLatin1Char('/'));
         }
         qCDebug(KIO_FTP) << "Initial path set to: " << m_initialPath;
@@ -712,11 +700,19 @@ void FtpInternal::ftpAutoLoginMacro()
         return;
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList list = macro.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#else
+    const QStringList list = macro.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#endif
 
     for (QStringList::const_iterator it = list.begin(); it != list.end(); ++it) {
         if ((*it).startsWith(QLatin1String("init"))) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             const QStringList list2 = macro.split(QLatin1Char('\\'), QString::SkipEmptyParts);
+#else
+            const QStringList list2 = macro.split(QLatin1Char('\\'), Qt::SkipEmptyParts);
+#endif
             it = list2.begin();
             ++it;  // ignore the macro name
 
@@ -754,13 +750,6 @@ bool FtpInternal::ftpSendCmd(const QByteArray &cmd, int maxretries)
 
     // Don't print out the password...
     bool isPassCmd = (cmd.left(4).toLower() == "pass");
-#if 0
-    if (!isPassCmd) {
-        qDebug() << "send> " << cmd.data();
-    } else {
-        qDebug() << "send> pass [protected]";
-    }
-#endif
 
     // Send the message...
     const QByteArray buf = cmd + "\r\n";      // Yes, must use CR/LF - see http://cr.yp.to/ftp/request.html
@@ -787,7 +776,7 @@ bool FtpInternal::ftpSendCmd(const QByteArray &cmd, int maxretries)
             // the beginning...
             if (maxretries > 0 && !isPassCmd) {
                 closeConnection();
-                const auto result = ftpOpenConnection(LoginMode::Defered);
+                const auto result = ftpOpenConnection(LoginMode::Deferred);
                 if (result.success && ftpSendCmd(cmd, maxretries - 1)) {
                     return true;
                 }
@@ -1280,6 +1269,7 @@ void FtpInternal::ftpCreateUDSEntry(const QString &filename, const FtpEntry &ftp
 {
     Q_ASSERT(entry.count() == 0); // by contract :-)
 
+    entry.reserve(9);
     entry.fastInsert(KIO::UDSEntry::UDS_NAME, filename);
     entry.fastInsert(KIO::UDSEntry::UDS_SIZE, ftpEnt.size);
     entry.fastInsert(KIO::UDSEntry::UDS_MODIFICATION_TIME, ftpEnt.date.toSecsSinceEpoch());
@@ -1296,10 +1286,10 @@ void FtpInternal::ftpCreateUDSEntry(const QString &filename, const FtpEntry &ftp
         QMimeType mime = db.mimeTypeForUrl(QUrl(QLatin1String("ftp://host/") + filename));
         // Links on ftp sites are often links to dirs, and we have no way to check
         // that. Let's do like Netscape : assume dirs generally.
-        // But we do this only when the mimetype can't be known from the filename.
+        // But we do this only when the MIME type can't be known from the filename.
         // --> we do better than Netscape :-)
         if (mime.isDefault()) {
-            qCDebug(KIO_FTP) << "Setting guessed mime type to inode/directory for " << filename;
+            qCDebug(KIO_FTP) << "Setting guessed MIME type to inode/directory for " << filename;
             entry.fastInsert(KIO::UDSEntry::UDS_GUESSED_MIME_TYPE, QStringLiteral("inode/directory"));
             isDir = true;
         }
@@ -1314,6 +1304,7 @@ void FtpInternal::ftpShortStatAnswer(const QString &filename, bool isDir)
 {
     UDSEntry entry;
 
+    entry.reserve(4);
     entry.fastInsert(KIO::UDSEntry::UDS_NAME, filename);
     entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, isDir ? S_IFDIR : S_IFREG);
     entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
@@ -1361,6 +1352,7 @@ Result FtpInternal::stat(const QUrl &url)
     // We can't stat root, but we know it's a dir.
     if (path.isEmpty() || path == QLatin1String("/")) {
         UDSEntry entry;
+        entry.reserve(6);
         //entry.insert( KIO::UDSEntry::UDS_NAME, UDSField( QString() ) );
         entry.fastInsert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
         entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
@@ -1706,7 +1698,7 @@ bool FtpInternal::ftpReadDir(FtpEntry &de)
                     de.link.clear();
                 }
 
-                if (tmp[0] == '/') { // listing on ftp://ftp.gnupg.org/ starts with '/'
+                if (tmp.startsWith('/')) { // listing on ftp://ftp.gnupg.org/ starts with '/'
                     tmp.remove(0, 1);
                 }
 
@@ -1899,7 +1891,7 @@ Result FtpInternal::ftpGet(int iCopyFile, const QString &sCopyFile, const QUrl &
         }
     }
 
-    // Send the mime-type...
+    // Send the MIME type...
     if (iCopyFile == -1) {
         const auto result = ftpSendMimeType(url);
         if (!result.success) {
@@ -1983,71 +1975,6 @@ Result FtpInternal::ftpGet(int iCopyFile, const QString &sCopyFile, const QUrl &
     return Result::pass();
 }
 
-#if 0
-void FtpInternal::mimetype(const QUrl &url)
-{
-    if (!ftpOpenConnection(loginImplicit)) {
-        return;
-    }
-
-    if (!ftpOpenCommand("retr", url.path(), 'I', ERR_CANNOT_OPEN_FOR_READING, 0)) {
-        qCWarning(KIO_FTP) << "Can't open for reading";
-        return;
-    }
-    char buffer[ 2048 ];
-    QByteArray array;
-    // Get one chunk of data only and send it, KIO::Job will determine the
-    // mimetype from it using KMimeMagic
-    int n = m_data->read(buffer, 2048);
-    array.setRawData(buffer, n);
-    data(array);
-    array.resetRawData(buffer, n);
-
-    qCDebug(KIO_FTP) << "aborting";
-    ftpAbortTransfer();
-
-    qCDebug(KIO_FTP) << "finished";
-    finished();
-    qCDebug(KIO_FTP) << "after finished";
-}
-
-void FtpInternal::ftpAbortTransfer()
-{
-    // RFC 959, page 34-35
-    // IAC (interpret as command) = 255 ; IP (interrupt process) = 254
-    // DM = 242 (data mark)
-    char msg[4];
-    // 1. User system inserts the Telnet "Interrupt Process" (IP) signal
-    //   in the Telnet stream.
-    msg[0] = (char) 255; //IAC
-    msg[1] = (char) 254; //IP
-    (void) send(sControl, msg, 2, 0);
-    // 2. User system sends the Telnet "Sync" signal.
-    msg[0] = (char) 255; //IAC
-    msg[1] = (char) 242; //DM
-    if (send(sControl, msg, 2, MSG_OOB) != 2)
-        ; // error...
-
-    // Send ABOR
-    qCDebug(KIO_FTP) << "send ABOR";
-    QCString buf = "ABOR\r\n";
-    if (KSocks::self()->write(sControl, buf.data(), buf.length()) <= 0)  {
-        error(ERR_CANNOT_WRITE, QString());
-        return;
-    }
-
-    //
-    qCDebug(KIO_FTP) << "read resp";
-    if (readresp() != '2') {
-        error(ERR_CANNOT_READ, QString());
-        return;
-    }
-
-    qCDebug(KIO_FTP) << "close sockets";
-    closeSockets();
-}
-#endif
-
 //===============================================================================
 // public: put           upload file to server
 // helper: ftpPut        called from put() and copy()
@@ -2530,8 +2457,8 @@ Result FtpInternal::ftpSendMimeType(const QUrl &url)
     if (!buffer.isEmpty()) {
         QMimeDatabase db;
         QMimeType mime = db.mimeTypeForFileNameAndData(url.path(), buffer);
-        qCDebug(KIO_FTP) << "Emitting mimetype" << mime.name();
-        q->mimeType(mime.name()); // emit the mime type...
+        qCDebug(KIO_FTP) << "Emitting MIME type" << mime.name();
+        q->mimeType(mime.name()); // emit the MIME type...
     }
 
     return Result::pass();
@@ -2597,11 +2524,7 @@ ConnectionResult FtpInternal::synchronousConnectToHost(const QString &host, quin
     socket->setProxy(proxy);
     socket->connectToHost(host, port);
     socket->waitForConnected(q->connectTimeout() * 1000);
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
     const auto socketError = socket->error();
-#else
-    const auto socketError = socket->socketError();
-#endif
      if (socketError == QAbstractSocket::ProxyAuthenticationRequiredError) {
         AuthInfo info;
         info.url = proxyUrl;
