@@ -1,20 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2008, 2009 Andreas Hartmetz <ahartmetz@gmail.com>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2008, 2009 Andreas Hartmetz <ahartmetz@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "httpauthentication.h"
@@ -34,16 +22,16 @@
 
 #endif /* HAVE_LIBGSSAPI */
 
-#include <krandom.h>
+#include <KRandom>
 #include <QDebug>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #include <kio/authinfo.h>
 #include <kntlm.h>
 
 #include <QTextCodec>
 #include <QCryptographicHash>
 
-Q_LOGGING_CATEGORY(KIO_HTTP_AUTH, "kf5.kio.kio_http.auth")
+Q_LOGGING_CATEGORY(KIO_HTTP_AUTH, "kf.kio.slaves.http.auth")
 
 static bool isWhiteSpace(char ch)
 {
