@@ -1,27 +1,11 @@
-/* This file is part of the KDE File Manager
+/*
+    This file is part of the KDE File Manager
+    SPDX-FileCopyrightText: 1998-2000 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Dawit Alemayehu <adawit@kde.org>
 
-   Copyright (C) 1998-2000 Waldo Bastian (bastian@kde.org)
-   Copyright (C) 2000,2001 Dawit Alemayehu (adawit@kde.org)
-
-   Permission is hereby granted, free of charge, to any person obtaining a copy
-   of this software and associated documentation files (the "Software"), to deal
-   in the Software without restriction, including without limitation the rights
-   to use, copy, modify, merge, publish, distribute, and/or sell copies of the
-   Software, and to permit persons to whom the Software is furnished to do so,
-   subject to the following conditions:
-
-   The above copyright notice and this permission notice shall be included in
-   all copies or substantial portions of the Software.
-
-   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
-   AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-   ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-   WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+    SPDX-License-Identifier: MIT
 */
-//----------------------------------------------------------------------------
-//
+
 // KDE File Manager -- HTTP Cookies
 
 //
@@ -36,9 +20,9 @@
 
 #include "kcookiejar.h"
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <qsavefile.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <QSaveFile>
 #include <QDebug>
 
 #include <QString>
@@ -48,7 +32,7 @@
 #include <QLocale>
 #include <QUrl>
 
-Q_LOGGING_CATEGORY(KIO_COOKIEJAR, "kf5.kio.cookiejar")
+Q_LOGGING_CATEGORY(KIO_COOKIEJAR, "kf.kio.slaves.http.cookiejar")
 
 // BR87227
 // Waba: Should the number of cookies be limited?
@@ -154,7 +138,7 @@ KCookieAdvice KCookieJar::strToAdvice(const QString &_str)
         return KCookieDunno;
     }
 
-    QString advice = _str.toLower();
+    QString advice = _str.toLower().remove(QLatin1Char(' '));
 
     if (advice == QL1S("accept")) {
         return KCookieAccept;
@@ -311,8 +295,11 @@ KCookieJar::KCookieJar()
 
     KConfig cfg(QStringLiteral("kf5/kcookiejar/domain_info"), KConfig::NoGlobals, QStandardPaths::GenericDataLocation);
     KConfigGroup group(&cfg, QString());
-    m_gTLDs = QSet<QString>::fromList(group.readEntry("gTLDs", QStringList()));
-    m_twoLevelTLD = QSet<QString>::fromList(group.readEntry("twoLevelTLD", QStringList()));
+
+    const QStringList tldList = group.readEntry("gTLDs", QStringList());
+    const QStringList twoLevelTldList = group.readEntry("twoLevelTLD", QStringList());
+    m_gTLDs = QSet<QString>(tldList.begin(), tldList.end());
+    m_twoLevelTLD = QSet<QString>(twoLevelTldList.begin(), twoLevelTldList.end());
 }
 
 //
@@ -969,9 +956,7 @@ void KCookieJar::addCookie(KHttpCookie &cookie)
         }
     }
 
-    QStringListIterator it(domains);
-    while (it.hasNext()) {
-        const QString &key = it.next();
+    for (const QString &key : qAsConst(domains)) {
         KHttpCookieList *list;
 
         if (key.isNull()) {
@@ -1322,12 +1307,11 @@ bool KCookieJar::saveCookies(const QString &_filename)
               "Name", "Sec", "Value");
     ts << str;
 
-    QStringListIterator it(m_domainList);
-    while (it.hasNext()) {
-        const QString &domain = it.next();
+
+    for (const QString &domainName : qAsConst(m_domainList)) {
         bool domainPrinted = false;
 
-        KHttpCookieList *cookieList = m_cookieDomains.value(domain);
+        KHttpCookieList *cookieList = m_cookieDomains.value(domainName);
         if (!cookieList) {
             continue;
         }
@@ -1345,7 +1329,7 @@ bool KCookieJar::saveCookies(const QString &_filename)
                 // Only save cookies that are not "session-only cookies"
                 if (!domainPrinted) {
                     domainPrinted = true;
-                    ts << '[' << domain.toLocal8Bit().data() << "]\n";
+                    ts << '[' << domainName.toLocal8Bit().data() << "]\n";
                 }
                 // Store persistent cookies
                 const QString path = QL1C('"') + cookie.path() + QL1C('"');
@@ -1551,9 +1535,7 @@ void KCookieJar::saveConfig(KConfig *_config)
     policyGroup.writeEntry("CookieGlobalAdvice", adviceToStr(m_globalAdvice));
 
     QStringList domainSettings;
-    QStringListIterator it(m_domainList);
-    while (it.hasNext()) {
-        const QString &domain = it.next();
+    for (const QString &domain : qAsConst(m_domainList)) {
         KCookieAdvice advice = getDomainAdvice(domain);
         if (advice != KCookieDunno) {
             const QString value = domain + QL1C(':') + adviceToStr(advice);
