@@ -13,13 +13,11 @@
 
 #include <QTimer>
 #include <QFile>
-#include <QDBusConnection>
 
 #include <KConfig>
 #include <QDebug>
 
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KLocalizedString>
 #include <kwindowsystem.h>
 #include <QStandardPaths>
