@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Tobias Koenig <tokoe@kde.org>                   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Tobias Koenig <tokoe@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kcmtrash.h"
 #include "discspaceutil.h"
@@ -29,13 +16,12 @@
 #include <QListWidget>
 #include <QListWidgetItem>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 #include <KLocalizedString>
-#include <qdialog.h>
-#include <qicon.h>
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
+#include <QDialog>
+#include <QIcon>
+#include <KPluginFactory>
 #include <KFormat>
 #include <QSpinBox>
 
@@ -284,8 +270,8 @@ void TrashConfigModule::setupGui()
 
 
     mPercent = new QDoubleSpinBox(this);
-    mPercent->setRange(0.001, 100);
-    mPercent->setDecimals(3);
+    mPercent->setRange(0.01, 100);
+    mPercent->setDecimals(2);
     mPercent->setSingleStep(1);
     mPercent->setSuffix(QStringLiteral(" %"));
     mPercent->setWhatsThis(xi18nc("@info:whatsthis",
