@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2004 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kio_trash.h"
@@ -284,7 +272,7 @@ void TrashProtocol::copyOrMoveToTrash(const QUrl &src, const QUrl &dest, CopyOrM
 
 void TrashProtocol::createTopLevelDirEntry(KIO::UDSEntry &entry)
 {
-    entry.clear();
+    entry.reserve(entry.count() + 8);
     entry.fastInsert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
     entry.fastInsert(KIO::UDSEntry::UDS_DISPLAY_NAME, i18n("Trash"));
     entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
@@ -295,13 +283,32 @@ void TrashProtocol::createTopLevelDirEntry(KIO::UDSEntry &entry)
     entry.fastInsert(KIO::UDSEntry::UDS_GROUP, m_groupName);
 }
 
+KIO::StatDetails TrashProtocol::getStatDetails()
+{
+    // takes care of converting old metadata details to new StatDetails
+    // TODO KF6 : remove legacy "details" code path
+    KIO::StatDetails details;
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
+    if (hasMetaData(QStringLiteral("statDetails"))) {
+#endif
+        const QString statDetails = metaData(QStringLiteral("statDetails"));
+        details = statDetails.isEmpty() ? KIO::StatDefaultDetails : static_cast<KIO::StatDetails>(statDetails.toInt());
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
+    } else {
+        const QString sDetails = metaData(QStringLiteral("details"));
+        details = sDetails.isEmpty() ? KIO::StatDefaultDetails : KIO::detailsToStatDetails(sDetails.toInt());
+    }
+#endif
+    return details;
+}
+
 void TrashProtocol::stat(const QUrl &url)
 {
     INIT_IMPL;
     const QString path = url.path();
     if (path.isEmpty() || path == QLatin1String("/")) {
         // The root is "virtual" - it's not a single physical directory
-        KIO::UDSEntry entry;
+        KIO::UDSEntry entry = impl.trashUDSEntry(getStatDetails());
         createTopLevelDirEntry(entry);
         statEntry(entry);
         finished();
@@ -346,7 +353,7 @@ void TrashProtocol::stat(const QUrl &url)
         }
 
         if (!ok) {
-            error(KIO::ERR_COULD_NOT_STAT, url.toString());
+            error(KIO::ERR_CANNOT_STAT, url.toString());
             return;
         }
 
@@ -418,9 +425,7 @@ void TrashProtocol::listDir(const QUrl &url)
     const QStringList entryNames = impl.listDir(info.physicalPath);
     totalSize(entryNames.count());
     KIO::UDSEntry entry;
-    for (QStringList::const_iterator entryIt = entryNames.begin(), entryEnd = entryNames.end();
-            entryIt != entryEnd; ++entryIt) {
-        const QString fileName = *entryIt;
+    for (const QString &fileName : entryNames) {
         if (fileName == QLatin1String("..")) {
             continue;
         }
@@ -440,10 +445,12 @@ void TrashProtocol::listDir(const QUrl &url)
 
 bool TrashProtocol::createUDSEntry(const QString &physicalPath, const QString &displayFileName, const QString &internalFileName, KIO::UDSEntry &entry, const TrashedFileInfo &info)
 {
+    entry.reserve(13);
     QByteArray physicalPath_c = QFile::encodeName(physicalPath);
     QT_STATBUF buff;
     if (QT_LSTAT(physicalPath_c.constData(), &buff) == -1) {
-        qCWarning(KIO_TRASH) << "couldn't stat " << physicalPath;
+        qCWarning(KIO_TRASH) << "couldn't stat " << physicalPath << ", relevant trashinfo file will be removed";
+        impl.deleteInfo(info.trashId, info.fileId);
         return false;
     }
     if (S_ISLNK(buff.st_mode)) {
@@ -502,12 +509,12 @@ void TrashProtocol::listRoot()
     KIO::UDSEntry entry;
     createTopLevelDirEntry(entry);
     listEntry(entry);
-    for (TrashedFileInfoList::ConstIterator it = lst.begin(); it != lst.end(); ++it) {
-        const QUrl url = TrashImpl::makeURL((*it).trashId, (*it).fileId, QString());
+    for (const TrashedFileInfo &fileInfo : lst) {
+        const QUrl url = TrashImpl::makeURL(fileInfo.trashId, fileInfo.fileId, QString());
         entry.clear();
-        const QString fileDisplayName = (*it).fileId;
+        const QString fileDisplayName = fileInfo.fileId;
 
-        if (createUDSEntry((*it).physicalPath, fileDisplayName, url.fileName(), entry, *it)) {
+        if (createUDSEntry(fileInfo.physicalPath, fileDisplayName, url.fileName(), entry, fileInfo)) {
             listEntry(entry);
         }
     }
@@ -589,7 +596,7 @@ void TrashProtocol::get(const QUrl &url)
     KIO::TransferJob *job = KIO::get(fileURL, KIO::NoReload, KIO::HideProgressInfo);
     connect(job, &KIO::TransferJob::data,
             this, &TrashProtocol::slotData);
-    connect(job,  QOverload<KIO::Job*,const QString&>::of(&KIO::TransferJob::mimetype),
+    connect(job,  &KIO::TransferJob::mimeTypeFound,
             this, &TrashProtocol::slotMimetype);
     connect(job, &KJob::result,
             this, &TrashProtocol::jobFinished);
@@ -667,7 +674,7 @@ void TrashProtocol::fileSystemFreeSpace(const QUrl &url)
 
     TrashImpl::TrashSpaceInfo spaceInfo;
     if (!impl.trashSpaceInfo(url.path(), spaceInfo)) {
-        error(KIO::ERR_COULD_NOT_STAT, url.toDisplayString());
+        error(KIO::ERR_CANNOT_STAT, url.toDisplayString());
         return;
     }
 
