@@ -1,25 +1,13 @@
-/* This file is part of the KDE project
-   Copyright (C) 2004 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "testtrash.h"
 
-#include <qtest.h>
+#include <QTest>
 
 #include "kio_trash.h"
 #include "../../../pathhelpers_p.h"
@@ -32,13 +20,13 @@
 #include <kio/copyjob.h>
 #include <kio/deletejob.h>
 #include <QDebug>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 
 #include <QDir>
 #include <QUrl>
 #include <QFileInfo>
 #include <QVector>
-#include <kjobuidelegate.h>
+#include <KJobUiDelegate>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -170,7 +158,7 @@ void TestTrash::initTestCase()
     QVector<int> writableTopDirs;
     for (TrashImpl::TrashDirMap::ConstIterator it = trashDirs.constBegin(); it != trashDirs.constEnd(); ++it) {
         if (it.key() == 0) {
-            QVERIFY(it.value() == m_trashDir);
+            QCOMPARE(it.value(), m_trashDir);
             QVERIFY(topDirs.find(0) == topDirs.end());
             foundTrashDir = true;
         } else {
@@ -340,7 +328,7 @@ void TestTrash::trashFile(const QString &origFilePath, const QString &fileId)
 
         QFileInfo files(m_trashDir + QLatin1String("/files/") + fileId);
         QVERIFY(files.isFile());
-        QVERIFY(files.size() == 12);
+        QCOMPARE(files.size(), 12);
     }
 
     // coolo suggests testing that the original file is actually gone, too :)
@@ -355,7 +343,7 @@ void TestTrash::trashFile(const QString &origFilePath, const QString &fileId)
             QUrl trashURL(it.value());
             qDebug() << trashURL;
             QVERIFY(!trashURL.isEmpty());
-            QVERIFY(trashURL.scheme() == QLatin1String("trash"));
+            QCOMPARE(trashURL.scheme(), QLatin1String("trash"));
             int trashId = 0;
             if (origFilePath.startsWith(QLatin1String("/tmp")) && m_tmpIsWritablePartition) {
                 trashId = m_tmpTrashId;
@@ -401,7 +389,7 @@ void TestTrash::testTrashNotEmpty()
     KConfig cfg(QStringLiteral("trashrc"), KConfig::SimpleConfig);
     const KConfigGroup group = cfg.group("Status");
     QVERIFY(group.exists());
-    QVERIFY(group.readEntry("Empty", true) == false);
+    QCOMPARE(group.readEntry("Empty", true), false);
 }
 
 void TestTrash::trashFileFromOther()
@@ -439,7 +427,7 @@ void TestTrash::trashFileIntoOtherPartition()
 
     QFileInfo files(m_otherPartitionTrashDir + QLatin1String("/files/") + fileId);
     QVERIFY(files.isFile());
-    QVERIFY(files.size() == 12);
+    QCOMPARE(files.size(), 12);
 
     // coolo suggests testing that the original file is actually gone, too :)
     QVERIFY(!QFile::exists(origFilePath));
@@ -452,8 +440,8 @@ void TestTrash::trashFileIntoOtherPartition()
             QUrl trashURL(it.value());
             qDebug() << trashURL;
             QVERIFY(!trashURL.isEmpty());
-            QVERIFY(trashURL.scheme() == QLatin1String("trash"));
-            QVERIFY(trashURL.path() == QStringLiteral("/%1-%2").arg(m_otherPartitionId).arg(fileId));
+            QCOMPARE(trashURL.scheme(), QLatin1String("trash"));
+            QCOMPARE(trashURL.path(), QStringLiteral("/%1-%2").arg(m_otherPartitionId).arg(fileId));
             found = true;
         }
     }
@@ -474,7 +462,7 @@ void TestTrash::trashFileOwnedByRoot()
     bool ok = job->exec();
     QVERIFY(!ok);
 
-    QVERIFY(job->error() == KIO::ERR_ACCESS_DENIED);
+    QCOMPARE(job->error(), KIO::ERR_ACCESS_DENIED);
     const QString infoPath(m_trashDir + QLatin1String("/info/") + fileId + QLatin1String(".trashinfo"));
     QVERIFY(!QFile::exists(infoPath));
 
@@ -504,7 +492,7 @@ void TestTrash::trashSymlink(const QString &origFilePath, const QString &fileId,
 
     QFileInfo files(m_trashDir + QLatin1String("/files/") + fileId);
     QVERIFY(files.isSymLink());
-    QVERIFY(files.symLinkTarget() == QFile::decodeName(target));
+    QCOMPARE(files.symLinkTarget(), QFile::decodeName(target));
     QVERIFY(!QFile::exists(origFilePath));
 }
 
@@ -554,7 +542,7 @@ void TestTrash::trashDirectory(const QString &origPath, const QString &fileId)
     QFileInfo files(m_trashDir + QLatin1String("/files/") + fileId + QLatin1String("/testfile"));
     QVERIFY(files.exists());
     QVERIFY(files.isFile());
-    QVERIFY(files.size() == 12);
+    QCOMPARE(files.size(), 12);
     QVERIFY(!QFile::exists(origPath));
     QVERIFY(QFile::exists(m_trashDir + QStringLiteral("/files/") + fileId + QStringLiteral("/subdir/subfile")));
 
@@ -586,8 +574,21 @@ void TestTrash::checkDirCacheValidity()
         QVERIFY(line.endsWith('\n'));
         line.chop(1);
         qDebug() << "LINE" << line;
-        const int lastSpace = line.lastIndexOf(' ');
-        const QByteArray dir = QByteArray::fromPercentEncoding(line.mid(lastSpace + 1));
+
+        const auto exploded = line.split(' ');
+        QCOMPARE(exploded.size(), 3);
+
+        bool succeeded = false;
+        const int size = exploded.at(0).toInt(&succeeded);
+        QVERIFY(succeeded);
+        QVERIFY(size > 0);
+
+        const int mtime = exploded.at(0).toInt(&succeeded);
+        QVERIFY(succeeded);
+        QVERIFY(mtime > 0);
+        QVERIFY(QDateTime::fromMSecsSinceEpoch(mtime).isValid());
+
+        const QByteArray dir = QByteArray::fromPercentEncoding(exploded.at(2));
         QVERIFY2(!seenDirs.contains(dir), dir.constData());
         seenDirs.insert(dir);
         const QString localDir = m_trashDir + QLatin1String("/files/") + QFile::decodeName(dir);
@@ -600,6 +601,7 @@ void TestTrash::trashDirectoryFromHome()
 {
     QString dirName = QStringLiteral("trashDirFromHome");
     trashDirectory(homeTmpDir() + dirName, dirName);
+    checkDirCacheValidity();
     // Do it again, check that we got a different id
     trashDirectory(homeTmpDir() + dirName, dirName + QLatin1String(" (1)"));
 }
@@ -655,6 +657,30 @@ void TestTrash::trashBrokenSymlinkIntoSubdir()
     trashDirectory(origPath, QStringLiteral("subDirBrokenSymlink"));
 }
 
+void TestTrash::testRemoveStaleInfofile()
+{
+    const QString fileName = QStringLiteral("disappearingFileInTrash");
+    const QString filePath = homeTmpDir() + fileName;
+    createTestFile(filePath);
+    trashFile(filePath, fileName);
+
+    const QString pathInTrash = m_trashDir + QLatin1String("/files/") + QLatin1String("disappearingFileInTrash");
+    // remove the file without using KIO
+    QVERIFY(QFile::remove(pathInTrash));
+
+    // .trashinfo file still exists
+    const QString infoPath = m_trashDir + QLatin1String("/info/disappearingFileInTrash.trashinfo");
+    QVERIFY(QFile(infoPath).exists());
+
+    KIO::ListJob *job = KIO::listDir(QUrl(QStringLiteral("trash:/")), KIO::HideProgressInfo);
+    connect(job, &KIO::ListJob::entries, this, &TestTrash::slotEntries);
+    QVERIFY(job->exec());
+
+    // during the list job, kio_trash should have deleted the .trashinfo file since it
+    // references a trashed file that doesn't exist any more
+    QVERIFY(!QFile(infoPath).exists());
+}
+
 void TestTrash::delRootFile()
 {
     // test deleting a trashed file
@@ -678,7 +704,7 @@ void TestTrash::delFileInDirectory()
     KIO::Job *delJob = KIO::del(QUrl(QStringLiteral("trash:/0-trashDirFromHome/testfile")), KIO::HideProgressInfo);
     bool ok = delJob->exec();
     QVERIFY(!ok);
-    QVERIFY(delJob->error() == KIO::ERR_ACCESS_DENIED);
+    QCOMPARE(delJob->error(), KIO::ERR_ACCESS_DENIED);
 
     QFileInfo dir(m_trashDir + QLatin1String("/files/trashDirFromHome"));
     QVERIFY(dir.exists());
@@ -702,6 +728,8 @@ void TestTrash::delDirectory()
     QFileInfo info(m_trashDir + QLatin1String("/info/trashDirFromHome.trashinfo"));
     QVERIFY(!info.exists());
 
+    checkDirCacheValidity();
+
     // trash it again, we'll need it later
     QString dirName = QStringLiteral("trashDirFromHome");
     trashDirectory(homeTmpDir() + dirName, dirName);
@@ -722,6 +750,22 @@ static bool MyNetAccess_exists(const QUrl &url)
     return MyNetAccess_stat(url, dummy);
 }
 
+void TestTrash::mostLocalUrlTest()
+{
+    const QStringList trashFiles = QDir(m_trashDir + QLatin1String("/files/")).entryList();
+    for (const QString &file : trashFiles) {
+        if (file == QLatin1Char('.') || file == QLatin1String("..")) {
+            continue;
+        }
+        QUrl url;
+        url.setScheme(QStringLiteral("trash"));
+        url.setPath(QLatin1String("0-") + file);
+        KIO::StatJob *statJob = KIO::mostLocalUrl(url, KIO::HideProgressInfo);
+        QVERIFY(statJob->exec());
+        QCOMPARE(url, statJob->mostLocalUrl());
+    }
+}
+
 void TestTrash::statRoot()
 {
     QUrl url(QStringLiteral("trash:/"));
@@ -844,7 +888,7 @@ void TestTrash::copyFileFromTrash()
     const QString destPath = otherTmpDir() + QString::fromLatin1("fileFromHome_copied");
     copyFromTrash("fileFromHome", destPath);
     QVERIFY(QFileInfo(destPath).isFile());
-    QVERIFY(QFileInfo(destPath).size() == 12);
+    QCOMPARE(QFileInfo(destPath).size(), 12);
 #endif
 }
 
@@ -853,7 +897,7 @@ void TestTrash::copyFileInDirectoryFromTrash()
     const QString destPath = otherTmpDir() + QLatin1String("testfile_copied");
     copyFromTrash(QStringLiteral("trashDirFromHome"), destPath, QStringLiteral("testfile"));
     QVERIFY(QFileInfo(destPath).isFile());
-    QVERIFY(QFileInfo(destPath).size() == 12);
+    QCOMPARE(QFileInfo(destPath).size(), 12);
     QVERIFY(QFileInfo(destPath).isWritable());
 }
 
@@ -1009,7 +1053,7 @@ void TestTrash::moveFileInDirectoryFromTrash()
     const QString destPath = otherTmpDir() + QStringLiteral("testfile_restored");
     copyFromTrash(QStringLiteral("trashDirFromHome"), destPath, QStringLiteral("testfile"));
     QVERIFY(QFileInfo(destPath).isFile());
-    QVERIFY(QFileInfo(destPath).size() == 12);
+    QCOMPARE(QFileInfo(destPath).size(), 12);
 }
 
 void TestTrash::moveDirectoryFromTrash()
@@ -1065,6 +1109,18 @@ void TestTrash::moveSymlinkFromTrash()
     QVERIFY(QFileInfo(destPath).isSymLink());
 }
 
+void TestTrash::testMoveNonExistingFile()
+{
+    const QUrl dest = QUrl::fromLocalFile(homeTmpDir() + QLatin1String("DoesNotExist"));
+    KIO::Job *job =
+        KIO::file_move(QUrl(QStringLiteral("trash:/0-DoesNotExist")), dest, -1, KIO::HideProgressInfo);
+
+    QVERIFY(!job->exec());
+    QCOMPARE(job->error(), KIO::ERR_DOES_NOT_EXIST);
+    QCOMPARE(job->errorString(), QStringLiteral("The file or folder trash:/DoesNotExist does not exist."));
+
+}
+
 void TestTrash::getFile()
 {
     const QString fileId = QStringLiteral("fileFromHome (1)");
@@ -1129,7 +1185,7 @@ void TestTrash::restoreFileFromSubDir()
     bool ok = job->exec();
     QVERIFY(!ok);
     // dest dir doesn't exist -> error message
-    QVERIFY(job->error() == KIO::ERR_SLAVE_DEFINED);
+    QCOMPARE(job->error(), KIO::ERR_SLAVE_DEFINED);
 
     // check that nothing happened
     QVERIFY(QFile::exists(infoFile));
@@ -1163,7 +1219,7 @@ void TestTrash::restoreFileToDeletedDirectory()
     bool ok = job->exec();
     QVERIFY(!ok);
     // dest dir doesn't exist -> error message
-    QVERIFY(job->error() == KIO::ERR_SLAVE_DEFINED);
+    QCOMPARE(job->error(), KIO::ERR_SLAVE_DEFINED);
 
     // check that nothing happened
     QVERIFY(QFile::exists(infoFile));
@@ -1251,7 +1307,7 @@ void TestTrash::slotEntries(KIO::Job *, const KIO::UDSEntryList &lst)
         QUrl url(entry.stringValue(KIO::UDSEntry::UDS_URL));
         qDebug() << "name" << name << "displayName" << displayName << " UDS_URL=" << url;
         if (!url.isEmpty()) {
-            QVERIFY(url.scheme() == QStringLiteral("trash"));
+            QCOMPARE(url.scheme(), QStringLiteral("trash"));
         }
         m_listResult << name;
         m_displayNameListResult << displayName;
