@@ -1,22 +1,8 @@
 /*
-   kproxydlg.cpp - Proxy configuration dialog
+    kproxydlg.cpp - Proxy configuration dialog
+    SPDX-FileCopyrightText: 2001, 2011 Dawit Alemayehu <adawit@kde.org>
 
-   Copyright (C) 2001, 2011 Dawit Alemayehu <adawit@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License (GPL) version 2 as published by the Free Software
-   Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 // Own
@@ -26,10 +12,10 @@
 #include "ksaveioconfig.h"
 
 // KDE
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 #include <KLineEdit>
 #include <KLocalizedString>
-#include <kmessagebox.h>
+#include <KMessageBox>
 #include <kurifilter.h>
 
 // Qt
@@ -122,7 +108,7 @@ static QString proxyUrlFromInput(KProxyDialog::DisplayUrlFlags* flags,
         data.setDefaultUrlScheme(defaultScheme);
     }
 
-    if (KUriFilter::self()->filterUri(data, QStringList() << QStringLiteral("kshorturifilter"))) {
+    if (KUriFilter::self()->filterUri(data, QStringList{QStringLiteral("kshorturifilter")})) {
         QUrl url = data.uri();
         const int portNum = (spinBox->value() > 0 ? spinBox->value() : url.port());
         url.setPort(-1);
@@ -170,7 +156,7 @@ static void setProxyInformation(const QString& value,
         }
 
         QUrl url;
-        if (KUriFilter::self()->filterUri(data, QStringList() << QStringLiteral("kshorturifilter"))) {
+        if (KUriFilter::self()->filterUri(data, QStringList{QStringLiteral("kshorturifilter")})) {
             url = QUrl(data.uri());
             url.setUserName(QString());
             url.setPassword(QString());
@@ -196,6 +182,18 @@ KProxyDialog::KProxyDialog(QWidget* parent, const QVariantList& args)
     Q_UNUSED(args);
     mUi.setupUi(this);
 
+    connect(mUi.autoDetectButton, &QAbstractButton::clicked, this, &KProxyDialog::autoDetect);
+    connect(mUi.showEnvValueCheckBox, &QAbstractButton::toggled, this, &KProxyDialog::showEnvValue);
+    connect(mUi.useSameProxyCheckBox, &QAbstractButton::clicked, this, &KProxyDialog::setUseSameProxy);
+    connect(mUi.manualProxyHttpEdit, &QLineEdit::textChanged, this, [this](const QString &text) {
+        mUi.useSameProxyCheckBox->setEnabled(!text.isEmpty());
+    });
+    connect(mUi.manualNoProxyEdit, &QLineEdit::textChanged, this, [this](const QString &text) {
+        mUi.useReverseProxyCheckBox->setEnabled(!text.isEmpty());
+    });
+    connect(mUi.manualProxyHttpEdit, &QLineEdit::textEdited, this, &KProxyDialog::syncProxies);
+    connect(mUi.manualProxyHttpSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &KProxyDialog::syncProxyPorts);
+
     mUi.systemProxyGroupBox->setVisible(false);
     mUi.manualProxyGroupBox->setVisible(false);
     mUi.autoDetectButton->setVisible(false);
@@ -426,7 +424,7 @@ bool KProxyDialog::autoDetectSystemProxy(QLineEdit* edit, const QString& envVarS
     return false;
 }
 
-void KProxyDialog::on_autoDetectButton_clicked()
+void KProxyDialog::autoDetect()
 {
     const bool showValue = mUi.showEnvValueCheckBox->isChecked();
     bool wasChanged = false;
@@ -441,17 +439,7 @@ void KProxyDialog::on_autoDetectButton_clicked()
         emit changed (true);
 }
 
-void KProxyDialog::on_manualProxyHttpEdit_textChanged(const QString& text)
-{
-    mUi.useSameProxyCheckBox->setEnabled(!text.isEmpty());
-}
-
-void KProxyDialog::on_manualNoProxyEdit_textChanged (const QString& text)
-{
-    mUi.useReverseProxyCheckBox->setEnabled(!text.isEmpty());
-}
-
-void KProxyDialog::on_manualProxyHttpEdit_textEdited(const QString& text)
+void KProxyDialog::syncProxies(const QString& text)
 {
     if (!mUi.useSameProxyCheckBox->isChecked()) {
         return;
@@ -462,7 +450,7 @@ void KProxyDialog::on_manualProxyHttpEdit_textEdited(const QString& text)
     mUi.manualProxySocksEdit->setText(text);
 }
 
-void KProxyDialog::on_manualProxyHttpSpinBox_valueChanged (int value)
+void KProxyDialog::syncProxyPorts(int value)
 {
     if (!mUi.useSameProxyCheckBox->isChecked()) {
         return;
@@ -473,7 +461,7 @@ void KProxyDialog::on_manualProxyHttpSpinBox_valueChanged (int value)
     mUi.manualProxySocksSpinBox->setValue(value);
 }
 
-void KProxyDialog::on_showEnvValueCheckBox_toggled (bool on)
+void KProxyDialog::showEnvValue(bool on)
 {
     if (on) {
         showSystemProxyUrl(mUi.systemProxyHttpEdit, &mProxyMap[mUi.systemProxyHttpEdit->objectName()]);
@@ -496,7 +484,7 @@ void KProxyDialog::on_showEnvValueCheckBox_toggled (bool on)
     mUi.systemNoProxyEdit->setEnabled(true);
 }
 
-void KProxyDialog::on_useSameProxyCheckBox_clicked(bool on)
+void KProxyDialog::setUseSameProxy(bool on)
 {
     if (on) {
         mProxyMap[QStringLiteral("ManProxyHttps")] = manualProxyToText (mUi.manualProxyHttpsEdit, mUi.manualProxyHttpsSpinBox, QL1C (' '));
