@@ -11,17 +11,16 @@
 #include "useragentinfo.h"
 
 // Qt
-#include <QPushButton>
+#include <QComboBox>
 #include <QDialogButtonBox>
+#include <QLineEdit>
+#include <QPushButton>
 #include <QValidator>
+#include <QVBoxLayout>
 #include <QWidget>
 
 // KDE
-#include <KComboBox>
-#include <QLineEdit>
 #include <KUrlLabel>
-#include <QVBoxLayout>
-
 
 class UserAgentSiteNameValidator : public QValidator
 {
@@ -86,13 +85,8 @@ UserAgentSelectorDlg::UserAgentSelectorDlg (UserAgentInfo* info, QWidget* parent
 
     connect (mUi.siteLineEdit, &QLineEdit::textEdited,
              this, &UserAgentSelectorDlg::onHostNameChanged);
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    connect (mUi.aliasComboBox, QOverload<const QString &>::of(&QComboBox::activated),
-             this, &UserAgentSelectorDlg::onAliasChanged);
-#else
     connect (mUi.aliasComboBox, &QComboBox::textActivated,
              this, &UserAgentSelectorDlg::onAliasChanged);
-#endif
 
     mButtonBox->button(QDialogButtonBox::Ok)->setEnabled (false);
 }
