@@ -1,20 +1,8 @@
 /*
- *  Copyright (c) 2000 Yves Arrouye <yves@realnames.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2000 Yves Arrouye <yves@realnames.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Own
 #include "main.h"
@@ -37,7 +25,7 @@ KURIFilterModule::KURIFilterModule(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args),
       m_widget(nullptr)
 {
-    KAboutData *about = new KAboutData(QStringLiteral("kcm_webshortcuts"), i18n("Web Shortcuts"),
+    KAboutData *about = new KAboutData(QStringLiteral("kcm_webshortcuts"), i18n("Web Search Keywords"),
                                        QStringLiteral("0.1"), i18n("Configure enhanced browsing features"),
                                        KAboutLicense::GPL);
     setAboutData(about);
@@ -48,7 +36,7 @@ KURIFilterModule::KURIFilterModule(QWidget *parent, const QVariantList &args)
 
     setQuickHelp(i18n("<h1>Enhanced Browsing</h1> In this module you can configure some enhanced browsing"
                       " features of KDE. "
-                      "<h2>Web Shortcuts</h2>Web Shortcuts are a quick way of using Web search engines. For example, type \"duckduckgo:frobozz\""
+                      "<h2>Web Search Keywords</h2>Web Search Keywords are a quick way of using Web search engines. For example, type \"duckduckgo:frobozz\""
                       " or \"dd:frobozz\" and your web browser will do a search on DuckDuckGo for \"frobozz\"."
                       " Even easier: just press Alt+F2 (if you have not"
                       " changed this keyboard shortcut) and enter the shortcut in the Run Command dialog."));
@@ -100,11 +88,18 @@ KURIFilterModule::KURIFilterModule(QWidget *parent, const QVariantList &args)
 
 void KURIFilterModule::load()
 {
-// seems not to be necessary, since modules automatically call load() on show (uwolfer)
-//     foreach( KCModule* module, modules )
-//     {
-//    module->load();
-//     }
+    static bool firstLoad = true;
+
+    // Modules automatically call load() when first shown, but subsequent
+    // calls need to be propagated to make the`Reset` button work
+    if (firstLoad) {
+        firstLoad = false;
+        return;
+    }
+
+    for (KCModule *module : qAsConst(modules)) {
+        module->load();
+    }
 }
 
 void KURIFilterModule::save()
