@@ -1,39 +1,23 @@
 /*
-   This file is part of the KDE libraries
-
-   Copyright (c) 2007, 2008, 2010 Andreas Hartmetz <ahartmetz@gmail.com>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2007, 2008, 2010 Andreas Hartmetz <ahartmetz@gmail.com>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kssld.h"
 
 #include "ksslcertificatemanager.h"
+#include "ksslcertificatemanager_p.h"
 #include "kssld_adaptor.h"
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <QFile>
+#include <KConfig>
+#include <KConfigGroup>
 
 #include <QDate>
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
+#include <KPluginFactory>
 
-K_PLUGIN_FACTORY_WITH_JSON(KSSLDFactory, "kssld.json", registerPlugin<KSSLD>();)
+K_PLUGIN_CLASS_WITH_JSON(KSSLD, "kssld.json")
 
 class KSSLDPrivate
 {
@@ -43,36 +27,46 @@ public:
     {
         struct strErr {
             const char *str;
-            KSslError::Error err;
+            QSslError::SslError err;
         };
 
         //hmmm, looks like these are all of the errors where it is possible to continue.
+        // TODO for Qt > 5.14 QSslError::SslError is a Q_ENUM, and we can therefore replace this manual mapping table
         const static strErr strError[] = {
-            {"NoError", KSslError::NoError},
-            {"UnknownError", KSslError::UnknownError},
-            {"InvalidCertificateAuthority", KSslError::InvalidCertificateAuthorityCertificate},
-            {"InvalidCertificate", KSslError::InvalidCertificate},
-            {"CertificateSignatureFailed", KSslError::CertificateSignatureFailed},
-            {"SelfSignedCertificate", KSslError::SelfSignedCertificate},
-            {"RevokedCertificate", KSslError::RevokedCertificate},
-            {"InvalidCertificatePurpose", KSslError::InvalidCertificatePurpose},
-            {"RejectedCertificate", KSslError::RejectedCertificate},
-            {"UntrustedCertificate", KSslError::UntrustedCertificate},
-            {"ExpiredCertificate", KSslError::ExpiredCertificate},
-            {"HostNameMismatch", KSslError::HostNameMismatch}
+            {"NoError", QSslError::NoError},
+            {"UnknownError", QSslError::UnspecifiedError},
+            {"InvalidCertificateAuthority", QSslError::InvalidCaCertificate},
+            {"InvalidCertificate", QSslError::UnableToDecodeIssuerPublicKey},
+            {"CertificateSignatureFailed", QSslError::CertificateSignatureFailed},
+            {"SelfSignedCertificate", QSslError::SelfSignedCertificate},
+            {"RevokedCertificate", QSslError::CertificateRevoked},
+            {"InvalidCertificatePurpose", QSslError::InvalidPurpose},
+            {"RejectedCertificate", QSslError::CertificateRejected},
+            {"UntrustedCertificate", QSslError::CertificateUntrusted},
+            {"ExpiredCertificate", QSslError::CertificateExpired},
+            {"HostNameMismatch", QSslError::HostNameMismatch},
+            {"UnableToGetLocalIssuerCertificate", QSslError::UnableToGetLocalIssuerCertificate},
+            {"InvalidNotBeforeField", QSslError::InvalidNotBeforeField},
+            {"InvalidNotAfterField", QSslError::InvalidNotAfterField},
+            {"CertificateNotYetValid", QSslError::CertificateNotYetValid},
+            {"SubjectIssuerMismatch", QSslError::SubjectIssuerMismatch},
+            {"AuthorityIssuerSerialNumberMismatch", QSslError::AuthorityIssuerSerialNumberMismatch},
+            {"SelfSignedCertificateInChain", QSslError::SelfSignedCertificateInChain},
+            {"UnableToVerifyFirstCertificate", QSslError::UnableToVerifyFirstCertificate},
+            {"UnableToDecryptCertificateSignature", QSslError::UnableToDecryptCertificateSignature},
+            {"UnableToGetIssuerCertificate", QSslError::UnableToGetIssuerCertificate}
         };
 
-        for (int i = 0; i < int(sizeof(strError) / sizeof(strErr)); i++) {
-            QString s = QString::fromLatin1(strError[i].str);
-            KSslError::Error e = strError[i].err;
-            stringToSslError.insert(s, e);
-            sslErrorToString.insert(e, s);
+        for (const strErr &row : strError) {
+            QString s = QString::fromLatin1(row.str);
+            stringToSslError.insert(s, row.err);
+            sslErrorToString.insert(row.err, s);
         }
     }
 
     KConfig config;
-    QHash<QString, KSslError::Error> stringToSslError;
-    QHash<KSslError::Error, QString> sslErrorToString;
+    QHash<QString, QSslError::SslError> stringToSslError;
+    QHash<QSslError::SslError, QString> sslErrorToString;
 };
 
 KSSLD::KSSLD(QObject *parent, const QVariantList &)
@@ -104,7 +98,12 @@ void KSSLD::setRule(const KSslCertificateRule &rule)
     if (rule.isRejected()) {
         sl.append(QStringLiteral("Reject"));
     } else {
-        foreach (KSslError::Error e, rule.ignoredErrors()) {
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
+        for (QSslError::SslError e : qAsConst(rule.d->ignoredErrors)) {
+#else
+        const auto ignoredErrors = rule.ignoredErrors();
+        for (QSslError::SslError e : ignoredErrors) {
+#endif
             sl.append(d->sslErrorToString.value(e));
         }
     }
@@ -140,9 +139,11 @@ void KSSLD::pruneExpiredRules()
 {
     // expired rules are deleted when trying to load them, so we just try to load all rules.
     // be careful about iterating over KConfig(Group) while changing it
-    foreach (const QString &groupName, d->config.groupList()) {
+    const QStringList groupNames = d->config.groupList();
+    for (const QString &groupName : groupNames) {
         QByteArray certDigest = groupName.toLatin1();
-        foreach (const QString &key, d->config.group(groupName).keyList()) {
+        const QStringList keys = d->config.group(groupName).keyList();
+        for (const QString &key : keys) {
             if (key == QLatin1String("CertificatePEM")) {
                 continue;
             }
@@ -244,9 +245,9 @@ KSslCertificateRule KSSLD::rule(const QSslCertificate &cert, const QString &host
         return ret;
     }
 
-    QList<KSslError::Error> ignoredErrors;
+    QList<QSslError::SslError> ignoredErrors;
     bool isRejected = false;
-    foreach (const QString &s, sl) {
+    for (const QString &s : qAsConst(sl)) {
         if (s == QLatin1String("Reject")) {
             isRejected = true;
             ignoredErrors.clear();
