@@ -1,47 +1,33 @@
 /*
-
     kshorturifilter.h
 
     This file is part of the KDE project
-    Copyright (C) 2000 Dawit Alemayehu <adawit@kde.org>
-    Copyright (C) 2000 Malte Starostik <starosti@zedat.fu-berlin.de>
+    SPDX-FileCopyrightText: 2000 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2000 Malte Starostik <starosti@zedat.fu-berlin.de>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kshorturifilter.h"
-#include "../../pathhelpers_p.h"
+#include "../pathhelpers_p.h" // concatPaths(), isAbsoluteLocalPath()
 
 #include <QDir>
 #include <QDBusConnection>
 #include <QLoggingCategory>
-#include <QRegularExpression>
 #include <qplatformdefs.h>
 
-#include <klocalizedstring.h>
-#include <kpluginfactory.h>
+#include <KLocalizedString>
+#include <KPluginFactory>
 #include <kprotocolinfo.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kmimetypetrader.h>
-#include <kservice.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KApplicationTrader>
+#include <KService>
 #include <kurlauthorized.h>
-#include <kuser.h>
+#include <KUser>
 
 namespace {
-QLoggingCategory category("org.kde.kurifilter-shorturi", QtWarningMsg);
+QLoggingCategory category("kf.kio.urifilters.shorturi", QtWarningMsg);
 }
 
 /**
@@ -59,7 +45,10 @@ static QRegularExpression sEnvVarExp(QStringLiteral("\\$[a-zA-Z_][a-zA-Z0-9_]*")
 static bool isPotentialShortURL(const QString &cmd)
 {
     // Host names and IPv4 address...
-    if (cmd.contains(QLatin1Char('.'))) {
+    // Exclude ".." and paths starting with "../", these are used to go up in a filesystem
+    // dir hierarchy
+    if (cmd != QLatin1String("..") && !cmd.startsWith(QLatin1String("../"))
+        && cmd.contains(QLatin1Char('.'))) {
         return true;
     }
 
@@ -97,7 +86,7 @@ static bool isKnownProtocol(const QString &protocol)
     if (KProtocolInfo::isKnownProtocol(protocol) || protocol == QLatin1String("mailto")) {
         return true;
     }
-    const KService::Ptr service = KMimeTypeTrader::self()->preferredService(QLatin1String("x-scheme-handler/") + protocol);
+    const KService::Ptr service = KApplicationTrader::preferredService(QLatin1String("x-scheme-handler/") + protocol);
     return service;
 }
 
@@ -137,7 +126,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
 
     // Replicate what KUrl(cmd) did in KDE4. This could later be folded into the checks further down...
     QUrl url;
-    if (QDir::isAbsolutePath(cmd)) {
+    if (isAbsoluteLocalPath(cmd)) {
         url = QUrl::fromLocalFile(cmd);
     } else {
         url.setUrl(cmd);
@@ -184,12 +173,12 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
     // Handle MAN & INFO pages shortcuts...
     const QString man_proto = QStringLiteral("man:");
     const QString info_proto = QStringLiteral("info:");
-    if (cmd[0] == QLatin1Char('#')
+    if (cmd.startsWith(QLatin1Char('#'))
         || cmd.indexOf(man_proto) == 0
         || cmd.indexOf(info_proto) == 0) {
         if (cmd.leftRef(2) == QLatin1String("##")) {
             cmd = QLatin1String("info:/") + cmd.midRef(2);
-        } else if (cmd[0] == QLatin1Char('#')) {
+        } else if (cmd.startsWith(QLatin1Char('#'))) {
             cmd = QLatin1String("man:/") + cmd.midRef(1);
         } else if ((cmd == info_proto) || (cmd == man_proto)) {
             cmd += QLatin1Char('/');
@@ -218,7 +207,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
     QString query;
     QString nameFilter;
 
-    if (QDir::isRelativePath(cmd) && QUrl(cmd).isRelative()) {
+    if (!isAbsoluteLocalPath(cmd) && QUrl(cmd).isRelative()) {
         path = cmd;
         qCDebug(category) << "path=cmd=" << path;
     } else {
@@ -247,7 +236,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
         }
     }
 
-    if (path[0] == QLatin1Char('~')) {
+    if (path.startsWith(QLatin1Char('~'))) {
         int slashPos = path.indexOf(QLatin1Char('/'));
         if (slashPos == -1) {
             slashPos = path.length();
@@ -272,7 +261,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
             }
         }
         expanded = true;
-    } else if (path[0] == QLatin1Char('$')) {
+    } else if (path.startsWith(QLatin1Char('$'))) {
         // Environment variable expansion.
         auto match = sEnvVarExp.match(path);
         if (match.hasMatch()) {
@@ -298,7 +287,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
         }
     }
 
-    bool isLocalFullPath = QDir::isAbsolutePath(path);
+    bool isLocalFullPath = isAbsoluteLocalPath(path);
 
     // Checking for local resource match...
     // Determine if "uri" is an absolute path to a local resource  OR
@@ -306,7 +295,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
     const QString abs_path = data.absolutePath();
 
     const bool canBeAbsolute = (protocol.isEmpty() && !abs_path.isEmpty());
-    const bool canBeLocalAbsolute = (canBeAbsolute && abs_path[0] == QLatin1Char('/') && !isMalformed);
+    const bool canBeLocalAbsolute = (canBeAbsolute && abs_path.startsWith(QLatin1Char('/')) && !isMalformed);
     bool exists = false;
 
     /*qCDebug(category) << "abs_path=" << abs_path
