@@ -163,7 +163,7 @@ DropMenu::DropMenu(QWidget *parent)
     : QMenu(parent),
       m_extraActionsSeparator(nullptr)
 {
-    m_cancelAction = new QAction(i18n("C&ancel") + QLatin1Char('\t') + QKeySequence(Qt::Key_Escape).toString(), this);
+    m_cancelAction = new QAction(i18n("C&ancel") + QLatin1Char('\t') + QKeySequence(Qt::Key_Escape).toString(QKeySequence::NativeText), this);
     m_cancelAction->setIcon(QIcon::fromTheme(QStringLiteral("process-stop")));
 
     m_lastSeparator = new QAction(this);
@@ -189,12 +189,16 @@ void DropMenu::addExtraActions(const QList<QAction *> &appActions, const QList<Q
 
     m_appActions = appActions;
     m_pluginActions = pluginActions;
+
     if (!m_appActions.isEmpty() || !m_pluginActions.isEmpty()) {
-        if (!m_extraActionsSeparator) {
-            m_extraActionsSeparator = new QAction(this);
-            m_extraActionsSeparator->setSeparator(true);
+        QAction *firstExtraAction = m_appActions.value(0, m_pluginActions.value(0, nullptr));
+        if (firstExtraAction && !firstExtraAction->isSeparator()) {
+            if (!m_extraActionsSeparator) {
+                m_extraActionsSeparator = new QAction(this);
+                m_extraActionsSeparator->setSeparator(true);
+            }
+            addAction(m_extraActionsSeparator);
         }
-        addAction(m_extraActionsSeparator);
         addActions(appActions);
         addActions(pluginActions);
     }
@@ -311,7 +315,7 @@ void DropJobPrivate::fillPopupMenu(KIO::DropMenu *popup)
     Q_Q(DropJob);
 
     // Check what the source can do
-    // TODO: Determining the mimetype of the source URLs is difficult for remote URLs,
+    // TODO: Determining the MIME type of the source URLs is difficult for remote URLs,
     // we would need to KIO::stat each URL in turn, asynchronously....
     KFileItemList fileItems;
     fileItems.reserve(m_urls.size());
@@ -326,21 +330,19 @@ void DropJobPrivate::fillPopupMenu(KIO::DropMenu *popup)
     const bool sDeleting = itemProps.supportsDeleting();
     const bool sMoving = itemProps.supportsMoving();
 
-    QString seq = QKeySequence(Qt::ShiftModifier).toString();
-    Q_ASSERT(seq.endsWith(QLatin1Char('+')));
-    seq.chop(1); // chop superfluous '+'
+    const int separatorLength = QCoreApplication::translate("QShortcut", "+").size();
+    QString seq = QKeySequence(Qt::ShiftModifier).toString(QKeySequence::NativeText);
+    seq.chop(separatorLength); // chop superfluous '+'
     QAction* popupMoveAction = new QAction(i18n("&Move Here") + QLatin1Char('\t') + seq, popup);
-    popupMoveAction->setIcon(QIcon::fromTheme(QStringLiteral("go-jump")));
+    popupMoveAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-move"), QIcon::fromTheme(QStringLiteral("go-jump"))));
     popupMoveAction->setData(QVariant::fromValue(Qt::MoveAction));
-    seq = QKeySequence(Qt::ControlModifier).toString();
-    Q_ASSERT(seq.endsWith(QLatin1Char('+')));
-    seq.chop(1);
+    seq = QKeySequence(Qt::ControlModifier).toString(QKeySequence::NativeText);
+    seq.chop(separatorLength);
     QAction* popupCopyAction = new QAction(i18n("&Copy Here") + QLatin1Char('\t') + seq, popup);
     popupCopyAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
     popupCopyAction->setData(QVariant::fromValue(Qt::CopyAction));
-    seq = QKeySequence(Qt::ControlModifier + Qt::ShiftModifier).toString();
-    Q_ASSERT(seq.endsWith(QLatin1Char('+')));
-    seq.chop(1);
+    seq = QKeySequence(Qt::ControlModifier | Qt::ShiftModifier).toString(QKeySequence::NativeText);
+    seq.chop(separatorLength);
     QAction* popupLinkAction = new QAction(i18n("&Link Here") + QLatin1Char('\t') + seq, popup);
     popupLinkAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-link")));
     popupLinkAction->setData(QVariant::fromValue(Qt::LinkAction));
@@ -366,8 +368,6 @@ void DropJobPrivate::fillPopupMenu(KIO::DropMenu *popup)
     popup->addAction(popupLinkAction);
 
     addPluginActions(popup, itemProps);
-
-    popup->addSeparator();
 }
 
 void DropJobPrivate::addPluginActions(KIO::DropMenu *popup, const KFileItemListProperties &itemProps)
@@ -507,6 +507,7 @@ void DropJobPrivate::doCopyToDirectory()
         return;
     }
     Q_ASSERT(job);
+    job->setUiDelegate(q->uiDelegate());
     job->setParentJob(q);
     job->setMetaData(m_metaData);
     QObject::connect(job, &KIO::CopyJob::copyingDone, q, [q](KIO::Job*, const QUrl &, const QUrl &to) {
