@@ -1,35 +1,28 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                       David Faure <faure@kde.org>
-    Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
-    Copyright (C) 2013 Dawit Alemayehu <adawit@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2006 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2013 Dawit Alemayehu <adawit@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "jobuidelegate.h"
 #include <kio/jobuidelegatefactory.h>
 #include "kio_widgets_debug.h"
+#include "kiogui_export.h"
+#include "widgetsuntrustedprogramhandler.h"
+#include "widgetsopenwithhandler.h"
+#include "widgetsopenorexecutefilehandler.h"
+#include "widgetsaskuseractionhandler.h"
 
-#include <kconfiggroup.h>
-#include <kjob.h>
-#include <kjobwidgets.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <ksharedconfig.h>
+#include <KConfigGroup>
+#include <KJob>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
 #include <ksslinfodialog.h>
 #include <clipboardupdater_p.h>
 
@@ -38,17 +31,25 @@
 #include <QPointer>
 #include <QWidget>
 #include <QIcon>
+#include <QRegularExpression>
 #include <QUrl>
 
 #include "kio/scheduler.h"
 
-class KIO::JobUiDelegate::Private
+class Q_DECL_HIDDEN KIO::JobUiDelegate::Private
 {
 public:
+    Private(KIO::JobUiDelegate *q) {
+        // Create extension objects. See KIO::delegateExtension<T>().
+        new WidgetsUntrustedProgramHandler(q);
+        new WidgetsOpenWithHandler(q);
+        new WidgetsOpenOrExecuteFileHandler(q);
+        new WidgetsAskUserActionHandler(q);
+    }
 };
 
 KIO::JobUiDelegate::JobUiDelegate()
-    : d(new Private())
+    : d(new Private(this))
 {
 }
 
@@ -97,8 +98,8 @@ public:
             // access QWidget::winId() (already destructed)
             WId windowId = window->winId();
             m_windowList.insert(obj, windowId);
-            connect(window, SIGNAL(destroyed(QObject*)),
-                    this, SLOT(slotUnregisterWindow(QObject*)));
+            connect(window, &QObject::destroyed,
+                    this, &JobUiDelegateStatic::slotUnregisterWindow);
             QDBusInterface(QStringLiteral("org.kde.kded5"), QStringLiteral("/kded"), QStringLiteral("org.kde.kded5")).
             call(QDBus::NoBlock, QStringLiteral("registerWindowId"), qlonglong(windowId));
         }
@@ -115,8 +116,8 @@ public Q_SLOTS:
             return;
         }
         WId windowId = it.value();
-        disconnect(it.key(), SIGNAL(destroyed(QObject*)),
-                   this, SLOT(slotUnregisterWindow(QObject*)));
+        disconnect(it.key(), &QObject::destroyed,
+                   this, &JobUiDelegateStatic::slotUnregisterWindow);
         m_windowList.erase(it);
         QDBusInterface(QStringLiteral("org.kde.kded5"), QStringLiteral("/kded"), QStringLiteral("org.kde.kded5")).
         call(QDBus::NoBlock, QStringLiteral("unregisterWindowId"), qlonglong(windowId));
@@ -127,6 +128,12 @@ private:
 
 Q_GLOBAL_STATIC(JobUiDelegateStatic, s_static)
 
+KIO::JobUiDelegate::JobUiDelegate(KJobUiDelegate::Flags flags, QWidget *window)
+    : KDialogJobUiDelegate(flags, window), d(new Private(this))
+{
+    s_static()->registerWindow(window);
+}
+
 void KIO::JobUiDelegate::setWindow(QWidget *window)
 {
     KDialogJobUiDelegate::setWindow(window);
@@ -159,9 +166,9 @@ KIO::RenameDialog_Result KIO::JobUiDelegate::askFileRename(KJob *job,
                           ctimeSrc, ctimeDest, mtimeSrc,
                           mtimeDest);
     dlg.setWindowModality(Qt::WindowModal);
-    connect(job, SIGNAL(finished(KJob*)), &dlg, SLOT(reject())); // #192976
+    connect(job, &KJob::finished, &dlg, &QDialog::reject); // #192976
     KIO::RenameDialog_Result res = static_cast<RenameDialog_Result>(dlg.exec());
-    if (res == R_AUTO_RENAME) {
+    if (res == Result_AutoRename) {
         newDest = dlg.autoDestUrl().path();
     } else {
         newDest = dlg.newDestUrl().path();
@@ -175,7 +182,7 @@ KIO::SkipDialog_Result KIO::JobUiDelegate::askSkip(KJob *job,
 {
     KIO::SkipDialog dlg(KJobWidgets::window(job), options, error_text);
     dlg.setWindowModality(Qt::WindowModal);
-    connect(job, SIGNAL(finished(KJob*)), &dlg, SLOT(reject())); // #192976
+    connect(job, &KJob::finished, &dlg, &QDialog::reject); // #192976
     return static_cast<KIO::SkipDialog_Result>(dlg.exec());
 }
 
@@ -188,31 +195,35 @@ bool KIO::JobUiDelegate::askDeleteConfirmation(const QList<QUrl> &urls,
     if (!ask) {
         KSharedConfigPtr kioConfig = KSharedConfig::openConfig(QStringLiteral("kiorc"), KConfig::NoGlobals);
 
+        // The default value for confirmations is true for delete and false
+        // for trash. If you change this, please also update:
+        //      dolphin/src/settings/general/confirmationssettingspage.cpp
+        bool defaultValue = true;
+
         switch (deletionType) {
         case Delete:
             keyName = QStringLiteral("ConfirmDelete");
             break;
         case Trash:
             keyName = QStringLiteral("ConfirmTrash");
+            defaultValue = false;
             break;
         case EmptyTrash:
             keyName = QStringLiteral("ConfirmEmptyTrash");
             break;
         }
 
-        // The default value for confirmations is true (for both delete and trash)
-        // If you change this, update kdebase/apps/konqueror/settings/konq/behaviour.cpp
-        const bool defaultValue = true;
         ask = kioConfig->group("Confirmations").readEntry(keyName, defaultValue);
     }
     if (ask) {
         QStringList prettyList;
-        Q_FOREACH (const QUrl &url, urls) {
+        prettyList.reserve(urls.size());
+        for (const QUrl &url : urls) {
             if (url.scheme() == QLatin1String("trash")) {
                 QString path = url.path();
                 // HACK (#98983): remove "0-foo". Note that it works better than
                 // displaying KFileItem::name(), for files under a subdir.
-                path.remove(QRegExp(QStringLiteral("^/[0-9]*-")));
+                path.remove(QRegularExpression(QStringLiteral("^/[0-9]*-")));
                 prettyList.append(path);
             } else {
                 prettyList.append(url.toDisplayString(QUrl::PreferLocalFile));
@@ -224,20 +235,30 @@ bool KIO::JobUiDelegate::askDeleteConfirmation(const QList<QUrl> &urls,
         const KMessageBox::Options options(KMessageBox::Notify | KMessageBox::WindowModal);
         switch (deletionType) {
         case Delete:
-            result = KMessageBox::warningContinueCancelList(
-                         widget,
-                         i18np("Do you really want to delete this item?", "Do you really want to delete these %1 items?", prettyList.count()),
-                         prettyList,
-                         i18n("Delete Files"),
-                         KStandardGuiItem::del(),
-                         KStandardGuiItem::cancel(),
-                         keyName, options);
+            if (prettyList.count() == 1) {
+                result = KMessageBox::warningContinueCancel(
+                            widget,
+                            xi18nc("@info", "Do you really want to permanently delete this item?<nl/><filename>%1</filename><nl/><nl/><emphasis strong='true'>This action cannot be undone.</emphasis>", prettyList.first()),
+                            i18n("Delete Permanently"),
+                            KStandardGuiItem::del(),
+                            KStandardGuiItem::cancel(),
+                            keyName, options);
+            } else {
+                result = KMessageBox::warningContinueCancelList(
+                            widget,
+                            xi18ncp("@info", "Do you really want to permanently delete this item?<nl/><nl/><emphasis strong='true'>This action cannot be undone.</emphasis>", "Do you really want to permanently delete these %1 items?<nl/><nl/><emphasis strong='true'>This action cannot be undone.</emphasis>", prettyList.count()),
+                            prettyList,
+                            i18n("Delete Permanently"),
+                            KStandardGuiItem::del(),
+                            KStandardGuiItem::cancel(),
+                            keyName, options);
+            }
             break;
         case EmptyTrash:
             result = KMessageBox::warningContinueCancel(
                          widget,
-                         i18nc("@info", "Do you want to permanently delete all items from Trash? This action cannot be undone."),
-                         QString(),
+                         xi18nc("@info", "Do you want to permanently delete all items from the Trash?<nl/><nl/><emphasis strong='true'>This action cannot be undone.</emphasis>"),
+                         i18n("Delete Permanently"),
                          KGuiItem(i18nc("@action:button", "Empty Trash"),
                                   QIcon::fromTheme(QStringLiteral("user-trash"))),
                          KStandardGuiItem::cancel(),
@@ -245,14 +266,24 @@ bool KIO::JobUiDelegate::askDeleteConfirmation(const QList<QUrl> &urls,
             break;
         case Trash:
         default:
-            result = KMessageBox::warningContinueCancelList(
-                         widget,
-                         i18np("Do you really want to move this item to the trash?", "Do you really want to move these %1 items to the trash?", prettyList.count()),
-                         prettyList,
-                         i18n("Move to Trash"),
-                         KGuiItem(i18nc("Verb", "&Trash"), QStringLiteral("user-trash")),
-                         KStandardGuiItem::cancel(),
-                         keyName, options);
+            if (prettyList.count() == 1) {
+                result = KMessageBox::warningContinueCancel(
+                            widget,
+                            xi18nc("@info", "Do you really want to move this item to the Trash?<nl/><filename>%1</filename>", prettyList.first()),
+                            i18n("Move to Trash"),
+                            KGuiItem(i18n("Move to Trash"), QStringLiteral("user-trash")),
+                            KStandardGuiItem::cancel(),
+                            keyName, options);
+            } else {
+                result = KMessageBox::warningContinueCancelList(
+                            widget,
+                            i18np("Do you really want to move this item to the Trash?", "Do you really want to move these %1 items to the Trash?", prettyList.count()),
+                            prettyList,
+                            i18n("Move to Trash"),
+                            KGuiItem(i18n("Move to Trash"), QStringLiteral("user-trash")),
+                            KStandardGuiItem::cancel(),
+                            keyName, options);
+            }
         }
         if (!keyName.isEmpty()) {
             // Check kmessagebox setting... erase & copy to konquerorrc.
@@ -276,7 +307,7 @@ int KIO::JobUiDelegate::requestMessageBox(KIO::JobUiDelegate::MessageBoxType typ
         const QString &buttonYes, const QString &buttonNo,
         const QString &iconYes, const QString &iconNo,
         const QString &dontAskAgainName,
-        const KIO::MetaData &sslMetaData)
+        const KIO::MetaData &metaData)
 {
     int result = -1;
 
@@ -318,10 +349,14 @@ int KIO::JobUiDelegate::requestMessageBox(KIO::JobUiDelegate::MessageBoxType typ
     case SSLMessageBox: {
         QPointer<KSslInfoDialog> kid(new KSslInfoDialog(window()));
         //### this is boilerplate code and appears in khtml_part.cpp almost unchanged!
-        const QStringList sl = sslMetaData.value(QStringLiteral("ssl_peer_chain")).split('\x01', QString::SkipEmptyParts);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+        const QStringList sl = metaData.value(QStringLiteral("ssl_peer_chain")).split(QLatin1Char('\x01'), QString::SkipEmptyParts);
+#else
+        const QStringList sl = metaData.value(QStringLiteral("ssl_peer_chain")).split(QLatin1Char('\x01'), Qt::SkipEmptyParts);
+#endif
         QList<QSslCertificate> certChain;
         bool decodedOk = true;
-        foreach (const QString &s, sl) {
+        for (const QString &s : sl) {
             certChain.append(QSslCertificate(s.toLatin1())); //or is it toLocal8Bit or whatever?
             if (certChain.last().isNull()) {
                 decodedOk = false;
@@ -332,13 +367,13 @@ int KIO::JobUiDelegate::requestMessageBox(KIO::JobUiDelegate::MessageBoxType typ
         if (decodedOk) {
             result = 1; // whatever
             kid->setSslInfo(certChain,
-                            sslMetaData.value(QStringLiteral("ssl_peer_ip")),
+                            metaData.value(QStringLiteral("ssl_peer_ip")),
                             text, // the URL
-                            sslMetaData.value(QStringLiteral("ssl_protocol_version")),
-                            sslMetaData.value(QStringLiteral("ssl_cipher")),
-                            sslMetaData.value(QStringLiteral("ssl_cipher_used_bits")).toInt(),
-                            sslMetaData.value(QStringLiteral("ssl_cipher_bits")).toInt(),
-                            KSslInfoDialog::errorsFromString(sslMetaData.value(QStringLiteral("ssl_cert_errors"))));
+                            metaData.value(QStringLiteral("ssl_protocol_version")),
+                            metaData.value(QStringLiteral("ssl_cipher")),
+                            metaData.value(QStringLiteral("ssl_cipher_used_bits")).toInt(),
+                            metaData.value(QStringLiteral("ssl_cipher_bits")).toInt(),
+                            KSslInfoDialog::certificateErrorsFromString(metaData.value(QStringLiteral("ssl_cert_errors"))));
             kid->exec();
         } else {
             result = -1;
@@ -350,6 +385,13 @@ int KIO::JobUiDelegate::requestMessageBox(KIO::JobUiDelegate::MessageBoxType typ
         delete kid;
         break;
     }
+    case WarningContinueCancelDetailed: {
+        const QString details = metaData.value(QStringLiteral("privilege_conf_details"));
+        result = KMessageBox::warningContinueCancelDetailed(
+                      window(), text, caption, KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
+                      dontAskAgainName, options | KMessageBox::Dangerous, details);
+        break;
+    }
     default:
         qCWarning(KIO_WIDGETS) << "Unknown type" << type;
         result = 0;
@@ -377,7 +419,7 @@ void KIO::JobUiDelegate::updateUrlInClipboard(const QUrl &src, const QUrl &dest)
 class KIOWidgetJobUiDelegateFactory : public KIO::JobUiDelegateFactory
 {
 public:
-    KJobUiDelegate *createDelegate() const Q_DECL_OVERRIDE
+    KJobUiDelegate *createDelegate() const override
     {
         return new KIO::JobUiDelegate;
     }
