@@ -13,6 +13,7 @@
 
 #include <KDialogJobUiDelegate>
 #include <kio/jobuidelegateextension.h>
+#include <kio/askuseractioninterface.h>
 #include <kio/skipdialog.h>
 #include <kio/renamedialog.h>
 #include <kio/global.h>
@@ -43,7 +44,7 @@ public:
      * @param window the window associated with this delegate, see setWindow.
      * @since 5.70
      */
-    explicit JobUiDelegate(KJobUiDelegate::Flags flags, QWidget *window);
+    explicit JobUiDelegate(KJobUiDelegate::Flags flags, QWidget *window); // KF6 TODO: merge with previous ctor using AutoHandlingDisabled and nullptr default values (same in KDialogJobUiDelegate)
 
     /**
      * Destroys the KIO Job UI delegate.
