@@ -1,22 +1,10 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Sean Harmer <sh@rama.homelinux.org>             *
- *                 2005 - 2007 Till Adam <adam@kde.org>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by  the Free Software Foundation; either version 2 of the   *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Sean Harmer <sh@rama.homelinux.org>
+    SPDX-FileCopyrightText: 2005-2007 Till Adam <adam@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
 #ifndef KACLEDITWIDGET_P_H
 #define KACLEDITWIDGET_P_H
 
@@ -30,7 +18,7 @@
 #include <QTreeWidget>
 #include <QHash>
 
-#include <KComboBox>
+#include <QComboBox>
 #include <kfileitem.h>
 
 class KACLListViewItem;
@@ -161,8 +149,8 @@ private:
     int m_allowedTypes;
     int m_allowedDefaultTypes;
     QButtonGroup *m_buttonGroup;
-    KComboBox *m_usersCombo;
-    KComboBox *m_groupsCombo;
+    QComboBox *m_usersCombo;
+    QComboBox *m_groupsCombo;
     QStackedWidget *m_widgetStack;
     QCheckBox *m_defaultCB;
     QHash<QAbstractButton *, int> m_buttonIds;
@@ -186,11 +174,6 @@ public:
 
     void togglePerm(acl_perm_t perm);
 
-#if 0
-    virtual void paintCell(QPainter *p, const QColorGroup &cg,
-                           int column, int width, int alignment);
-#endif
-
     void updatePermissionIcons();
     void repaint();
 
