@@ -1,35 +1,24 @@
-/* This file is part of the KDE project
-   Copyright (C) 2006-2019 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2006-2019 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kdirmodel.h"
 #include "kdirlister.h"
 #include "kfileitem.h"
 
-#include <klocalizedstring.h>
-#include <kjobuidelegate.h>
+#include <KLocalizedString>
+#include <KJobUiDelegate>
 #include <kio/simplejob.h>
 #include <kio/statjob.h>
 #include <kio/fileundomanager.h>
 #include "joburlcache_p.h"
-#include <kurlmimedata.h>
-#include <kiconloader.h>
+#include <KUrlMimeData>
+#include <KIconLoader>
 
+#include <QLocale>
 #include <QMimeData>
 #include <QBitArray>
 #include <QDebug>
@@ -47,7 +36,7 @@
 #include <qt_windows.h>
 #endif
 
-static QLoggingCategory category("kf5.kio.kdirmodel", QtInfoMsg);
+static QLoggingCategory category("kf.kio.widgets.kdirmodel", QtInfoMsg);
 
 class KDirModelNode;
 class KDirModelDirNode;
@@ -505,6 +494,7 @@ void KDirModelPrivate::_k_slotNewItems(const QUrl &directoryUrl, const KFileItem
         dump();
 #endif
         Q_ASSERT(result);
+        return;
     }
     Q_ASSERT(isDir(result));
     KDirModelDirNode *dirNode = static_cast<KDirModelDirNode *>(result);
@@ -699,7 +689,7 @@ void KDirModelPrivate::_k_slotRefreshItems(const QList<QPair<KFileItem, KFileIte
                 m_nodeHash.remove(cleanupUrl(oldUrl));
                 m_nodeHash.insert(cleanupUrl(newUrl), node);
             }
-            // Mimetype changed -> forget cached icon (e.g. from "cut", #164185 comment #13)
+            // MIME type changed -> forget cached icon (e.g. from "cut", #164185 comment #13)
             if (fit->first.determineMimeType().name() != fit->second.determineMimeType().name()) {
                 node->setPreview(QIcon());
             }
@@ -747,13 +737,13 @@ void KDirModelPrivate::_k_slotClear()
     const int numRows = m_rootNode->m_childNodes.count();
     if (numRows > 0) {
         q->beginRemoveRows(QModelIndex(), 0, numRows - 1);
+        m_nodeHash.clear();
+        clear();
         q->endRemoveRows();
+    } else {
+        m_nodeHash.clear();
+        clear();
     }
-
-    m_nodeHash.clear();
-    //emit layoutAboutToBeChanged();
-    clear();
-    //emit layoutChanged();
 }
 
 void KDirModelPrivate::_k_slotJobUrlsChanged(const QStringList &urlList)
@@ -802,8 +792,8 @@ void KDirModel::clearAllPreviews()
 void KDirModel::itemChanged(const QModelIndex &index)
 {
     // This method is really a itemMimeTypeChanged(), it's mostly called by KFilePreviewGenerator.
-    // When the mimetype is determined, clear the old "preview" (could be
-    // mimetype dependent like when cutting files, #164185)
+    // When the MIME type is determined, clear the old "preview" (could be
+    // MIME type dependent like when cutting files, #164185)
     KDirModelNode *node = d->nodeForIndex(index);
     if (node) {
         node->setPreview(QIcon());
@@ -832,7 +822,7 @@ QVariant KDirModel::data(const QModelIndex &index, int role) const
                 return KIO::convertSize(item.size()); // size formatted as QString
             case ModifiedTime: {
                 QDateTime dt = item.time(KFileItem::ModificationTime);
-                return dt.toString(Qt::SystemLocaleShortDate);
+                return QLocale().toString(dt, QLocale::ShortFormat);
             }
             case Permissions:
                 return item.permissionsString();
@@ -991,6 +981,9 @@ bool KDirModel::setData(const QModelIndex &index, const QVariant &value, int rol
 
 int KDirModel::rowCount(const QModelIndex &parent) const
 {
+    if (parent.column() > 0) { // for QAbstractItemModelTester
+        return 0;
+    }
     KDirModelNode *node = d->nodeForIndex(parent);
     if (!node || !d->isDir(node)) { // #176555
         return 0;
@@ -1004,7 +997,7 @@ int KDirModel::rowCount(const QModelIndex &parent) const
     for (int i = 0; i < count; ++i) {
         filenames << d->urlForNode(parentNode->m_childNodes.at(i)).fileName();
     }
-    //qDebug() << "rowCount for " << d->urlForNode(parentNode) << ": " << count << filenames;
+    qDebug() << "rowCount for " << d->urlForNode(parentNode) << ": " << count << filenames;
 #endif
     return count;
 }
@@ -1102,7 +1095,7 @@ QMimeData *KDirModel::mimeData(const QModelIndexList &indexes) const
         const KFileItem &item = d->nodeForIndex(index)->item();
         urls << item.url();
         bool isLocal;
-        mostLocalUrls << item.mostLocalUrl(isLocal);
+        mostLocalUrls << item.mostLocalUrl(&isLocal);
         if (!isLocal) {
             canUseMostLocalUrls = false;
         }
@@ -1133,12 +1126,14 @@ KFileItem KDirModel::itemForIndex(const QModelIndex &index) const
     }
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(4, 0)
 QModelIndex KDirModel::indexForItem(const KFileItem *item) const
 {
     // Note that we can only use the URL here, not the pointer.
     // KFileItems can be copied.
     return indexForUrl(item->url()); // O(n)
 }
+#endif
 
 QModelIndex KDirModel::indexForItem(const KFileItem &item) const
 {
@@ -1213,7 +1208,19 @@ bool KDirModel::hasChildren(const QModelIndex &parent) const
         return !static_cast<const KDirModelDirNode *>(parentNode)->m_childNodes.isEmpty();
     }
     if (parentItem.isLocalFile()) {
-        QDirIterator it(parentItem.localPath(), QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot,  QDirIterator::Subdirectories);
+        QDir::Filters filters = QDir::Dirs | QDir::NoDotAndDotDot;
+
+        if (d->m_dirLister->dirOnlyMode()) {
+            filters |= QDir::NoSymLinks;
+        } else {
+            filters |= QDir::Files | QDir::System;
+        }
+
+        if (d->m_dirLister->showingDotFiles()) {
+            filters |= QDir::Hidden;
+        }
+
+        QDirIterator it(parentItem.localPath(), filters,  QDirIterator::Subdirectories);
         return it.hasNext();
     }
     // Remote and not listed yet, we can't know; let the user click on it so we'll find out
@@ -1222,9 +1229,12 @@ bool KDirModel::hasChildren(const QModelIndex &parent) const
 
 Qt::ItemFlags KDirModel::flags(const QModelIndex &index) const
 {
-    Qt::ItemFlags f = Qt::ItemIsEnabled;
-    if (index.column() == Name) {
-        f |= Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsDragEnabled;
+    Qt::ItemFlags f;
+    if (index.isValid()) {
+        f |= Qt::ItemIsEnabled;
+        if (index.column() == Name) {
+            f |= Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsDragEnabled;
+        }
     }
 
     // Allow dropping onto this item?
