@@ -1,21 +1,10 @@
-/* This file is part of the KDE project
-   Copyright (C) 2006 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2006 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 #ifndef KDIRMODEL_H
 #define KDIRMODEL_H
 
@@ -58,6 +47,34 @@ public:
     explicit KDirModel(QObject *parent = nullptr);
     ~KDirModel();
 
+    /**
+     * Flags for the openUrl() method
+     * @see OpenUrlFlags
+     * @since 5.69
+     */
+    enum OpenUrlFlag {
+        NoFlags = 0x0,   ///< No additional flags specified.
+        Reload = 0x1,    ///< Indicates whether to use the cache or to reread
+                         ///< the directory from the disk.
+                         ///< Use only when opening a dir not yet listed by our dirLister()
+                         ///< without using the cache. Otherwise use dirLister()->updateDirectory().
+        ShowRoot = 0x2,  ///< Display a root node for the URL being opened.
+    };
+    /**
+     * Stores a combination of #OpenUrlFlag values.
+     */
+    Q_DECLARE_FLAGS(OpenUrlFlags, OpenUrlFlag)
+
+    /**
+     * Display the contents of @p url in the model.
+     * Apart from the support for the ShowRoot flag, this is equivalent to dirLister()->openUrl(url, flags)
+     * @param url   the URL of the directory whose contents should be listed.
+     *              Unless ShowRoot is set, the item for this directory will NOT be shown, the model starts at its children.
+     * @param flags see OpenUrlFlag
+     * @since 5.69
+     */
+    void openUrl(const QUrl &url, OpenUrlFlags flags = NoFlags);
+
     /**
      * Set the directory lister to use by this model, instead of the default KDirLister created internally.
      * The model takes ownership.
@@ -149,12 +166,18 @@ public:
         HasJobRole = 0x01E555A5  ///< returns whether or not there is a job on an item (file/directory)
     };
 
+    /**
+     * @see DropsAllowed
+     */
     enum DropsAllowedFlag {
         NoDrops = 0,
         DropOnDirectory = 1, ///< allow drops on any directory
         DropOnAnyFile = 2, ///< allow drops on any file
         DropOnLocalExecutable = 4 ///< allow drops on local executables, shell scripts and desktop files. Can be used with DropOnDirectory.
     };
+    /**
+     * Stores a combination of #DropsAllowedFlag values.
+     */
     Q_DECLARE_FLAGS(DropsAllowed, DropsAllowedFlag)
 
     /// Set whether dropping onto items should be allowed, and for which kind of item
@@ -278,5 +301,6 @@ private:
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KDirModel::DropsAllowed)
+Q_DECLARE_OPERATORS_FOR_FLAGS(KDirModel::OpenUrlFlags)
 
 #endif /* KDIRMODEL_H */
