@@ -1,24 +1,11 @@
-/*  This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1997 Torben Weis <weis@stud.uni-frankfurt.de>
+    SPDX-FileCopyrightText: 1999 Dirk Mueller <mueller@kde.org>
+    Portions SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
+    SPDX-FileCopyrightText: 2007 Pino Toscano <pino@kde.org>
 
-    Copyright (C) 1997 Torben Weis <weis@stud.uni-frankfurt.de>
-    Copyright (C) 1999 Dirk Mueller <mueller@kde.org>
-    Portions copyright (C) 1999 Preston Brown <pbrown@kde.org>
-    Copyright (C) 2007 Pino Toscano <pino@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kopenwithdialog.h"
@@ -36,30 +23,30 @@
 #include <QCheckBox>
 #include <QStyle>
 #include <QStyleOptionButton>
-#include <qstandardpaths.h>
-#include <qmimedatabase.h>
+#include <QStandardPaths>
+#include <QMimeDatabase>
 #include <QScreen>
 
 #include <kurlauthorized.h>
-#include <khistorycombobox.h>
-#include <kdesktopfile.h>
-#include <klineedit.h>
-#include <ksharedconfig.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <kshell.h>
+#include <KHistoryComboBox>
+#include <KDesktopFile>
+#include <KLineEdit>
+#include <KSharedConfig>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KShell>
 #include <kio/desktopexecparser.h>
-#include <kstringhandler.h>
+#include <KStringHandler>
 #include <kurlcompletion.h>
 #include <kurlrequester.h>
-#include <kservicegroup.h>
-#include <kcollapsiblegroupbox.h>
+#include <KServiceGroup>
+#include <KCollapsibleGroupBox>
 #include <QDebug>
 
 #include <assert.h>
 #include <stdlib.h>
 #include <kbuildsycocaprogressdialog.h>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 
 inline void writeEntry(KConfigGroup &group, const char *key,
                        const KCompletion::CompletionMode &aValue,
@@ -87,6 +74,7 @@ public:
 
     QString icon;
     QString text;
+    QString tooltip;
     QString entryPath;
     QString exec;
     bool isDir;
@@ -147,6 +135,7 @@ void KApplicationModelPrivate::fillNode(const QString &_entryPath, KDEPrivate::A
     for (const KSycocaEntry::Ptr &p : list) {
         QString icon;
         QString text;
+        QString tooltip;
         QString entryPath;
         QString exec;
         bool isDir = false;
@@ -159,6 +148,11 @@ void KApplicationModelPrivate::fillNode(const QString &_entryPath, KDEPrivate::A
 
             icon = service->icon();
             text = service->name();
+
+            // no point adding a tooltip that only repeats service->name()
+            const QString generic = service->genericName();
+            tooltip = generic != text ? generic : QString();
+
             exec = service->exec();
             entryPath = service->entryPath();
         } else if (p->isType(KST_KServiceGroup)) {
@@ -180,6 +174,7 @@ void KApplicationModelPrivate::fillNode(const QString &_entryPath, KDEPrivate::A
         KDEPrivate::AppNode *newnode = new KDEPrivate::AppNode();
         newnode->icon = icon;
         newnode->text = text;
+        newnode->tooltip = tooltip;
         newnode->entryPath = entryPath;
         newnode->exec = exec;
         newnode->isDir = isDir;
@@ -236,6 +231,11 @@ QVariant KApplicationModel::data(const QModelIndex &index, int role) const
             return QIcon::fromTheme(node->icon);
         }
         break;
+    case Qt::ToolTipRole:
+        if (!node->tooltip.isEmpty()) {
+            return node->tooltip;
+        }
+        break;
     default:
         ;
     }
@@ -499,18 +499,19 @@ public:
     KOpenWithDialog * const q;
 
     /**
-     * Determine mime type from URLs
+     * Determine MIME type from URLs
      */
-    void setMimeType(const QList<QUrl> &_urls);
+    void setMimeTypeFromUrls(const QList<QUrl> &_urls);
+
+    void setMimeType(const QString &mimeType);
 
     void addToMimeAppsList(const QString &serviceId);
 
     /**
-     * Create a dialog that asks for a application to open a given
-     * URL(s) with.
+     * Creates a dialog that lets the user select an application for opening one or more URLs.
      *
-     * @param text   appears as a label on top of the entry box.
-     * @param value  is the initial value of the line
+     * @param text   appears as a label on top of the entry box
+     * @param value  is the initial value in the entry box
      */
     void init(const QString &text, const QString &value);
 
@@ -563,12 +564,19 @@ KOpenWithDialog::KOpenWithDialog(const QList<QUrl> &_urls, QWidget *parent)
     {
         text = i18n("Choose the name of the program with which to open the selected files.");
     }
-    d->setMimeType(_urls);
+    d->setMimeTypeFromUrls(_urls);
     d->init(text, QString());
 }
 
 KOpenWithDialog::KOpenWithDialog(const QList<QUrl> &_urls, const QString &_text,
                                  const QString &_value, QWidget *parent)
+    : KOpenWithDialog(_urls, QString(), _text, _value, parent)
+{
+}
+
+KOpenWithDialog::KOpenWithDialog(const QList<QUrl> &_urls, const QString &mimeType,
+                                 const QString &_text, const QString &_value,
+                                 QWidget *parent)
     : QDialog(parent), d(new KOpenWithDialogPrivate(this))
 {
     setObjectName(QStringLiteral("openwith"));
@@ -584,7 +592,11 @@ KOpenWithDialog::KOpenWithDialog(const QList<QUrl> &_urls, const QString &_text,
         }
     }
     setWindowTitle(i18n("Choose Application"));
-    d->setMimeType(_urls);
+    if (mimeType.isEmpty()) {
+        d->setMimeTypeFromUrls(_urls);
+    } else {
+        d->setMimeType(mimeType);
+    }
     d->init(text, _value);
 }
 
@@ -598,13 +610,8 @@ KOpenWithDialog::KOpenWithDialog(const QString &mimeType, const QString &value,
     QString text = i18n("<qt>Select the program for the file type: <b>%1</b>. "
                         "If the program is not listed, enter the name or click "
                         "the browse button.</qt>", mimeType);
-    d->qMimeType = mimeType;
-    QMimeDatabase db;
-    d->qMimeTypeComment = db.mimeTypeForName(mimeType).comment();
+    d->setMimeType(mimeType);
     d->init(text, value);
-    if (d->remember) {
-        d->remember->hide();
-    }
 }
 
 KOpenWithDialog::KOpenWithDialog(QWidget *parent)
@@ -620,7 +627,7 @@ KOpenWithDialog::KOpenWithDialog(QWidget *parent)
     d->init(text, QString());
 }
 
-void KOpenWithDialogPrivate::setMimeType(const QList<QUrl> &_urls)
+void KOpenWithDialogPrivate::setMimeTypeFromUrls(const QList<QUrl> &_urls)
 {
     if (_urls.count() == 1) {
         QMimeDatabase db;
@@ -636,6 +643,13 @@ void KOpenWithDialogPrivate::setMimeType(const QList<QUrl> &_urls)
     }
 }
 
+void KOpenWithDialogPrivate::setMimeType(const QString &mimeType)
+{
+    qMimeType = mimeType;
+    QMimeDatabase db;
+    qMimeTypeComment = db.mimeTypeForName(mimeType).comment();
+}
+
 void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
 {
     bool bReadOnly = !KAuthorized::authorize(QStringLiteral("shell_access"));
@@ -644,8 +658,7 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
     m_pService = nullptr;
     curService = nullptr;
 
-    QBoxLayout *topLayout = new QVBoxLayout;
-    q->setLayout(topLayout);
+    QBoxLayout *topLayout = new QVBoxLayout(q);
     label = new QLabel(_text, q);
     label->setWordWrap(true);
     topLayout->addWidget(label);
@@ -699,13 +712,13 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
     QObject::connect(edit, &KUrlRequester::textChanged, q, &KOpenWithDialog::slotTextChanged);
     QObject::connect(edit, SIGNAL(urlSelected(QUrl)), q, SLOT(_k_slotFileSelected()));
 
+    view = new KApplicationView(q);
     QTreeViewProxyFilter *proxyModel = new QTreeViewProxyFilter(view);
     KApplicationModel *appModel = new KApplicationModel(proxyModel);
     proxyModel->setSourceModel(appModel);
     proxyModel->setFilterKeyColumn(0);
     proxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     proxyModel->setRecursiveFilteringEnabled(true);
-    view = new KApplicationView(q);
     view->setModels(appModel, proxyModel);
     topLayout->addWidget(view);
     topLayout->setStretchFactor(view, 1);
@@ -729,7 +742,7 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
     dialogExtension = new KCollapsibleGroupBox(q);
     dialogExtension->setTitle(i18n("Terminal options"));
 
-    QVBoxLayout *dialogExtensionLayout = new QVBoxLayout;
+    QVBoxLayout *dialogExtensionLayout = new QVBoxLayout(dialogExtension);
     dialogExtensionLayout->setContentsMargins(0, 0, 0, 0);
 
     terminal = new QCheckBox(i18n("Run in &terminal"), q);
@@ -766,7 +779,6 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
     nocloseonexitLayout->addWidget(nocloseonexit);
     dialogExtensionLayout->addLayout(nocloseonexitLayout);
 
-    dialogExtension->setLayout(dialogExtensionLayout);
     topLayout->addWidget(dialogExtension);
 
     buttonBox = new QDialogButtonBox(q);
@@ -779,11 +791,7 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
     //edit->setText( _value );
     // The resize is what caused "can't click on items before clicking on Name header" in previous versions.
     // Probably due to the resizeEvent handler using width().
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    q->resize( q->minimumWidth(), 0.6 * QApplication::screens().at(0)->availableGeometry().height());
-#else
     q->resize( q->minimumWidth(), 0.6 * q->screen()->availableGeometry().height());
-#endif
     edit->setFocus();
     q->slotTextChanged();
 }
@@ -910,7 +918,7 @@ void KOpenWithDialogPrivate::addToMimeAppsList(const QString &serviceId /*menu i
 
     profile->sync();
 
-    // Also make sure the "auto embed" setting for this mimetype is off
+    // Also make sure the "auto embed" setting for this MIME type is off
     KSharedConfig::Ptr fileTypesConfig = KSharedConfig::openConfig(QStringLiteral("filetypesrc"), KConfig::NoGlobals);
     fileTypesConfig->group("EmbedSettings").writeEntry(QStringLiteral("embed-") + qMimeType, false);
     fileTypesConfig->sync();
