@@ -1,29 +1,17 @@
-/* This file is part of the KDE libraries
- *  Copyright (C) 2000 Yves Arrouye <yves@realnames.com>
- *  Copyright (C) 2000,2010 Dawit Alemayehu <adawit at kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- **/
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Yves Arrouye <yves@realnames.com>
+    SPDX-FileCopyrightText: 2000, 2010 Dawit Alemayehu <adawit at kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kurifilter.h"
 
 #include "hostinfo.h"
 
-#include <kiconloader.h>
-#include <kservice.h>
+#include <KIconLoader>
+#include <KService>
 #include <kio/global.h>
 
 #include <KPluginMetaData>
@@ -636,10 +624,12 @@ QString KUriFilter::filteredUri(const QString &uri, const QStringList &filters)
     return data.uri().toString();
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(4, 6)
 bool KUriFilter::filterSearchUri(KUriFilterData &data)
 {
     return filterSearchUri(data, (NormalTextFilter | WebShortcutFilter));
 }
+#endif
 
 bool KUriFilter::filterSearchUri(KUriFilterData &data, SearchFilterTypes types)
 {
