@@ -1,23 +1,14 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2, as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kurlcombobox.h"
 
+#include "../pathhelpers_p.h" // isAbsoluteLocalPath()
+
 #include <QDir>
 #include <QMouseEvent>
 #include <QDrag>
@@ -26,8 +17,8 @@
 
 #include <QDebug>
 #include <kio/global.h>
-#include <klocalizedstring.h>
-#include <kiconloader.h>
+#include <KLocalizedString>
+#include <KIconLoader>
 
 #include <algorithm>
 #include <memory>
@@ -137,7 +128,7 @@ QStringList KUrlComboBox::urls() const
     for (int i = static_cast<int>(d->defaultList.size()); i < count(); i++) {
         url = itemText(i);
         if (!url.isEmpty()) {
-            if (QDir::isAbsolutePath(url))
+            if (isAbsoluteLocalPath(url))
                 list.append(QUrl::fromLocalFile(url).toString());
             else
                 list.append(url);
@@ -219,7 +210,7 @@ void KUrlComboBox::setUrls(const QStringList &_urls, OverLoadResolving remove)
             continue;
         }
         QUrl u;
-        if (QDir::isAbsolutePath(*it)) {
+        if (isAbsoluteLocalPath(*it)) {
             u = QUrl::fromLocalFile(*it);
         } else {
             u.setUrl(*it);
@@ -276,8 +267,8 @@ void KUrlComboBox::setUrl(const QUrl &url)
 
     setDefaults();
 
-    KUrlComboBoxPrivate::KUrlComboItemList::size_type offset = qMax(KUrlComboBoxPrivate::KUrlComboItemList::size_type(0), d->itemList.size() - d->myMaximum + d->defaultList.size());
-    for (auto i = offset; i < d->itemList.size(); ++i) {
+    const int offset = qMax(0, static_cast<int>(d->itemList.size() + d->defaultList.size()) - d->myMaximum);
+    for (size_t i = offset; i < d->itemList.size(); ++i) {
         d->insertUrlItem(d->itemList.at(i).get());
     }
 
@@ -329,8 +320,8 @@ void KUrlComboBox::setMaxItems(int max)
 
         setDefaults();
 
-        KUrlComboBoxPrivate::KUrlComboItemList::size_type offset = qMax(KUrlComboBoxPrivate::KUrlComboItemList::size_type(0), d->itemList.size() - d->myMaximum + d->defaultList.size());
-        for (auto i = offset; i < d->itemList.size(); ++i) {
+        const int offset = qMax(0, static_cast<int>(d->itemList.size() + d->defaultList.size()) - d->myMaximum);
+        for (size_t i = offset; i < d->itemList.size(); ++i) {
             d->insertUrlItem(d->itemList.at(i).get());
         }
 
@@ -437,11 +428,6 @@ void KUrlComboBoxPrivate::updateItem(const KUrlComboItem *item,
                                      int index, const QIcon &icon)
 {
     m_parent->setItemIcon(index, icon);
-#if 0
-    if (m_parent->isEditable()) {
-        item->text.clear(); // so that it gets recalculated
-    }
-#endif
     m_parent->setItemText(index, textForItem(item));
 }
 
