@@ -1,20 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1999,2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
-    Copyright (C) 2013           Teo Mrnjavac <teo@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999, 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2013 Teo Mrnjavac <teo@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2, as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KURLREQUESTER_H
@@ -22,7 +11,7 @@
 
 #include "kiowidgets_export.h"
 
-#include <keditlistwidget.h>
+#include <KEditListWidget>
 #include <kfile.h>
 
 #include <QFileDialog>
@@ -64,8 +53,10 @@ class KIOWIDGETS_EXPORT KUrlRequester : public QWidget
     Q_PROPERTY(QString filter READ filter WRITE setFilter)
     Q_PROPERTY(KFile::Modes mode READ mode WRITE setMode)
     Q_PROPERTY(QFileDialog::AcceptMode acceptMode READ acceptMode WRITE setAcceptMode)
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 0)
     /// @deprecated Since 5.0, use placeholderText
     Q_PROPERTY(QString clickMessage READ clickMessage WRITE setClickMessage)
+#endif
     Q_PROPERTY(QString placeholderText READ placeholderText WRITE setPlaceholderText)
     Q_PROPERTY(QString text READ text WRITE setText NOTIFY textChanged)
     Q_PROPERTY(Qt::WindowModality fileDialogModality READ fileDialogModality WRITE setFileDialogModality)
@@ -120,6 +111,9 @@ public:
      * Sets the mode of the file dialog.
      * Note: you can only select one file with the filedialog,
      * so KFile::Files doesn't make much sense.
+     *
+     * The default is KFile::File | KFile::ExistingOnly | KFile::LocalOnly.
+     *
      * @see QFileDialog::setFileMode()
      */
     void setMode(KFile::Modes m);
@@ -132,6 +126,9 @@ public:
 
     /**
      * Sets the open / save mode of the file dialog.
+     *
+     * The default is QFileDialog::AcceptOpen.
+     *
      * @see QFileDialog::setAcceptMode()
      * @since 5.33
      */
@@ -145,25 +142,25 @@ public:
     QFileDialog::AcceptMode acceptMode() const;
 
     /**
-     * Sets the filters for the file dialog, separated by \n.
+     * Sets the filters for the file dialog, separated by \\n.
      * @see QFileDialog::setNameFilters()
      */
     void setFilter(const QString &filter);
 
     /**
-    * Returns the filters for the file dialog, separated by \n.
+    * Returns the filters for the file dialog, separated by \\n.
     * @see QFileDialog::nameFilters()
     */
     QString filter() const;
 
     /**
-     * Sets the mimetype filters for the file dialog.
+     * Sets the MIME type filters for the file dialog.
      * @see QFileDialog::setMimeTypeFilters()
      * @since 5.31
      */
     void setMimeTypeFilters(const QStringList &mimeTypes);
     /**
-     * Returns the mimetype filters for the file dialog.
+     * Returns the MIME type filters for the file dialog.
      * @see QFileDialog::mimeTypeFilters()
      * @since 5.31
      */
@@ -263,6 +260,9 @@ public:
     /**
      * Set the window modality for the file dialog to @p modality
      * Directory selection dialogs are always modal
+     *
+     * The default is Qt::ApplicationModal.
+     *
      * @since 4.4
      */
     void setFileDialogModality(Qt::WindowModality modality);
@@ -289,7 +289,7 @@ public Q_SLOTS:
      *
      * @deprecated Since 4.3. Use setUrl(QUrl::fromLocalFile(path)) instead.
      */
-    KIOWIDGETS_DEPRECATED_VERSION(4, 3, "Use KUrlRequester::setUrlQUrl::fromLocalFile(path))")
+    KIOWIDGETS_DEPRECATED_VERSION(4, 3, "Use KUrlRequester::setUrl(QUrl::fromLocalFile(path))")
     void setPath(const QString &path);
 #endif
 
