@@ -1,33 +1,21 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Wilco Greven <greven@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Wilco Greven <greven@kde.org>
 
-    library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kurlrequesterdialog.h"
 
 #include <QDialogButtonBox>
 #include <QLabel>
-#include <QLayout>
 #include <QFileDialog>
+#include <QVBoxLayout>
 
-#include <klineedit.h>
-#include <klocalizedstring.h>
+#include <KLineEdit>
+#include <KLocalizedString>
 #include <krecentdocument.h>
-#include <kstandardguiitem.h>
+#include <KStandardGuiItem>
 #include <kurlrequester.h>
 
 class KUrlRequesterDialogPrivate
@@ -68,8 +56,7 @@ KUrlRequesterDialog::~KUrlRequesterDialog()
 
 void KUrlRequesterDialogPrivate::initDialog(const QString &text, const QUrl &urlName)
 {
-    QVBoxLayout *topLayout = new QVBoxLayout;
-    q->setLayout(topLayout);
+    QVBoxLayout *topLayout = new QVBoxLayout(q);
 
     QLabel *label = new QLabel(text, q);
     topLayout->addWidget(label);
@@ -127,7 +114,7 @@ QUrl KUrlRequesterDialog::getUrl(const QUrl &dir, QWidget *parent,
     return url;
 }
 
-#ifndef KIOWIDGETS_NO_DEPRECATED
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 0)
 QFileDialog *KUrlRequesterDialog::fileDialog()
 {
     return d->urlRequester->fileDialog();
