@@ -1,27 +1,16 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2005 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2005 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "pastedialog_p.h"
 
-#include <kcombobox.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QApplication>
+#include <QComboBox>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QLineEdit>
@@ -37,8 +26,7 @@ KIO::PasteDialog::PasteDialog(const QString &caption, const QString &label,
     setWindowTitle(caption);
     setModal(true);
 
-    QVBoxLayout *topLayout = new QVBoxLayout;
-    setLayout(topLayout);
+    QVBoxLayout *topLayout = new QVBoxLayout(this);
 
     QFrame *frame = new QFrame(this);
     topLayout->addWidget(frame);
@@ -55,7 +43,7 @@ KIO::PasteDialog::PasteDialog(const QString &caption, const QString &label,
     m_label->setBuddy(m_lineEdit);
 
     layout->addWidget(new QLabel(i18n("Data format:"), frame));
-    m_comboBox = new KComboBox(frame);
+    m_comboBox = new QComboBox(frame);
     m_comboBox->addItems(items);
     layout->addWidget(m_comboBox);
 
