@@ -1,22 +1,10 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  1999 - 2008 David Faure <faure@kde.org>
-                  2001, 2006 Holger Freyther <freyther@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 1999-2008 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2001, 2006 Holger Freyther <freyther@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kio/renamedialog.h"
@@ -35,23 +23,21 @@
 #include <QScrollArea>
 #include <QScrollBar>
 #include <QLayout>
+#include <QMenu>
+#include <QToolButton>
 
-#include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kio/global.h>
+#include <KIconLoader>
+#include <KMessageBox>
 #include <kio/udsentry.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <kfileitem.h>
-#include <kseparator.h>
-#include <kstringhandler.h>
-#include <kstandardguiitem.h>
-#include <kguiitem.h>
-#include <ksqueezedtextlabel.h>
-#if 0
-#include <kfilemetadatawidget.h>
-#endif
+#include <KSeparator>
+#include <KStringHandler>
+#include <KStandardGuiItem>
+#include <KGuiItem>
+#include <KSqueezedTextLabel>
 #include <previewjob.h>
-#include <kfileutils.h>
+#include <KFileUtils>
 
 using namespace KIO;
 
@@ -91,23 +77,87 @@ static KSqueezedTextLabel *createSqueezedLabel(QWidget *parent, const QString &t
     return label;
 }
 
+enum CompareFilesResult {
+    Identical,
+    PartiallyIdentical,
+    Different
+};
+static CompareFilesResult compareFiles(const QString &filepath, const QString &secondFilePath)
+{
+    const qint64 bufferSize = 4096; // 4kb
+    QFile f(filepath);
+    QFile f2(secondFilePath);
+    const auto fileSize = f.size();
+
+    if (fileSize != f2.size()) {
+        return CompareFilesResult::Different;
+    }
+    if (!f.open(QFile::ReadOnly)) {
+        qCWarning(KIO_WIDGETS) << "Could not open file for comparison:" << f.fileName();
+        return CompareFilesResult::Different;
+    }
+    if (!f2.open(QFile::ReadOnly)) {
+        f.close();
+        qCWarning(KIO_WIDGETS) << "Could not open file for comparison:" << f2.fileName();
+        return CompareFilesResult::Different;
+    }
+
+    QByteArray buffer(bufferSize, 0);
+    QByteArray buffer2(bufferSize, 0);
+
+    bool result = true;
+
+    auto seekFillBuffer = [bufferSize](qint64 pos, QFile &f, QByteArray &buffer) {
+        auto ioresult = f.seek(pos);
+        int bytesRead;
+        if (ioresult) {
+            bytesRead = f.read(buffer.data(), bufferSize);
+            ioresult = bytesRead != -1;
+        }
+        if (!ioresult) {
+            qCWarning(KIO_WIDGETS) << "Could not read file for comparison:" << f.fileName();
+            return false;
+        }
+        return true;
+    };
+
+    // compare at the beginning of the files
+    result = result && seekFillBuffer(0, f, buffer);
+    result = result && seekFillBuffer(0, f2, buffer2);
+    result = result && buffer == buffer2;
+
+    if (result && fileSize > 2 * bufferSize) {
+        // compare the contents in the middle of the files
+        result = result && seekFillBuffer(fileSize / 2 - bufferSize / 2, f, buffer);
+        result = result && seekFillBuffer(fileSize / 2 - bufferSize / 2, f2, buffer2);
+        result = result && buffer == buffer2;
+    }
+
+    if (result && fileSize > bufferSize) {
+        // compare the contents at the end of the files
+        result = result && seekFillBuffer(fileSize - bufferSize, f, buffer);
+        result = result && seekFillBuffer(fileSize - bufferSize, f2, buffer2);
+        result = result && buffer == buffer2;
+    }
+
+    if (!result) {
+        return CompareFilesResult::Different;
+    }
+
+    if (fileSize <= bufferSize * 3) {
+        // for files smaller than bufferSize * 3, we in fact compared fully the files
+        return CompareFilesResult::Identical;
+    } else {
+        return CompareFilesResult::PartiallyIdentical;
+    }
+}
+
 /** @internal */
 class Q_DECL_HIDDEN RenameDialog::RenameDialogPrivate
 {
 public:
     RenameDialogPrivate()
     {
-        bCancel = nullptr;
-        bRename = bSkip = bOverwrite = nullptr;
-        bResume = bSuggestNewName = nullptr;
-        bApplyAll = nullptr;
-        m_pLineEdit = nullptr;
-        m_srcPendingPreview = false;
-        m_destPendingPreview = false;
-        m_srcPreview = nullptr;
-        m_destPreview = nullptr;
-        m_srcArea = nullptr;
-        m_destArea = nullptr;
     }
 
     void setRenameBoxText(const QString &fileName)
@@ -125,22 +175,23 @@ public:
         }
     }
 
-    QPushButton *bCancel;
-    QPushButton *bRename;
-    QPushButton *bSkip;
-    QPushButton *bOverwrite;
-    QPushButton *bResume;
-    QPushButton *bSuggestNewName;
-    QCheckBox *bApplyAll;
-    QLineEdit *m_pLineEdit;
+    QPushButton *bCancel = nullptr;
+    QPushButton *bRename = nullptr;
+    QPushButton *bSkip = nullptr;
+    QToolButton *bOverwrite = nullptr;
+    QAction     *bOverwriteWhenOlder = nullptr;
+    QPushButton *bResume = nullptr;
+    QPushButton *bSuggestNewName = nullptr;
+    QCheckBox *bApplyAll = nullptr;
+    QLineEdit *m_pLineEdit = nullptr;
     QUrl src;
     QUrl dest;
-    bool m_srcPendingPreview;
-    bool m_destPendingPreview;
-    QLabel *m_srcPreview;
-    QLabel *m_destPreview;
-    QScrollArea *m_srcArea;
-    QScrollArea *m_destArea;
+    bool m_srcPendingPreview = false;
+    bool m_destPendingPreview = false;
+    QLabel *m_srcPreview = nullptr;
+    QLabel *m_destPreview = nullptr;
+    QScrollArea *m_srcArea = nullptr;
+    QScrollArea *m_destArea = nullptr;
     KFileItem srcItem;
     KFileItem destItem;
 };
@@ -169,8 +220,13 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
 
     if (_options & RenameDialog_MultipleItems) {
         d->bApplyAll = new QCheckBox(i18n("Appl&y to All"), this);
-        d->bApplyAll->setToolTip((_options & RenameDialog_IsDirectory) ? i18n("When this is checked the button pressed will be applied to all subsequent folder conflicts for the remainder of the current job.\nUnless you press Skip you will still be prompted in case of a conflict with an existing file in the directory.")
-                                 : i18n("When this is checked the button pressed will be applied to all subsequent conflicts for the remainder of the current job."));
+        d->bApplyAll->setToolTip((_options & RenameDialog_DestIsDirectory) ?
+                                 i18n("When this is checked the button pressed will be applied to all "
+                                      "subsequent folder conflicts for the remainder of the current job.\n"
+                                      "Unless you press Skip you will still be prompted in case of a "
+                                      "conflict with an existing file in the directory.")
+                                 : i18n("When this is checked the button pressed will be applied to "
+                                        "all subsequent conflicts for the remainder of the current job."));
         connect(d->bApplyAll, &QAbstractButton::clicked, this, &RenameDialog::applyAllPressed);
     }
 
@@ -184,15 +240,36 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
 
     if ((_options & RenameDialog_MultipleItems) && (_options & RenameDialog_Skip)) {
         d->bSkip = new QPushButton(i18n("&Skip"), this);
-        d->bSkip->setToolTip((_options & RenameDialog_IsDirectory) ? i18n("Do not copy or move this folder, skip to the next item instead")
+        d->bSkip->setToolTip((_options & RenameDialog_DestIsDirectory) ?
+                             i18n("Do not copy or move this folder, skip to the next item instead")
                              : i18n("Do not copy or move this file, skip to the next item instead"));
         connect(d->bSkip, &QAbstractButton::clicked, this, &RenameDialog::skipPressed);
     }
 
     if (_options & RenameDialog_Overwrite) {
-        const QString text = (_options & RenameDialog_IsDirectory) ? i18nc("Write files into an existing folder", "&Write Into") : i18n("&Overwrite");
-        d->bOverwrite = new QPushButton(text, this);
-        d->bOverwrite->setToolTip(i18n("Files and folders will be copied into the existing directory, alongside its existing contents.\nYou will be prompted again in case of a conflict with an existing file in the directory."));
+        d->bOverwrite = new QToolButton(this);
+        d->bOverwrite->setText(KStandardGuiItem::overwrite().text());
+        d->bOverwrite->setIcon(QIcon::fromTheme(KStandardGuiItem::overwrite().iconName()));
+        d->bOverwrite->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+
+        if (_options & RenameDialog_DestIsDirectory) {
+            d->bOverwrite->setText(i18nc("Write files into an existing folder", "&Write Into"));
+            d->bOverwrite->setIcon(QIcon());
+            d->bOverwrite->setToolTip(i18n("Files and folders will be copied into the existing directory, alongside its existing contents.\nYou will be prompted again in case of a conflict with an existing file in the directory."));
+
+        } else if ((_options & RenameDialog_MultipleItems) && mtimeSrc.isValid() && mtimeDest.isValid()) {
+            d->bOverwriteWhenOlder = new QAction(QIcon::fromTheme(KStandardGuiItem::overwrite().iconName()),
+                                                 i18nc("Overwrite files into an existing folder when files are older", "&Overwrite older files"), this);
+            d->bOverwriteWhenOlder->setEnabled(false);
+            d->bOverwriteWhenOlder->setToolTip(i18n("Destination files which have older modification times will be overwritten by the source, skipped otherwise."));
+            connect(d->bOverwriteWhenOlder, &QAction::triggered, this, &RenameDialog::overwriteWhenOlderPressed);
+
+            QMenu *overwriteMenu = new QMenu();
+            overwriteMenu->addAction(d->bOverwriteWhenOlder);
+            d->bOverwrite->setMenu(overwriteMenu);
+            d->bOverwrite->setPopupMode(QToolButton::MenuButtonPopup);
+
+        }
         connect(d->bOverwrite, &QAbstractButton::clicked, this, &RenameDialog::overwritePressed);
     }
 
@@ -219,6 +296,7 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
         } else {
             UDSEntry srcUds;
 
+            srcUds.reserve(4);
             srcUds.fastInsert(UDSEntry::UDS_NAME, d->src.fileName());
             srcUds.fastInsert(UDSEntry::UDS_MODIFICATION_TIME, mtimeSrc.toMSecsSinceEpoch() / 1000);
             srcUds.fastInsert(UDSEntry::UDS_CREATION_TIME, ctimeSrc.toMSecsSinceEpoch() / 1000);
@@ -232,6 +310,7 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
         } else {
             UDSEntry destUds;
 
+            destUds.reserve(4);
             destUds.fastInsert(UDSEntry::UDS_NAME, d->dest.fileName());
             destUds.fastInsert(UDSEntry::UDS_MODIFICATION_TIME, mtimeDest.toMSecsSinceEpoch() / 1000);
             destUds.fastInsert(UDSEntry::UDS_CREATION_TIME, ctimeDest.toMSecsSinceEpoch() / 1000);
@@ -242,12 +321,15 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
 
         d->m_srcPreview = createLabel(parent, QString());
         d->m_destPreview = createLabel(parent, QString());
+        QLabel *srcToDestArrow = createLabel(parent, QString());
 
         d->m_srcPreview->setMinimumHeight(KIconLoader::SizeEnormous);
         d->m_destPreview->setMinimumHeight(KIconLoader::SizeEnormous);
+        srcToDestArrow->setMinimumHeight(KIconLoader::SizeEnormous);
 
         d->m_srcPreview->setAlignment(Qt::AlignCenter);
         d->m_destPreview->setAlignment(Qt::AlignCenter);
+        srcToDestArrow->setAlignment(Qt::AlignCenter);
 
         d->m_srcPendingPreview = true;
         d->m_destPendingPreview = true;
@@ -269,38 +351,92 @@ RenameDialog::RenameDialog(QWidget *parent, const QString &_caption,
         QLabel *titleLabel = new QLabel(i18n("This action will overwrite the destination."), this);
         gridLayout->addWidget(titleLabel, gridRow, 0, 1, 2);    // takes the complete first line
 
-        if (mtimeDest > mtimeSrc) {
-            QLabel *warningLabel = new QLabel(i18n("Warning, the destination is more recent."), this);
 
-            gridLayout->addWidget(warningLabel, ++gridRow, 0, 1, 2);
-        }
         gridLayout->setRowMinimumHeight(++gridRow, 15);    // spacer
 
         QLabel *srcTitle = createLabel(parent, i18n("Source"), true);
         gridLayout->addWidget(srcTitle, ++gridRow, 0);
         QLabel *destTitle = createLabel(parent, i18n("Destination"), true);
-        gridLayout->addWidget(destTitle, gridRow, 1);
+        gridLayout->addWidget(destTitle, gridRow, 2);
 
         QLabel *srcUrlLabel = createSqueezedLabel(parent, d->src.toDisplayString(QUrl::PreferLocalFile));
         srcUrlLabel->setTextFormat(Qt::PlainText);
         gridLayout->addWidget(srcUrlLabel, ++gridRow, 0);
         QLabel *destUrlLabel = createSqueezedLabel(parent, d->dest.toDisplayString(QUrl::PreferLocalFile));
         destUrlLabel->setTextFormat(Qt::PlainText);
-        gridLayout->addWidget(destUrlLabel, gridRow, 1);
+        gridLayout->addWidget(destUrlLabel, gridRow, 2);
 
-        // The labels containing previews or icons
-        gridLayout->addWidget(d->m_srcArea, ++gridRow, 0);
-        gridLayout->addWidget(d->m_destArea, gridRow, 1);
+        gridLayout->addWidget(d->m_srcArea, ++gridRow, 0, 2, 1);
+
+        // The labels containing previews or icons, and an arrow icon indicating
+        // direction from src to dest
+        const QString arrowName = qApp->isRightToLeft() ? QStringLiteral("go-previous")
+                                                          : QStringLiteral("go-next");
+        const QPixmap pix = QIcon::fromTheme(arrowName).pixmap(d->m_srcPreview->height());
+        srcToDestArrow->setPixmap(pix);
+        gridLayout->addWidget(srcToDestArrow, gridRow, 1);
+
+        gridLayout->addWidget(d->m_destArea, gridRow, 2);
+
+        QLabel *diffTitle = createLabel(parent, i18n("Differences"), true);
+        gridLayout->addWidget(diffTitle, ++gridRow, 1);
 
         QLabel *srcDateLabel = createDateLabel(parent, d->srcItem);
         gridLayout->addWidget(srcDateLabel, ++gridRow, 0);
-        QLabel *destDateLabel = createDateLabel(parent, d->destItem);
-        gridLayout->addWidget(destDateLabel, gridRow, 1);
+
+        if (mtimeDest > mtimeSrc) {
+            gridLayout->addWidget(createLabel(parent, QStringLiteral("The destination is <b>more recent</b>")), gridRow, 1);
+        }
+        QLabel *destDateLabel = createLabel(parent, i18n("Date: %1", d->destItem.timeString(KFileItem::ModificationTime)));
+        gridLayout->addWidget(destDateLabel, gridRow, 2);
 
         QLabel *srcSizeLabel = createSizeLabel(parent, d->srcItem);
         gridLayout->addWidget(srcSizeLabel, ++gridRow, 0);
-        QLabel *destSizeLabel = createSizeLabel(parent, d->destItem);
-        gridLayout->addWidget(destSizeLabel, gridRow, 1);
+
+        if (d->srcItem.size() != d->destItem.size()) {
+            QString text;
+            int diff = 0;
+            if (d->srcItem.size() > d->destItem.size()) {
+                diff = d->srcItem.size()  - d->destItem.size();
+                text = i18n("The destination is <b>smaller by %1</b>", KIO::convertSize(diff));
+            } else {
+                diff = d->destItem.size()  - d->srcItem.size();
+                text = i18n("The destination is <b>bigger by %1</b>", KIO::convertSize(diff));
+            }
+            gridLayout->addWidget(createLabel(parent, text), gridRow, 1);
+        }
+        QLabel *destSizeLabel = createLabel(parent, i18n("Size: %1", KIO::convertSize(d->destItem.size())));
+        gridLayout->addWidget(destSizeLabel, gridRow, 2);
+
+        // check files contents for local files
+        if ((d->dest.isLocalFile() && !(_options & RenameDialog_DestIsDirectory))
+            && (d->src.isLocalFile() && !(_options & RenameDialog_SourceIsDirectory))) {
+
+            const CompareFilesResult CompareFilesResult = compareFiles(d->src.toLocalFile(), d->dest.toLocalFile());
+
+            QString text;
+            switch (CompareFilesResult) {
+                case CompareFilesResult::Identical: text = i18n("The files are identical."); break;
+                case CompareFilesResult::PartiallyIdentical: text = i18n("The files seem identical."); break;
+                case CompareFilesResult::Different: text = i18n("The files are different."); break;
+            }
+            QLabel* filesIdenticalLabel = createLabel(this, text, true);
+            if (CompareFilesResult == CompareFilesResult::PartiallyIdentical) {
+                QLabel* pixmapLabel = new QLabel(this);
+                pixmapLabel->setPixmap(QIcon::fromTheme(QStringLiteral("help-about")).pixmap(QSize(16,16)));
+                pixmapLabel->setToolTip(
+                            i18n("The files are likely to be identical: they have the same size and their contents are the same at the beginning, middle and end.")
+                            );
+                pixmapLabel->setCursor(Qt::WhatsThisCursor);
+
+                QHBoxLayout* hbox = new QHBoxLayout(this);
+                hbox->addWidget(filesIdenticalLabel);
+                hbox->addWidget(pixmapLabel);
+                gridLayout->addLayout(hbox, gridRow + 1, 1);
+            } else {
+                gridLayout->addWidget(filesIdenticalLabel, gridRow + 1, 1);
+            }
+        }
 
     } else {
         // This is the case where we don't want to allow overwriting, the existing
@@ -464,10 +600,12 @@ void RenameDialog::renamePressed()
     }
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 0)
 QString RenameDialog::suggestName(const QUrl &baseURL, const QString &oldName)
 {
     return KFileUtils::suggestName(baseURL, oldName);
 }
+#endif
 
 // Propose button clicked
 void RenameDialog::suggestNewNamePressed()
@@ -504,6 +642,13 @@ void RenameDialog::overwritePressed()
     }
 }
 
+void RenameDialog::overwriteWhenOlderPressed()
+{
+    if (d->bApplyAll && d->bApplyAll->isChecked()) {
+        done(Result_OverwriteWhenOlder);
+    }
+}
+
 void RenameDialog::overwriteAllPressed()
 {
     done(Result_OverwriteAll);
@@ -525,27 +670,25 @@ void RenameDialog::resumeAllPressed()
 
 void RenameDialog::applyAllPressed()
 {
-    if (d->bApplyAll  && d->bApplyAll->isChecked()) {
+    const bool applyAll = d->bApplyAll && d->bApplyAll->isChecked();
+
+    if (applyAll) {
         d->m_pLineEdit->setText(KIO::decodeFileName(d->dest.fileName()));
         d->m_pLineEdit->setEnabled(false);
-
-        if (d->bRename) {
-            d->bRename->setEnabled(true);
-        }
-
-        if (d->bSuggestNewName) {
-            d->bSuggestNewName->setEnabled(false);
-        }
     } else {
         d->m_pLineEdit->setEnabled(true);
+    }
 
-        if (d->bRename) {
-            d->bRename->setEnabled(false);
-        }
+    if (d->bRename) {
+        d->bRename->setEnabled(applyAll);
+    }
 
-        if (d->bSuggestNewName) {
-            d->bSuggestNewName->setEnabled(true);
-        }
+    if (d->bSuggestNewName) {
+        d->bSuggestNewName->setEnabled(!applyAll);
+    }
+
+    if (d->bOverwriteWhenOlder) {
+        d->bOverwriteWhenOlder->setEnabled(applyAll);
     }
 }
 
@@ -555,7 +698,7 @@ void RenameDialog::showSrcIcon(const KFileItem &fileitem)
     d->m_srcPendingPreview = false;
 
     const int size = d->m_srcPreview->height();
-    const QPixmap pix = KIconLoader::global()->loadMimeTypeIcon(fileitem.iconName(), KIconLoader::Desktop, size);
+    const QPixmap pix = QIcon::fromTheme(fileitem.iconName(), QIcon::fromTheme(QStringLiteral("application-octet-stream"))).pixmap(size);
     d->m_srcPreview->setPixmap(pix);
 }
 
@@ -565,7 +708,7 @@ void RenameDialog::showDestIcon(const KFileItem &fileitem)
     d->m_destPendingPreview = false;
 
     const int size = d->m_destPreview->height();
-    const QPixmap pix = KIconLoader::global()->loadMimeTypeIcon(fileitem.iconName(), KIconLoader::Desktop, size);
+    const QPixmap pix = QIcon::fromTheme(fileitem.iconName(), QIcon::fromTheme(QStringLiteral("application-octet-stream"))).pixmap(size);
     d->m_destPreview->setPixmap(pix);
 }
 
@@ -612,11 +755,11 @@ void RenameDialog::resizePanels()
     d->m_srcArea->setMinimumSize(halfSize.boundedTo(maxHalfSize));
     d->m_destArea->setMinimumSize(halfSize.boundedTo(maxHalfSize));
 
-    KIO::PreviewJob *srcJob = KIO::filePreview(KFileItemList() << d->srcItem,
+    KIO::PreviewJob *srcJob = KIO::filePreview(KFileItemList{d->srcItem},
                               QSize(d->m_srcPreview->width() * qreal(0.9), d->m_srcPreview->height()));
     srcJob->setScaleType(KIO::PreviewJob::Unscaled);
 
-    KIO::PreviewJob *destJob = KIO::filePreview(KFileItemList() << d->destItem,
+    KIO::PreviewJob *destJob = KIO::filePreview(KFileItemList{d->destItem},
                                QSize(d->m_destPreview->width() * qreal(0.9), d->m_destPreview->height()));
     destJob->setScaleType(KIO::PreviewJob::Unscaled);
 
@@ -632,10 +775,11 @@ void RenameDialog::resizePanels()
 
 QScrollArea *RenameDialog::createContainerLayout(QWidget *parent, const KFileItem &item, QLabel *preview)
 {
+    Q_UNUSED(item)
+#if 0 // PENDING
     KFileItemList itemList;
     itemList << item;
 
-#if 0 // PENDING
     // KFileMetaDataWidget was deprecated for a Nepomuk widget, which is itself deprecated...
     // If we still want metadata shown, we need a plugin that fetches data from KFileMetaData::ExtractorCollection
     KFileMetaDataWidget *metaWidget =  new KFileMetaDataWidget(this);
@@ -656,9 +800,6 @@ QScrollArea *RenameDialog::createContainerLayout(QWidget *parent, const KFileIte
     containerLayout->setContentsMargins(0, 0, 0, 0);
     containerLayout->setSpacing(0);
     containerLayout->addWidget(preview);
-#if 0 // PENDING
-    containerLayout->addWidget(metaWidget);
-#endif
     containerLayout->addStretch(1);
 
     QScrollArea *metaDataArea = new QScrollArea(parent);
