@@ -1,22 +1,10 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  1999 - 2008 David Faure <faure@kde.org>
-                  2001 Holger Freyther <freyther@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 1999-2008 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2001 Holger Freyther <freyther@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_RENAMEDIALOG_H
@@ -90,15 +78,16 @@ public:
      */
     QUrl autoDestUrl() const;
 
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Given a directory path and a filename (which usually exists already),
      * this function returns a suggested name for a file that doesn't exist
      * in that directory. The existence is only checked for local urls though.
      * The suggested file name is of the form "foo 1", "foo 2" etc.
-     * @deprecated use KIO::suggestName
+     * @deprecated Since 5.0. Use KIO::suggestName, since 5.61, use KFileUtils::suggestName from KCoreAddons
      */
-#ifndef KIOWIDGETS_NO_DEPRECATED
-    static KIOWIDGETS_DEPRECATED QString suggestName(const QUrl &baseURL, const QString &oldName);
+    KIOWIDGETS_DEPRECATED_VERSION(5, 0, "Use KFileUtils::suggestName(const QUrl &, const QString &) from KCoreAddons >= 5.61, or KIO::suggestName(const QUrl &, const QString &)")
+    static QString suggestName(const QUrl &baseURL, const QString &oldName);
 #endif
 
 public Q_SLOTS:
@@ -108,6 +97,7 @@ public Q_SLOTS:
     void autoSkipPressed();
     void overwritePressed();
     void overwriteAllPressed();
+    void overwriteWhenOlderPressed();
     void resumePressed();
     void resumeAllPressed();
     void suggestNewNamePressed();
