@@ -17,7 +17,6 @@
 #include <QVBoxLayout>
 
 #include <KLocalizedString>
-#include <kio/jobuidelegateextension.h>
 
 using namespace KIO;
 
@@ -26,8 +25,7 @@ SkipDialog::SkipDialog(QWidget *parent, KIO::SkipDialog_Options options, const Q
 {
     setWindowTitle(i18n("Information"));
 
-    QVBoxLayout *layout = new QVBoxLayout;
-    setLayout(layout);
+    QVBoxLayout *layout = new QVBoxLayout(this);
 
     layout->addWidget(new QLabel(_error_text, this));
 
