@@ -25,6 +25,10 @@
 #include <kio/copyjob.h>
 #include <kio/deletejob.h>
 #include <kprotocolinfo.h>
+
+// QT_STAT_LNK on Windows
+#include "kioglobal_p.h"
+
 #include <QTimer>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
@@ -312,7 +316,7 @@ void KioslaveTest::slotResult(KJob *_job)
         UDSEntry entry = ((KIO::StatJob *)_job)->statResult();
         printUDSEntry(entry);
     } else if (selectedOperation == Mimetype) {
-        qDebug() << "mimetype is " << ((KIO::MimetypeJob *)_job)->mimetype();
+        qDebug() << "MIME type is " << ((KIO::MimetypeJob *)_job)->mimetype();
     }
 
     if (job == _job) {
