@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2002 Dirk Mueller <mueller@kde.org>
-    Copyright (C) 2003 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2002 Dirk Mueller <mueller@kde.org>
+    SPDX-FileCopyrightText: 2003 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <QApplication>
@@ -50,7 +38,7 @@ int main(int argc, char **argv)
     }
     delete dlg;
 
-    // Test with a mimetype
+    // Test with a MIME type
     QString mimetype = QStringLiteral("text/plain");
     dlg = new KOpenWithDialog(mimetype, QStringLiteral("kwrite"), nullptr);
     if (dlg->exec()) {
